/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.cocoon;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.regex.Pattern;

import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.thread.ThreadSafe;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.matching.Matcher;
import org.apache.cocoon.sitemap.PatternException;

/**
 * Regexp matcher for URI. Unlike Cocoon's native RegexpMatcher, it uses JDK's {@link Pattern}.
 */
public class RegexpURIMatcher extends AbstractLogEnabled implements Matcher, ThreadSafe
{
    private Map<String, Pattern> _patterns = new ConcurrentHashMap<>();
    
    public Map match(String pattern, Map objectModel, Parameters parameters) throws PatternException
    {
        Pattern p = _patterns.computeIfAbsent("^" + pattern + "$", Pattern::compile);

        String uri = ObjectModelHelper.getRequest(objectModel).getSitemapURI();

        if (uri.startsWith("/")) 
        {
            uri = uri.substring(1);
        }
        
        java.util.regex.Matcher matcher = p.matcher(uri);
        if (!matcher.matches())
        {
            return null;
        }

        Map<String, String> result = new HashMap<>();

        for (int i = 0; i <= matcher.groupCount(); i++)
        {
            result.put(String.valueOf(i), matcher.group(i));
        }
        
        return result;
    }
}
