/*
 *  Copyright 2024 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.config;

import java.util.Map;
import java.util.Optional;

import org.apache.commons.lang3.StringUtils;

import org.ametys.runtime.model.ElementDefinition;
import org.ametys.runtime.model.disableconditions.AbstractDisableConditionsEvaluator;
import org.ametys.runtime.model.disableconditions.DisableConditions;

/**
 * Evaluator for {@link DisableConditions} on config parameters
 */
public class ConfigDisableConditionsEvaluator extends AbstractDisableConditionsEvaluator<Config>
{
    /** The Avalon role */
    public static final String ROLE = ConfigDisableConditionsEvaluator.class.getName();
    
    @Override
    protected Optional<ElementDefinition> getConditionDefinition(String conditionDataPath, Config object)
    {
        ConfigManager configManager = ConfigManager.getInstance();
        return Optional.ofNullable(conditionDataPath)
                       .map(configManager::getModelItem)
                       .filter(ElementDefinition.class::isInstance)
                       .map(ElementDefinition.class::cast);
    }
    
    /**
     * {@inheritDoc}
     * @throws IllegalArgumentException if the given condition data path is empty
     */
    @Override
    protected boolean containsValue(String conditionDataPath, Optional<String> oldConditionDataPath, Map<String, Object> values, Config config, Map<String, Object> contextualParameters)
    {
        if (StringUtils.isEmpty(conditionDataPath))
        {
            throw new IllegalArgumentException("Unable to retrieve the value at the given condition path. This path is empty.");
        }
        
        return values.containsKey(conditionDataPath);
    }
    
    @Override
    protected Object getValueFromMap(String conditionDataPath, Optional<String> oldConditionDataPath, Map<String, Object> values, Config config, Map<String, Object> contextualParameters) throws IllegalArgumentException
    {
        return values.get(conditionDataPath);
    }
    
    @Override
    protected Object getStoredValue(String conditionDataPath, Optional<String> oldConditionDataPath, Config config, Map<String, Object> contextualParameters)
    {
        return config.getValue(conditionDataPath);
    }
}
