/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.config;

import org.ametys.runtime.model.CategorizedElementDefinitionWrapper;

/**
 * Object containing the definition of a configuration parameter and informations about its categories / groups and group switch
 * @param <T> Type of the parameter value
 */
public class ConfigParameterDefinitionWrapper<T> extends CategorizedElementDefinitionWrapper<T>
{
    /** Defines if this definition is the group switch */
    protected boolean _isGroupSwitch;
    
    /**
     * Default constructor.
     */
    public ConfigParameterDefinitionWrapper()
    {
        super();
    }
    
    /**
     * Constructor by copying an existing {@link ConfigParameterDefinitionWrapper}.
     * @param wrapperToCopy The {@link ConfigParameterDefinitionWrapper} to copy
     */
    public ConfigParameterDefinitionWrapper(CategorizedElementDefinitionWrapper<T> wrapperToCopy)
    {
        super(wrapperToCopy);
        
        // Group switch
        setGroupSwitch(isGroupSwitch());
    }
    
    /**
     * Retrieves true if this definition is the group switch
     * @return true if this definition is the group switch, false otherwise
     */
    public boolean isGroupSwitch()
    {
        return _isGroupSwitch;
    }
    
    /***
     * Sets the group switch
     * @param isGroupSwitch true if this definition is the group switch
     */
    public void setGroupSwitch(boolean isGroupSwitch)
    {
        _isGroupSwitch = isGroupSwitch;
    }
}
