/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.config;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.runtime.model.CategorizedElementDefinitionParser;
import org.ametys.runtime.model.ElementDefinition;
import org.ametys.runtime.model.ElementDefinitionParser;
import org.ametys.runtime.model.Model;
import org.ametys.runtime.model.ModelItemGroup;

/**
 * Parser for configuration parameter wrappers
 */
public class ConfigParameterDefinitionWrapperParser extends CategorizedElementDefinitionParser
{
    /**
     * Creates a configuration parameter definition parser.
     * @param parser the element definition parser
     */
    public ConfigParameterDefinitionWrapperParser(ElementDefinitionParser parser)
    {
        super(parser);
    }
    
    @Override
    public ConfigParameterDefinitionWrapper parse(ServiceManager serviceManager, String pluginName, Configuration definitionConfig, Model model, ModelItemGroup parent) throws ConfigurationException
    {
        ConfigParameterDefinitionWrapper wrapper = (ConfigParameterDefinitionWrapper) super.parse(serviceManager, pluginName, definitionConfig, model, parent);
        
        wrapper.setGroupSwitch(_isGroupSwitch(definitionConfig));
        _setGroupSwitchDefaultValue(definitionConfig, wrapper.getDefinition());
        
        return wrapper;
    }
    
    @Override
    protected ConfigParameterDefinitionWrapper _createElementDefinitionWrapper()
    {
        return new ConfigParameterDefinitionWrapper();
        
    }
    
    @SuppressWarnings("unchecked")
    private void _setGroupSwitchDefaultValue(Configuration definitionConfig, ElementDefinition definition)
    {
        Object defaultValue = definition.getDefaultValue();
        if (_isGroupSwitch(definitionConfig) && defaultValue == null)
        {
            definition.setDefaultValue(Boolean.FALSE);
        }
    }
    
    private boolean _isGroupSwitch(Configuration definitionConfig)
    {
        return definitionConfig.getAttributeAsBoolean("group-switch", false);
    }
}
