/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.i18n;

import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

/**
 * Interface for all internationalizable or localizable objects (dates, texts, numbers...).
 */
public interface I18nizable
{
    /**
     * Represents this {@link I18nizable} as SAX events.
     * @param handler the SAX content handler
     * @throws SAXException if an error occurs
     */
    public void toSAX(ContentHandler handler) throws SAXException;
    
    /**
     * Represents this {@link I18nizable} as SAX events, surrounded by the provided tag.
     * @param handler the SAX content handler
     * @param tagName the tag name
     * @throws SAXException if an error occurs
     */
    public default void toSAX(ContentHandler handler, String tagName) throws SAXException
    {
        XMLUtils.startElement(handler, tagName);
        toSAX(handler);
        XMLUtils.endElement(handler, tagName);
    }
}
