/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.log;

import org.apache.log4j.Appender;
import org.apache.log4j.Logger;

import org.ametys.runtime.plugin.ExtensionPoint;
import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;

/**
 * {@link ExtensionPoint} handling the {@link ExternalLog}s.
 */
public class ExternalLogExtensionPoint  extends AbstractThreadSafeComponentExtensionPoint<ExternalLog>
{
    /** Avalon Role */
    public static final String ROLE = ExternalLogExtensionPoint.class.getName();
    
    @Override
    public void initializeExtensions() throws Exception
    {
        super.initializeExtensions();
        MemoryAppender memoryAppender = _getMemoryAppender();

        for (String extensionId : this.getExtensionsIds())
        {
            ExternalLog extension = this.getExtension(extensionId);
            Appender appender = extension.getAppender();
            org.apache.log4j.Logger category = extension.getCategory();
            category.addAppender(appender);
            if (memoryAppender != null && !category.getAdditivity())
            {
                category.addAppender(memoryAppender);
            }
        }
    }

    /**
     * Get the memory-appender
     * @return the memory appender of the application, or null if none found
     */
    private MemoryAppender _getMemoryAppender()
    {
        Appender memoryAppender = Logger.getRootLogger().getAppender(org.ametys.plugins.core.ui.log.LogManager.MEMORY_APPENDER_NAME);
        if (memoryAppender != null && memoryAppender instanceof MemoryAppender)
        {
            return (MemoryAppender) memoryAppender;
        }
        return null;
    }

}
