/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

import java.util.Comparator;

/**
 * Comparator for the element definition wrappers using their position
 * If no position is set, compares the definitions themselves
 * @param <T> type of the {@link CategorizedElementDefinitionWrapper} to compare
 */
public class CategorizedElementDefinitionWrapperComparator<T extends CategorizedElementDefinitionWrapper> implements Comparator<T>
{
    public int compare(T wrapper1, T wrapper2)
    {
        int positionComparison = CategorizedElementDefinitionHelper.compareWrapperPositions(wrapper1, wrapper2);
        if (positionComparison != 0)
        {
            return positionComparison;
        }
        else
        {
            return compareWrappersWithSamePositions(wrapper1, wrapper2);
        }
    }
    
    /**
     * Compares the given wrappers that have the same (maybe not set) positions
     * @param wrapper1 the first wrapper
     * @param wrapper2 the second wrapper
     * @return a negative integer, zero, or a positive integer as the first wrapper
     * is less than, equal to, or greater than the second.
     */
    protected int compareWrappersWithSamePositions(T wrapper1, T wrapper2)
    {
        return wrapper1.getDefinition().compareTo(wrapper2.getDefinition());
    }
}
