/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

import java.util.Comparator;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * Comparator of model items. Compare the model items' by their labels using the given {@link Comparator} of {@link I18nizableText}
 */
public class I18nizableTextModelItemComparator implements Comparator<ModelItem>
{
    private final Comparator<I18nizableText> _labelComparator;

    /**
     * Constructor
     * @param labelComparator a {@link Comparator} of {@link I18nizableText}
     */
    public I18nizableTextModelItemComparator(Comparator<I18nizableText> labelComparator)
    {
        this._labelComparator = labelComparator;
    }

    public int compare(ModelItem item1, ModelItem item2)
    {
        return _labelComparator.compare(item1.getLabel(), item2.getLabel());
    }
}
