/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

import java.util.Arrays;
import java.util.Collection;

/**
 * Interface of model classes for parameters or attributes
 */
public interface Model extends ModelItemContainer
{
    /**
     * Creates a {@link Model} with the given {@link ModelItem}s
     * @param id the model identifier
     * @param familyId the model family identifier
     * @param modelItems the model items
     * @return the created {@link Model}
     */
    public static Model of(String id, String familyId, ModelItem... modelItems)
    {
        Collection<? extends ModelItem> modelItemsAsList = Arrays.asList(modelItems);
        
        Model model = new Model()
        {
            public Collection< ? extends ModelItem> getModelItems()
            {
                return modelItemsAsList;
            }
            
            public String getId()
            {
                return id;
            }
            
            public String getFamilyId()
            {
                return familyId;
            }
        };
        
        for (ModelItem modelItem : modelItems)
        {
            modelItem.setModel(model);
        }
        
        return model;
    }
    
    /**
     * Retrieves the model id (an id must be unique in the family {@link #getFamilyId()}
     * @return model id (for example the content type id for a content)
     */
    public String getId();
    
    /**
     * Retrieves the Family Id (for example the extension point)
     * Each model Id have to be unique in it's family Id
     * @return content point (for example "org.ametys.cms.contenttype.ContentTypeExtensionPoint" for a content)
     */
    public String getFamilyId();
}
