/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

/**
 * Interface for view references to model items
 * @param <T> type of the referenced model item
 */
public interface ModelViewItem<T extends ModelItem> extends ViewItem
{
    /**
     * Retrieves the referenced model item definition
     * @return the referenced definition
     */
    public T getDefinition();
    
    /**
     * Sets the referenced model item definition
     * @param definition the referenced definition
     */
    public void setDefinition(T definition);
    
    default void setName(String name)
    {
        throw new UnsupportedOperationException("Cannot set name for a ModelViewItem");
    }
}
