/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

import java.util.LinkedHashMap;
import java.util.Map;

import org.ametys.runtime.i18n.I18nizableText;


/**
 * This implementation enumerate the static configured elements
 * @param <T> Type of the values
 */
public class StaticEnumerator<T> implements Enumerator<T>
{
    private Map<T, I18nizableText> _entries = new LinkedHashMap<>();
    
    /**
     * Adds new entries.
     * @param entries the entries to add
     */
    public void addAll(Map<T, I18nizableText> entries)
    {
        _entries.putAll(entries);
    }

    /**
     * Adds a new entry.
     * @param label the entry label.
     * @param value the entry value.
     */
    public void add(I18nizableText label, T value)
    {
        _entries.put(value, label);
    }
    
    public I18nizableText getEntry(T value)
    {
        return _entries.get(value);
    }
    
    public Map<T, I18nizableText> getTypedEntries()
    {
        return _entries;
    }
}
