/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

import java.util.Map;

import org.apache.cocoon.ProcessingException;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * Reference to a view to included in another view.
 * Use this temporary reference only in view parsers, and resolve it before using the first view
 */
public class TemporaryViewReference implements ViewItem
{
    private String _name;

    public void setName(String name)
    {
        _name = name;
    }
    
    public String getName()
    {
        return _name;
    }

    public void setLabel(I18nizableText label)
    {
        throw new UnsupportedOperationException("Cannot set a label to a view reference");
    }

    public void setDescription(I18nizableText description)
    {
        throw new UnsupportedOperationException("Cannot set a description to a view reference");
    }

    public I18nizableText getLabel()
    {
        throw new UnsupportedOperationException("Cannot get a label from a view reference");
    }

    public I18nizableText getDescription()
    {
        throw new UnsupportedOperationException("Cannot get a description from a view reference");
    }
    
    public ViewItemAccessor getParent()
    {
        throw new UnsupportedOperationException("Cannot get a parent from a view reference");
    }
    
    public void setParent(ViewItemAccessor parent)
    {
        // Do nothing, ignore parent setting
    }

    public Map<String, Object> toJSON(DefinitionContext context) throws ProcessingException
    {
        throw new UnsupportedOperationException("Cannot convert a view reference to JSON");
    }
    
    public void toSAX(ContentHandler contentHandler, DefinitionContext context) throws SAXException
    {
        throw new UnsupportedOperationException("Cannot generate SAX events for a view reference"); 
    }
    
    public boolean equals(Object obj, boolean checkDetails)
    {
        throw new UnsupportedOperationException("Cannot compare view references");
    }

    public ViewItem createInstance()
    {
        return new TemporaryViewReference();
    }

    public void copyTo(ViewItem item)
    {
        assert item instanceof TemporaryViewReference;
        item.setName(getName());
    }

}
