/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

/**
 * interface for group of view items
 */
public interface ViewItemGroup extends ViewItem, ViewItemContainer
{
    /** Role for tab view items */
    public static final String TAB_ROLE = "tab";
    
    /** Role for fieldset view items */
    public static final String FIELDSET_ROLE = "fieldset";
    
    /**
     * Retrieves the role.
     * @return the role.
     */
    public String getRole();
    
    /**
     * Set the role.
     * @param role the role.
     */
    public void setRole(String role);
    
    @Override
    public default void copyTo(ViewItem item, View referenceView, String itemPath)
    {
        ViewItem.super.copyTo(item, referenceView, itemPath);
        
        assert item instanceof ViewItemGroup;
        ViewHelper.addViewAccessorItems((ViewItemGroup) item, this, referenceView, itemPath);
    }
}
