/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model;

import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.runtime.model.ModelHelper.ConfigurationAndPluginName;

/**
 * Interface for components that parse view's configuration
 */
public interface ViewParser
{
    /** Default tag name for simple groups */
    public static final String ADD_GROUP_TAG_NAME = "group";
    
    /** Default tag name for items */
    public static final String ADD_ITEM_TAG_NAME = "item";

    /** Default attribute name for items' references */
    public static final String ITEM_REFERENCE_ATTRIBUTE_NAME = "ref";
    
    /** Tag name for references to delete items */
    public static final String REMOVE_ITEM_TAG_NAME = "remove-item";
    
    /** The name of item reference to add all items */
    public static final String ALL_ITEMS_REFERENCE = "*";
    
    /**
     * Parses a view configuration to create a {@link View} object.
     * @param viewConfiguration the configuration of the view to parse
     * @return the view
     * @throws ConfigurationException if the configuration is not valid.
     */
    public View parseView(ConfigurationAndPluginName viewConfiguration) throws ConfigurationException;
    
    /**
     * Parses a view configuration to override a {@link View} object.
     * @param viewConfiguration the configuration of the view to parse
     * @param existingView The view to override
     * @return the overridden view
     * @throws ConfigurationException if the configuration is not valid.
     */
    public View overrideView(ConfigurationAndPluginName viewConfiguration, View existingView) throws ConfigurationException;
}
