/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.model.compare;

/**
 * Details of type of data change
 */
public enum DataChangeTypeDetail
{
    /**
     * No particular detail
     */
    NONE,
    /**
     * New (int/bool/long) is bigger than old
     */
    MORE,
    /**
     * New (int/bool/long) is smaller than old
     */
    LESS,
    /**
     * Same data, but order changed
     */
    ORDER,
    /**
     * New (date) is before old
     */
    BEFORE,
    /**
     * New (date) is after old
     */
    AFTER,
    /**
     * More content in new field
     */
    MORE_CONTENT,
    /**
     * More content at the start of the new field
     */
    MORE_CONTENT_START,
    /**
     * More content at the end of the new field
     */
    MORE_CONTENT_END,
    /**
     * Less content in the new field
     */
    LESS_CONTENT,
    /**
     * Less content at the start of the new field
     */
    LESS_CONTENT_START,
    /**
     * Less content at the end of the new field
     */
    LESS_CONTENT_END,
    /**
     * MetadataType changed (reference file to binary file for example)
     */
    TYPE
}
