/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugin;

import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

import org.apache.commons.collections4.CollectionUtils;

import org.ametys.runtime.plugin.PluginsManager.InactivityCause;

class IncomingDeactivation
{
    static enum Type
    {
        DEACTIVATED(InactivityCause.DEACTIVATED),
        OVERRIDDEN(InactivityCause.OVERRIDDEN);
        
        private InactivityCause _cause;
        private Type(InactivityCause cause)
        {
            _cause = cause;
        }
        InactivityCause getInactivityCause()
        {
            return _cause;
        }
    }
    
    private Type _type;
    private String _featureId;
    
    IncomingDeactivation(Type type, String featureId)
    {
        _type = type;
        _featureId = featureId;
    }
    
    static boolean containsAny(List<String> includedFeatures, Collection<IncomingDeactivation> deactivatedBy)
    {
        if (deactivatedBy == null)
        {
            return false;
        }
        Collection<String> deactivatedByIds = deactivatedBy.stream()
                .map(IncomingDeactivation::getFeatureId)
                .collect(Collectors.toList());
        return CollectionUtils.containsAny(includedFeatures, deactivatedByIds);
    }
    
    static Collection<IncomingDeactivation> intersection(List<String> includedFeatures, Collection<IncomingDeactivation> deactivatedBy)
    {
        return deactivatedBy.stream()
                .filter(incomingDeactivation -> includedFeatures.contains(incomingDeactivation.getFeatureId()))
                .collect(Collectors.toList());
    }

    Type getType()
    {
        return _type;
    }

    String getFeatureId()
    {
        return _featureId;
    }
    
    @Override
    public String toString()
    {
        return String.format("IncomingDeactivation(%s, %s)", _featureId, _type.name());
    }
}
