/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugin.component;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

/**
 * Just like a {@link Serviceable}, a DeferredServiceable is a component that need to connect to other components. <br>
 * Unlike a standard {@link Serviceable}, which {@link Serviceable#service(ServiceManager)} method is called during component initialization,
 * the {@link #deferredService(ServiceManager)} method of a DeferredServiceable is called *after* component initialization.<br>
 * The drawback is that it cannot use other components during initialization.<br>
 * This interface is mainly used to avoid circular dependencies during initialization.
 */
public interface DeferredServiceable
{
    /**
     * Pass the {@link ServiceManager} used to access other components.
     * @param manager The {@link ServiceManager} which this {@link DeferredServiceable} uses. Must not be <code>null</code>.
     * @throws ServiceException if an error occurs
     */
    public void deferredService(ServiceManager manager) throws ServiceException;
}
