/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugin.component;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.service.ServiceManager;
import org.slf4j.Logger;

import org.ametys.runtime.plugin.ExtensionPoint;

/**
 * Component manager used to initialize extensions to extension points subclassing {@link AbstractThreadSafeComponentExtensionPoint}.
 * @param <T> The type of handled extensions
 */
public class ExtensionPointComponentManager<T> extends ThreadSafeComponentManager<T>
{
    private ExtensionPoint<T> _point;
    
    /**
     * Constructor.
     * @param point the parent {@link ExtensionPoint}.
     */
    public ExtensionPointComponentManager(ExtensionPoint<T> point)
    {
        super(true);
        _point = point;
    }
    
    @Override
    ComponentFactory getComponentFactory(String pluginName, String featureName, String role, Class<? extends T> componentClass, Configuration configuration)
    {
        return new ExtensionFactory(pluginName, featureName, role, componentClass, configuration, _manager, getLogger());
    }
    
    class ExtensionFactory extends ComponentFactory
    {
        ExtensionFactory(String pluginName, String featureName, String role, Class<? extends T> componentClass, Configuration configuration, ServiceManager serviceManager, Logger logger)
        {
            super(pluginName, featureName, role, componentClass, configuration, serviceManager, logger);
        }
        
        @Override
        T instanciate() throws Exception
        {
            T object = super.instanciate();
            
            if (object instanceof ExtensionPointAware)
            {
                ((ExtensionPointAware) object).setExtensionPoint(_point);
            }
            
            return object;
        }
    }
}
