/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugins.admin.configuration;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.core.cocoon.JSonReader;
import org.ametys.core.util.I18nUtils;
import org.ametys.runtime.config.Config;
import org.ametys.runtime.config.ConfigManager;
import org.ametys.runtime.model.DefinitionContext;
import org.ametys.runtime.model.View;

/**
 * Get the configuration model with current values of configuration
 */
public class GetConfigAction extends ServiceableAction
{
    private I18nUtils _i18nUtils;
    private View _view; 
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        _i18nUtils = (I18nUtils) smanager.lookup(I18nUtils.ROLE);
    }

    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        if (_view == null)
        {
            _view = ConfigManager.getInstance().getView(_i18nUtils);
        }
        
        Map<String, Object> jsonObject = new HashMap<>();
        jsonObject.put("configuration", _view.toJSON(DefinitionContext.newInstance().withEdition(true)));
        jsonObject.put("configuration-values", Collections.singletonMap("values", Config.getValuesAsJSONForClient()));
        
        request.setAttribute(JSonReader.OBJECT_TO_READ, jsonObject);

        return EMPTY_MAP;
    }
}
