/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.runtime.plugins.admin.jvmstatus.monitoring.sample;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.rrd4j.DsType;
import org.rrd4j.core.RrdDef;
import org.rrd4j.core.Sample;

import org.ametys.core.cache.AbstractCacheManager;
import org.ametys.core.cache.Cache;
import org.ametys.runtime.plugins.admin.jvmstatus.monitoring.SampleManager;

/**
 * {@link SampleManager} for collecting the throughput and the number of active
 * HTTP requests .
 */
public class CacheSampleManager extends AbstractSampleManager implements Serviceable
{

    private AbstractCacheManager _cacheManager;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _cacheManager = (AbstractCacheManager) manager.lookup(AbstractCacheManager.ROLE);
    }

    @Override
    protected void _configureDatasources(RrdDef rrdDef)
    {
        _registerDatasources(rrdDef, "total", DsType.GAUGE, 0, Double.NaN);
    }

    @Override
    protected Map<String, Object> _internalCollect(Sample sample) throws IOException
    {
        try
        {
            long sum = _cacheManager.getAllCaches()
                    .values()
                    .stream()
                    .flatMap(List::stream)
                    .filter(Cache::isComputableSize)
                    .mapToLong(Cache::getMemorySize)
                    .sum();
            float value = sum / (1024f * 1024f);
            
            sample.setValue("total", value);
            
            Map<String, Object> result = new HashMap<>();
            result.put("total", value);
            return result;
        }
        catch (RuntimeException e)
        {
            throw new IOException(e);
        }
    }

    @Override
    protected String _getGraphTitle()
    {
        return "Cache";
    }
}
