/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugins.admin.jvmstatus.monitoring.sample;

import java.io.IOException;
import java.lang.management.ManagementFactory;
import java.lang.management.ThreadMXBean;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.rrd4j.DsType;
import org.rrd4j.core.RrdDef;
import org.rrd4j.core.Sample;

import org.ametys.runtime.plugins.admin.jvmstatus.monitoring.SampleManager;
import org.ametys.runtime.plugins.admin.jvmstatus.monitoring.alerts.AbstractAlertSampleManager;
import org.ametys.runtime.plugins.admin.jvmstatus.monitoring.alerts.AlertSampleManager.Threshold.Operator;

/**
 * {@link SampleManager} for collecting the number of live threads.
 */
public class ThreadSampleManager extends AbstractAlertSampleManager
{
    @Override
    protected void _configureDatasources(RrdDef rrdDef)
    {
        _registerDatasources(rrdDef, "daemon", DsType.GAUGE, 0, Double.NaN);
        _registerDatasources(rrdDef, "total", DsType.GAUGE, 0, Double.NaN);
    }

    @Override
    protected Map<String, Object> _internalCollect(Sample sample) throws IOException
    {
        Map<String, Object> result = new HashMap<>();
        ThreadMXBean threadMXBean = ManagementFactory.getThreadMXBean();

        int daemon = threadMXBean.getDaemonThreadCount();
        sample.setValue("daemon", daemon);
        result.put("daemon", daemon);
        
        int total = threadMXBean.getThreadCount();
        sample.setValue("total", total);
        result.put("total", total);
        
        return result;
    }

    @Override
    protected String _getGraphTitle()
    {
        return "Live thread";
    }

    @Override
    protected Map<String, String> getThresholdConfigNames()
    {
        return Collections.singletonMap("total", "runtime.system.alerts.threads.threshold");
    }
    
    @Override
    protected Map<String, Operator> getOperators()
    {
        return Collections.singletonMap("total", Operator.GEQ);
    }
}
