/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugins.admin.migration;

import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.activity.Initializable;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.core.ObservationConstants;
import org.ametys.core.observation.Event;
import org.ametys.core.observation.ObservationManager;
import org.ametys.core.observation.Observer;
import org.ametys.runtime.plugins.admin.notificator.AbstractConfigurableAdministratorNotificator;
import org.ametys.runtime.plugins.admin.notificator.Notification;

/**
 * Notify when migration is not completed correctly
 */
public class MigrationAdministratorNotificator extends AbstractConfigurableAdministratorNotificator implements Observer, Initializable, Serviceable
{
    private ObservationManager _observationManager;
    private boolean _migrationDone;

    public List<Notification> getNotifications()
    {
        if (_migrationDone)
        {
            return List.of();
        }
        else
        {
            return List.of(new Notification(_type, _title, _message, _iconGlyph, _action));
        }
    }

    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.EVENT_MIGRATION_ENDED);
    }

    public int getPriority(Event event)
    {
        return 0;
    }

    public void observe(Event event, Map<String, Object> transientVars) throws Exception
    {
        _migrationDone = true;
    }

    public void initialize() throws Exception
    {
        _observationManager.registerObserver(this);
    }

    public void service(ServiceManager manager) throws ServiceException
    {
        _observationManager = (ObservationManager) manager.lookup(ObservationManager.ROLE);
    }
}
