/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.runtime.plugins.admin.migration;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.core.migration.MigrationEngine;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * The migration status buttton 
 */
public class MigrationsStatusClientSideElement extends StaticClientSideElement
{
    private MigrationEngine _migrationEngine;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _migrationEngine = (MigrationEngine) smanager.lookup(MigrationEngine.ROLE);
    }
    
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        List<Script> modifiedScripts = new ArrayList<>();
        
        for (Script script : scripts)
        {
            Script modifiedScript = new Script(script);
            modifiedScripts.add(modifiedScript);
            
            if (_migrationEngine.getFailedException() != null)
            {
                modifiedScript.getParameters().put("description", modifiedScript.getParameters().get("description-error"));
                modifiedScript.getParameters().put("icon-decorator-type", "state-error");
            }
            else
            {
                modifiedScript.getParameters().put("description", modifiedScript.getParameters().get("description-ok"));
                modifiedScript.getParameters().put("icon-decorator-type", "state-ok");
            }
        }
        
        return modifiedScripts;
    }
}
