/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugins.admin.statistics;

import java.util.Map;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * Statistics parent interface 
 */
public interface Statistics
{
    /**
     * The node identifier
     * @return an identifier
     */
    public String getName();
    
    /**
     * The node label
     * @return label
     */
    public I18nizableText getLabel();
    
    /**
     * The icon
     * @return The glyph icon
     */
    public String getIcon();
    
    /**
     * Get the json for the statistics export
     * @return A non null json
     */
    public Map<String, Object> toJSONForExport();

    /**
     * Get the json for the client tree
     * @return A non null json for tree
     */
    public Map<String, Object> toJSONTree();
}
