/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugins.admin.statistics;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * A node in the statistics tree 
 */
public class StatisticsNode extends StatisticsValue
{
    private List<Statistics> _children;
    private boolean _expanded;

    /**
     * Create a node
     * @param name The identifier of the node
     * @param label The label
     * @param icon The glyph icon
     * @param value A jsonizable value. Can be null.
     * @param children The children
     * @param expanded Is the tree expanded by default
     */
    public StatisticsNode(String name, I18nizableText label, String icon, Object value, List<Statistics> children, boolean expanded)
    {
        super(name, label, icon, value);
        _children = children;
        _expanded = expanded;
    }

    /**
     * The children of the node
     * @return the children
     */
    public List<Statistics> getChildren()
    {
        return _children;
    }
    
    @Override
    public Map<String, Object> toJSONForExport()
    {
        Map<String, Object> children = new LinkedHashMap<>();
        for (Statistics statistics : _children)
        {
            children.putAll(statistics.toJSONForExport());
        }
        
        children.put("_value", getValue());
        
        return Map.of(
            getName(), 
            children
        );
    }
    
    @Override
    public Map<String, Object> toJSONTree()
    {
        Map<String, Object> jsonTree = super.toJSONTree();
        jsonTree.put("leaf", false);
        jsonTree.put("expanded", _expanded);
        jsonTree.put("children", _children.stream().map(Statistics::toJSONTree).toList());
        return jsonTree;
    }
}
