/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugins.admin.statistics;

import java.util.HashMap;
import java.util.Map;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * A terminal node in statistics 
 */
public class StatisticsValue implements Statistics
{
    private Object _value;
    private String _name;
    private I18nizableText _label;
    private String _icon;

    /**
     * Create a value
     * @param name The identifier of the node
     * @param label The label
     * @param icon The glyph icon 
     * @param value A jsonizable value. Can be null.
     */
    public StatisticsValue(String name, I18nizableText label, String icon, Object value)
    {
        _name = name;
        _label = label;
        _icon = icon;
        _value = value;
    }
    
    public String getName()
    {
        return _name;
    }
    
    public I18nizableText getLabel()
    {
        return _label;
    }
    
    public String getIcon()
    {
        return _icon;
    }
    
    /**
     * The wrapped value
     * @return the nullable and jsonizable value
     */
    public Object getValue()
    {
        return _value;
    }
    
    public Map<String, Object> toJSONForExport()
    {
        Map<String, Object> m = new HashMap<>();
        m.put(_name, _value);
        return m;
    }
    
    public Map<String, Object> toJSONTree()
    {
        Map<String, Object> m = new HashMap<>();
        m.put("name", _name);
        m.put("label", _label.isI18n() ? StatisticsProviderExtensionPoint._I18N_PREFIX + _label.getCatalogue() + StatisticsProviderExtensionPoint._I18N_SEPARATOR + _label.getKey() + StatisticsProviderExtensionPoint._I18N_SUFFIX : _label.getLabel());
        m.put("iconCls", _icon);
        m.put("value", _value);
        m.put("leaf", true);
        return m;
    }
}
