/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.authentication;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.cocoon.reading.AbstractReader;
import org.xml.sax.SAXException;

import org.ametys.plugins.core.authentication.MultifactorAuthenticationManager;

import dev.samstevens.totp.exceptions.QrGenerationException;
import dev.samstevens.totp.qr.QrData;
import dev.samstevens.totp.qr.QrGenerator;
import dev.samstevens.totp.qr.ZxingPngQrGenerator;

/**
 * Read the generated QrCode for multifactor authentication
 * This QrCode can be used to give the secret to an authentication application
 */
public class MultifactorAuthenticationQrCodeReader extends AbstractReader implements Serviceable
{
    private MultifactorAuthenticationManager _multifactorAuthenticationManager;
    private QrGenerator _qrGenerator;

    public void service(ServiceManager manager) throws ServiceException
    {
        _multifactorAuthenticationManager = (MultifactorAuthenticationManager) manager.lookup(MultifactorAuthenticationManager.ROLE);
    }

    @Override
    public void setup(SourceResolver sourceResolver, Map sourceObjectModel, String src, Parameters par) throws ProcessingException, SAXException, IOException
    {
        super.setup(sourceResolver, sourceObjectModel, src, par);
        _qrGenerator = new ZxingPngQrGenerator();
    }
    
    @Override
    public void recycle()
    {
        super.recycle();
        _qrGenerator = null;
    }
    
    public void generate() throws IOException, SAXException, ProcessingException
    {
        try
        {
            QrData data = _multifactorAuthenticationManager.getCurrentUserQrData();
            byte[] imageData;
            imageData = _qrGenerator.generate(data);
            out.write(imageData);
        }
        catch (QrGenerationException e)
        {
            throw new ProcessingException(e);
        }
    }

    @Override
    public String getMimeType()
    {
        return _qrGenerator.getImageMimeType();
    }
    
    @Override
    public boolean shouldSetContentLength()
    {
        return false;
    }
}
