/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.cache;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * AbstractCacheKey Class used to create cache keys as tuples
 */
public abstract class AbstractCacheKey
{

    private List< ? super Object> _fields;

    private boolean _isPartialKey;

    /** 
     * AbstractCacheKey
     * @param fields list of fields in the key
     */
    protected AbstractCacheKey(Object... fields)
    {
        _fields = new ArrayList<>();
        for (Object field : fields)
        {
            if (field == null)
            {
                _isPartialKey = true;
            }
            _fields.add(field);
        }
    }

    /** 
     * true if one of fields is null
     * @return true if the key is used for mass invalidation
     */
    public boolean isPartialKey()
    {
        return _isPartialKey;
    }

    /** 
     * get list of fields
     * @return the list of fields
     */
    public List< ? super Object> getFields()
    {
        return _fields;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(_fields);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        if (obj == null)
        {
            return false;
        }
        if (getClass() != obj.getClass())
        {
            return false;
        }
        AbstractCacheKey other = (AbstractCacheKey) obj;
        return Objects.equals(_fields, other._fields);
    }
    
    @Override
    public String toString()
    {
        return _fields.toString(); // will print '[field1Value, field2Value, ...]'
    }

}
