/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.cache;

import java.time.Duration;

import org.ametys.core.cache.AbstractCacheManager;
import org.ametys.core.cache.Cache;
import org.ametys.core.util.SizeUtils;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * Implementation of AbstractCacheManager to create new Cache using GuavaCache implementation
 */
public class GuavaCacheManager extends AbstractCacheManager
{
    /** Is size computable on this configuration */
    protected boolean _canComputeSize;
    
    @Override
    public void initialize() throws Exception
    {
        super.initialize();
        
        _canComputeSize = SizeUtils.enabled();
        
        if (!_canComputeSize)
        {
            getLogger().warn("JOL is not supported for this JVM. Caches sizes won't be computed.");
        }
    }
    
    @SuppressWarnings("unchecked")
    @Override
    protected Cache _createCache(String id, I18nizableText name, I18nizableText description, boolean computableSize, Duration duration, boolean isDispatchable)
    {
        return new GuavaCache(id, name, description, Long.MAX_VALUE, _canComputeSize && computableSize, duration, isDispatchable);
    }
}
