/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.plugins.core.impl.cache;

import org.ametys.core.cache.CacheStats;

/**
 * Guava implementation of CacheStats
 */
public class GuavaCacheStats implements CacheStats
{
    private com.google.common.cache.CacheStats _cacheStats;

    /**
     * GuavaCacheStats implementation of CacheStats
     */
    public GuavaCacheStats()
    {
        this._cacheStats = new com.google.common.cache.CacheStats(0, 0, 0, 0, 0, 0);
    }
    
    /**
     * GuavaCacheStats implementation of CacheStats
     * @param cacheStats stats of Guava cache
     */
    public GuavaCacheStats(com.google.common.cache.CacheStats cacheStats)
    {
        this._cacheStats = cacheStats;
    }

    public long requestCount()
    {
        return _cacheStats.requestCount();
    }

    public long hitCount()
    {
        return _cacheStats.hitCount();
    }
    
    public double hitRate()
    {
        return _cacheStats.hitRate();
    }

    public long missCount()
    {
        return _cacheStats.missCount();
    }

    public double missRate()
    {
        return _cacheStats.missRate();
    }

    public long evictionCount()
    {
        return _cacheStats.evictionCount();
    }

    public double evictionRate()
    {
        long requestCount = requestCount();
        return (requestCount == 0) ? 0.0 : (double) evictionCount() / requestCount;
    }

    public CacheStats minus(CacheStats cacheStats)
    {
        com.google.common.cache.CacheStats guavaCacheStats = new com.google.common.cache.CacheStats(cacheStats.hitCount(), cacheStats.missCount(), cacheStats.missCount(), 0, 0, cacheStats.evictionCount());
        return new GuavaCacheStats(_cacheStats.minus(guavaCacheStats)); 
    }

    public CacheStats plus(CacheStats cacheStats)
    {
        com.google.common.cache.CacheStats guavaCacheStats = new com.google.common.cache.CacheStats(cacheStats.hitCount(), cacheStats.missCount(), cacheStats.missCount(), 0, 0, cacheStats.evictionCount());
        return new GuavaCacheStats(_cacheStats.plus(guavaCacheStats)); 
    }
}
