/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.captcha.jcaptcha;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.core.captcha.CaptchaHelper;
import org.ametys.plugins.core.impl.schedule.ConfigBasedEveryNMinutesRunnable;

/**
 * Runnable to clean JCaptcha saved into the {@link CaptchaHelper} every N minutes. It is only activated when JCaptcha is selected in the configuration.
 */
public class CleanJCaptchaRunnable extends ConfigBasedEveryNMinutesRunnable
{
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        // Look up to ensure that the component is instantiated before we use it
        manager.lookup(CaptchaHelper.ROLE);
    }
    
    @Override
    protected boolean isEnabled(Configuration configuration)
    {
        return "jcaptcha".equals(CaptchaHelper.getCaptchaType());
    }
}
