/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.captcha.jcaptcha;

import org.quartz.JobExecutionContext;

import org.ametys.core.captcha.Captcha;
import org.ametys.core.captcha.CaptchaHelper;
import org.ametys.core.schedule.Schedulable;
import org.ametys.core.schedule.progression.ContainerProgressionTracker;
import org.ametys.plugins.core.impl.schedule.AbstractStaticSchedulable;

/**
 * A {@link Schedulable} job for cleaning JCaptcha saved into the {@link CaptchaHelper}.
 */
public class CleanJCaptchaSchedulable extends AbstractStaticSchedulable
{
    @Override
    public void execute(JobExecutionContext context, ContainerProgressionTracker progressionTracker) throws Exception
    {

        Captcha captcha = CaptchaHelper.getCaptcha();
        
        if (captcha instanceof JCaptcha)
        {
            JCaptcha jCaptcha = (JCaptcha) captcha;
            jCaptcha.cleanOldCaptchas();

        }
        else
        {
            throw new RuntimeException("This schedulable can only work if jcaptcha is enabled");
        }
    }
}
