/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.datasource;

import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.Map;

import org.ametys.core.datasource.AbstractDataSourceManager.DataSourceDefinition;
import org.ametys.core.datasource.SQLDataSourceManager;

/**
 * Specifically handle Derby connections, allowing to actually shut the database down;
 */
public class DerbySQLDatabaseType extends StaticSQLDatabaseType
{
    private static final String __DERBY_SHUTDOWN_SUFFIX = ";shutdown=true";
    
    /**
     * Shut down a derby database.<br>
     * This method is static because often called during dispose() process.
     * @param definition the corresponding {@link DataSourceDefinition}.
     */
    public static void shutDown(DataSourceDefinition definition)
    {
        Map<String, Object> parameters = definition.getParameters();
        String url = (String) parameters.get(SQLDataSourceManager.PARAM_DATABASE_URL);
        int i = url.indexOf(';');
        url = i == -1 ? url + __DERBY_SHUTDOWN_SUFFIX : url.substring(0, i) + __DERBY_SHUTDOWN_SUFFIX;
        
        try
        {
            DriverManager.getConnection(url).close();
        }
        catch (SQLException e)
        {
            // Derby "normal" shutdown exception
        }
    }
}
