/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.datasource;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

/**
 * Specifically handle Derby connections, allowing to actually shut the database down;
 */
public class PostgreSQLDatabaseType extends StaticSQLDatabaseType
{
    @Override
    public InputStream getBlob(ResultSet resultSet, String columnName) throws SQLException
    {
        return resultSet.getBinaryStream(columnName);
    }
    @Override
    public InputStream getBlob(ResultSet resultSet, int pos) throws SQLException
    {
        return resultSet.getBinaryStream(pos);
    }
    
    @Override
    public void setBlob(PreparedStatement statement, int pos, String blob) throws SQLException, UnsupportedEncodingException
    {
        if (blob == null)
        {
            statement.setNull(pos, Types.BINARY);
        }
        else
        {
            byte[] bytes = blob.getBytes("UTF-8");
            setBlob(statement, pos, bytes);
        }
    }
    
    @Override
    public void setBlob(PreparedStatement statement, int pos, byte[] bytes) throws SQLException
    {
        if (bytes == null)
        {
            statement.setNull(pos, Types.BINARY);
        }
        else
        {
            ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bytes);
            setBlob(statement, pos, byteArrayInputStream,  bytes.length);
        }
    }
    
    @Override
    public void setBlob(PreparedStatement statement, int pos, InputStream is, long length) throws SQLException
    {
        if (is == null)
        {
            statement.setNull(pos, Types.BINARY);
        }
        else
        {
            statement.setBinaryStream(pos, is, length);
        }
    }
}
