/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.model.type.xml;

import java.util.ArrayList;
import java.util.List;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.commons.lang3.StringUtils;

import org.ametys.core.model.type.AbstractStringElementType;
import org.ametys.runtime.model.type.xml.XMLElementType;

/**
 * Class for string XML element type
 */
public class StringXMLElementType extends AbstractStringElementType implements XMLElementType<String>
{
    /**
     * {@inheritDoc}}
     * The value is a string, so the default value is an empty string if it can not be read
     */
    @Override
    public Object readValueFromNode(Configuration elementConfiguration) throws ConfigurationException
    {
        if (elementConfiguration == null)
        {
            return null;
        }
        
        // Multiple element management
        Configuration[] valuesConfiguration = elementConfiguration.getChildren("value");
        if (valuesConfiguration.length > 0)
        {
            List<String> values = new ArrayList<>();
            for (Configuration valueConfiguration : valuesConfiguration)
            {
                String value = StringUtils.defaultString(parseConfiguration(valueConfiguration));
                values.add(value);
            }
            return values.toArray(String[]::new);
        }
        else
        {
            // Simple element management
            return StringUtils.defaultString(parseConfiguration(elementConfiguration));
        }
    }
}
