/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.right;

import java.util.Set;

import org.ametys.core.right.AccessController;

/**
 * Abstract {@link AccessController} for a hierarchical type of object. This implementation of hierarchical access controller ignores its permission context.
 * @param <T> The class of a supported object, from which you can retrieve its parent with {@link #_getParents(Object)}
 */
public abstract class AbstractHierarchicalAccessController<T> extends AbstractHierarchicalWithPermissionContextAccessController<T, T>
{
    /**
     * Gets the parents of the object. Must return null when the object is the "root" (where "root" means here the root of the hierarchy of the access controller)
     * @param object The object
     * @return the parents of the object, or null if the object is the "root" of the hierarchy
     */
    protected abstract Set<T> _getParents(T object);
    
    @Override
    protected Set<T> _getParents(T object, T permissionCtx)
    {
        return _getParents(object);
    }
}
