/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.right;

import java.util.HashSet;
import java.util.Set;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.core.right.RightContextConvertor;

/**
 * This RightContextConvertor is just an hardcoded translation from a configured string to another configured string
 */
public class StringRightContextConvertor implements RightContextConvertor, Configurable
{
    /** The context to remove */
    protected String _contextToRemove;
    /** The context to replace with */
    protected String _contextToReplaceWith;
    
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _contextToRemove = "/" + configuration.getChild("context-to-remove").getValue();
        _contextToReplaceWith = "/" + configuration.getChild("context-to-replace-with").getValue();
    }
    
    public Set<Object> convert(Object object)
    {
        Set<Object> objects = new HashSet<>();
        
        if (object instanceof String)
        {
            String context = (String) object;
            
            if (context.equals(_contextToRemove))
            {
                objects.add(_contextToReplaceWith);
            }
            else if (context.startsWith(_contextToRemove + "/"))
            {
                objects.add(_contextToRemove + context.substring(_contextToReplaceWith.length()));
            }
        }
        
        return objects;
    }
}
