/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.right;

import java.util.HashSet;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.commons.collections.CollectionUtils;

import org.ametys.core.right.AccessController;
import org.ametys.runtime.workspace.WorkspaceManager;

/**
 * {@link AccessController} for a workspace context objects (strings starting with "/" + workspace name).
 */
public class WorkspaceAccessController extends StringHierarchicalAccessController implements Contextualizable
{
    /** The avalon context */
    protected Context _context;
    
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        // Do not "super.configure"
    }
    
    @Override
    protected Set<String> getRootPrefixes()
    {
        return WorkspaceManager.getInstance().getWorkspaceNames().stream().map(name -> "/" + name).collect(Collectors.toSet());
    }
    
    @Override
    protected Set<String> getSupportedPrefixes()
    {
        return getRootPrefixes();
    }
    
    @SuppressWarnings("unchecked")
    @Override
    protected Set< ? extends Object> _convertWorkspaceToRootRightContexts(Set<Object> workspacesContexts)
    {
        Set<String> rootPrefixes = getRootPrefixes();
        return workspacesContexts != null && rootPrefixes != null ? new HashSet<>(CollectionUtils.intersection(workspacesContexts, rootPrefixes))
                                                                  : null;
    }
}
