/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.right;

import java.util.HashSet;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.commons.lang3.StringUtils;

import org.ametys.core.right.RightContextConvertor;
import org.ametys.runtime.plugin.ExtensionPoint;
import org.ametys.runtime.plugin.component.ExtensionPointAware;
import org.ametys.runtime.workspace.WorkspaceMatcher;

/**
 * Covnert /${WorkspaceName} to the name of the current workspace and recursiverly relaunch the convertors
 */
public class WorkspaceRightContextConvertor implements RightContextConvertor, Contextualizable, ExtensionPointAware
{
    /** The avalon context */
    protected Context _context;
    
    /** The extension point for the Right Context Convertors */
    protected ExtensionPoint<RightContextConvertor> _rightContextConvertorEP;
    
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    public void setExtensionPoint(ExtensionPoint point)
    {
        _rightContextConvertorEP = point;
    }
    
    public Set<Object> convert(Object object)
    {
        Set<Object> objects = new HashSet<>();
        
        if (object instanceof String)
        {
            String context = (String) object;
            if (context.indexOf("${WorkspaceName}") != -1)
            {
                Request request = ContextHelper.getRequest(_context);
                String currentWorkspace = (String) request.getAttribute(WorkspaceMatcher.WORKSPACE_NAME);
                if (StringUtils.isBlank(currentWorkspace))
                {
                    // When comming from schedulable for example... lets use the most restrictive cas
                    currentWorkspace = "admin";
                }
                
                String resolvedContext = StringUtils.replace(context, "${WorkspaceName}", currentWorkspace);
                
                objects.addAll(_rightContextConvertorEP.getExtensionsIds()
                                                       .stream()
                                                       .map(_rightContextConvertorEP::getExtension)
                                                       .flatMap(convertor -> convertor.convert(resolvedContext).stream())
                                                       .collect(Collectors.toSet()));
                
                objects.add(resolvedContext);
            }
        }
        
        return objects;
    }
}
