/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.right;

import java.util.Collections;
import java.util.Set;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.commons.lang3.StringUtils;

import org.ametys.runtime.workspace.WorkspaceMatcher;

/**
 * Act as the WorksapceAccessController but also have a configured switching value when converting the variable ${WorkspaceName}. Such as 'repository' =&gt; 'admin'. 
 */
public class WorkspaceSwitchedAccessController extends WorkspaceAccessController
{
    /** The workspace to react on */
    protected String _workspaceToMatch;
    /** The workspace to replace with */
    protected String _workspaceToReplaceWith;

    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        super.configure(configuration);
        _workspaceToMatch = configuration.getChild("workspace-to-match").getValue();
        _workspaceToReplaceWith = configuration.getChild("workspace-to-replace-with").getValue();
    }
    
    @Override
    protected Set<String> getRootPrefixes()
    {
        Request request = ContextHelper.getRequest(_context);
        String workspaceName = (String) request.getAttribute(WorkspaceMatcher.WORKSPACE_NAME);
        if (StringUtils.equals(_workspaceToMatch, workspaceName))
        {
            return Collections.singleton(SEPARATOR + _workspaceToReplaceWith);
        }
        else
        {
            return null;
        }
    }
    
    @Override
    protected Set<String> getSupportedPrefixes()
    {
        return getRootPrefixes();
    }
}
