/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.schedule;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.configuration.DefaultConfiguration;

import org.ametys.runtime.config.Config;

/**
 * A {@link Runnable} is launched every N minutes where N is defined by the config parameter defined into param-period.
 */
public class ConfigBasedEveryNMinutesRunnable extends ConfigBasedRunnable
{
    @Override
    protected void configureFireProcess(Configuration configuration, DefaultConfiguration modifiedConfiguration) throws ConfigurationException
    {
        Configuration periodCfg = configuration.getChild("param-period", false);
        if (periodCfg != null)
        {
            String periodParamName = periodCfg.getValue("").trim();
            Long periodCfgValue = Config.getInstance().getValue(periodParamName);
            
            // If the value is 60, it's mean that it should be executed each hour, then we force minutes to 0
            if (periodCfgValue == 60)
            {
                periodCfgValue = Long.valueOf(0);
            }
            
            // FireProcess = cron
            DefaultConfiguration fireProcessConfig = new DefaultConfiguration("fire-process");
            fireProcessConfig.setValue(FireProcess.CRON.name());
            modifiedConfiguration.addChild(fireProcessConfig);
            
            String cronExpression = "0 0/" + periodCfgValue + " * * * ?";
            
            DefaultConfiguration cronConfig = new DefaultConfiguration("cron");
            cronConfig.setValue(cronExpression);
            modifiedConfiguration.addChild(cronConfig);
        }
        else
        {
            throw new ConfigurationException("Mandatory configuration 'param-period' is missing for config based every N minutes runnable " + this.getClass().getName());
        }
    }
}
