/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.schedule;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.configuration.DefaultConfiguration;

import org.ametys.runtime.config.Config;

/**
 * This {@link Runnable} is launched if enabled in config (by the param defined by param-enabled) or always launched if there is no param 'param-enabled'.
 */
public class ConfigBasedRunnable extends StaticRunnable
{

    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        DefaultConfiguration modifiedConfiguration = new DefaultConfiguration(configuration);
    
        if (isEnabled(configuration))
        {
            configureFireProcess(configuration, modifiedConfiguration);
        }
        else
        {
            // FireProcess = never
            DefaultConfiguration fireProcessConfig = new DefaultConfiguration("fire-process");
            fireProcessConfig.setValue(FireProcess.NEVER.name());
            modifiedConfiguration.addChild(fireProcessConfig);
        }
        
        // Call configure of StaticRunnable
        super.configure(modifiedConfiguration);
    }

    /**
     * Check if the Runnable should be enabled
     * @param configuration the configuration
     * @return true if the Runnable is enabled
     */
    protected boolean isEnabled(Configuration configuration)
    {
        Configuration enabledCfg = configuration.getChild("param-enabled", false);
        if (enabledCfg != null)
        {
            return Config.getInstance().getValue(enabledCfg.getValue("").trim());
        }
        else
        {
            return true;
        }
    }
    
    /**
     * Edit the runnable configuration based on the {@link Config}
     * @param configuration the original configuration
     * @param modifiedConfiguration the edited configuration
     * @throws ConfigurationException if configuration is invalid
     */
    protected void configureFireProcess(Configuration configuration, DefaultConfiguration modifiedConfiguration) throws ConfigurationException
    {
        // StaticRunnable default implementation will look for a fire-process and cron child
    }
}
