/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.schedule;

import java.time.LocalTime;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.runtime.config.Config;

/**
 * A {@link Runnable} is launched if enabled in config (by the param defined by param-enabled)
 * Will run every week at the specified day in config (by the param defined by param-dayofweek)
 */
public class ConfigBasedWeeklyRunnable extends AbstractConfigBasedHourRunnable
{
    @Override
    protected String getCronExpression(Configuration configuration, LocalTime time) throws ConfigurationException
    {
        Configuration dayCfg = configuration.getChild("param-dayofweek", false);
        if (dayCfg != null)
        {
            Long dayCfgValue = Config.getInstance().getValue(dayCfg.getValue("").trim());
            return "0 " /*seconds*/ 
                    + time.getMinute() /*minutes*/ 
                    + " " + time.getHour() /*hour*/ 
                    + " ? * " /* no restriction on day of month nor month */
                    + (dayCfgValue % 7 + 1) /* day of the week (SUN=1,MON=2,TUE=3,... in cron expression) */ 
                    + " * " /* on every year*/;
        }
        else
        {
            throw new ConfigurationException("Mandatory configuration 'param-dayofweek' is missing for config based weekly runnable " + this.getClass().getName());
        }
        
    }
}
