/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.user;

import org.ametys.core.user.UserIdentity;
import org.ametys.plugins.core.impl.user.directory.LdapUserDirectory;

/**
 * {@link UserIdentity} of a user in a {@link LdapUserDirectory}. It contains the DN of the user
 */
public class LdapUserIdentity extends UserIdentity
{
    /** The DN of the user */
    protected String _dn;

    /**
     * Constructs a LDAP user identity, containing the DN of the user
     * @param login The login of the user
     * @param populationId The id of the user population the user belongs to
     * @param dn The DN of the user in the LDAP
     */
    public LdapUserIdentity(String login, String populationId, String dn)
    {
        super(login, populationId);
        _dn = dn;
    }
    
    /**
     * Gets the DN of the user in the {@link LdapUserDirectory}
     * @return the DN of the user
     */
    public String getDn()
    {
        return _dn;
    }
    
    @Override
    public String toString()
    {
        return "LdapUserIdentity [login=" + getLogin() + ", population=" + getPopulationId() + ", DN='" + _dn + "']";
    }
}
