/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Field displaying a combobox allowing to select one of the values from a given enumerator.
 * 
 * Enumeration are already supported by the "Ametys.form.widget.ComboBox".
 * This widget is only relevant for config element definition that require access
 * to the service manager in order to enumerate their entries
 */
Ext.define('Ametys.form.widget.EnumeratorCombobox', {
    extend: "Ametys.form.widget.ComboBox",
    
    getStoreCfg: function(config)
    {
        return {
            proxy: {
                type: 'ametys',
                role: 'org.ametys.plugins.core.ui.util.ParameterEnumeratorHelper',
                methodName: 'getTypedEntries',
                methodArguments: ['role'],
                reader: {
                    type: 'json',
                    rootProperty: "data"
                }
            },
            autoLoad: true, 
            sorters: [{property: config.displayField, direction: 'ASC'}],
            listeners: {
                scope: this,
                'beforeload': function(store, operation)
                {
                    // Get the parameters, or create empty object if needed
                    var parameters = operation.getParams() || {};
                    // Add the enumerator role to the parameters
                    params = Ext.apply(parameters, {role: config["enumerator-role"]});
                    // Set the parameters
                    operation.setParams(parameters);
                }
            }
        };
    },
    
    constructor: function (config)
    {
        config = Ext.apply(config, {
            queryMode: 'local',
            valueField : 'id',
            displayField : 'label'
        });
        
        this.callParent(arguments);
    },
});
