/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Helper to create a grid with profiles as column
 * @private
 */
Ext.define('Ametys.plugins.coreui.profiles.ProfilesGridHelper', {
    statics: {
        /**
         * @readonly
         * @property {String} READER_PROFILE_ID The id of the special profile (READER profile)
         */
        READER_PROFILE_ID: 'READER',
        
        /**
         * Get the column definition based on a list of profiles
         * @param {Object[]} a list of object representing the profiles
         * @param {Function} a renderer to use for the profile columns
         * @param {Object} the scope for the renderer
         * @returns {Object[]} the columns definition
         */
        getProfilesColumns: function (profiles, renderer, scope)
        {
            var columns = [];
            Ext.Array.forEach(profiles, function(profile) {
                columns.push({
                    stateId: 'grid-profile-' + profile.id,
                    text: profile.label,
                    locked: profile.id == Ametys.plugins.coreui.profiles.ProfilesGridHelper.READER_PROFILE_ID ? true : null,
                    lockable: false,
                    tooltip: profile.label,
                    dataIndex: profile.id,
                    hideable: profile.id != Ametys.plugins.coreui.profiles.ProfilesGridHelper.READER_PROFILE_ID,
                    sortable: false,
                    align: 'center',
                    width: 115,
                    cls: profile.id == Ametys.plugins.coreui.profiles.ProfilesGridHelper.READER_PROFILE_ID ? 'a-column-header-reader' : '',
                    tdCls: profile.id == Ametys.plugins.coreui.profiles.ProfilesGridHelper.READER_PROFILE_ID ? 'a-grid-cell-reader' : '',
                    renderer: renderer,
                    scope: scope
                });
            }, this);
            
            // Reader first then all the profiles alphabetically sorted
            return columns.sort(function(a, b) {
                if (a.dataIndex == Ametys.plugins.coreui.profiles.ProfilesGridHelper.READER_PROFILE_ID)
                {
                    return -1;
                }
                else if (b.dataIndex == Ametys.plugins.coreui.profiles.ProfilesGridHelper.READER_PROFILE_ID)
                {
                    return 1;
                }
                else
                {
                    return Ext.data.SortTypes.asNonAccentedUCString(a.text) < Ext.data.SortTypes.asNonAccentedUCString(b.text) ? -1 : 1;
                }
            });
        }
    
    }
});
