/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.ui;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;

import org.ametys.core.schedule.AmetysJob;
import org.ametys.runtime.workspace.WorkspaceMatcher;

/**
 * This implementation creates an element for adding a new task
 */
public class AddTaskClientSideElement extends StaticClientSideElement implements Contextualizable
{
    /** The Avalon context */
    protected Context _context;
    
    @Override
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }

    @Override
    protected String _configureClass(Configuration configuration) throws ConfigurationException
    {
        return "Ametys.plugins.coreui.schedule.AddTaskButtonController";
    }
    
    @SuppressWarnings("unchecked")
    @Override
    protected Map<String, Object> configureInitialParameters(Configuration configuration) throws ConfigurationException
    {
        Map<String, Object> initialParameters = super.configureInitialParameters(configuration);
        
        initialParameters.put("action", _configureClass(configuration) + ".act");
        
        // Always have at least the log category 'org.ametys.plugins.core.schedule.Scheduler', 
        // because in case of error in AmetysJob during the execution of the Schedulable, it will log in that category
        List<String> logCategories = new ArrayList<>();
        String jobLogCategory = AmetysJob.class.getName() + "$" + initialParameters.get("schedulable");
        logCategories.add(jobLogCategory);
        if (initialParameters.containsKey("log-category"))
        {
            Object initialLogCategory = initialParameters.get("log-category");
            
            if (initialLogCategory instanceof String)
            {
                logCategories.add((String) initialLogCategory);
            }
            else if (initialLogCategory instanceof List)
            {
                logCategories.addAll((List<String>) initialLogCategory);
            }
        }
        initialParameters.put("log-category", logCategories);
        
        return initialParameters;
    }
    
    @Override
    protected Script _configureScript(Configuration configuration) throws ConfigurationException
    {
        List<ScriptFile> scriptsImports = _configureImports(configuration.getChild("scripts"));
        scriptsImports.add(new ScriptFile("/plugins/core-ui/resources/js/Ametys/plugins/coreui/schedule/AddTaskButtonController.js"));
        List<ScriptFile> cssImports = _configureImports(configuration.getChild("css"));
        String jsClassName = _configureClass(configuration.getChild("class"));
        Map<String, Object> initialParameters = configureInitialParameters(configuration);
        
        return new Script(this.getId(), jsClassName, scriptsImports, cssImports, initialParameters);
    }
    
    @Override
    protected Map<String, List<String>> _configureDependencies(Configuration configuration) throws ConfigurationException
    {
        Map<String, List<String>> dependencies = super._configureDependencies(configuration);
        
        List<String> importDependencies = dependencies.computeIfAbsent("org.ametys.core.ui.StaticFileImportsManager", __ -> new ArrayList<>());
        importDependencies.add("org.ametys.core.schedule.Scheduler");

        List<String> uitoolsDependencies = dependencies.computeIfAbsent("org.ametys.core.ui.UIToolsFactoriesManager", __ -> new ArrayList<>());
        uitoolsDependencies.add("uitool-server-logs");
        
        return dependencies;
    }
    
    @Override
    public Map<String, List<String>> getDependencies()
    {
        // RUNTIME-2913 The task scheduler is opened in the CMS while using the AddTaskButtonController
        // Load the task scheduler only on admin context
        Request request = ContextHelper.getRequest(_context);
        String workspaceName = (String) request.getAttribute(WorkspaceMatcher.WORKSPACE_NAME);
        if ("admin".equals(workspaceName))
        {
            Map<String, List<String>> clonedDependencies = new HashMap<>(_dependencies);
            List<String> uitoolsDependencies = new ArrayList<>();
            if (clonedDependencies.containsKey("org.ametys.core.ui.UIToolsFactoriesManager"))
            {
                uitoolsDependencies.addAll(clonedDependencies.get("org.ametys.core.ui.UIToolsFactoriesManager"));
            }
            uitoolsDependencies.add("uitool-scheduled-tasks");
            clonedDependencies.put("org.ametys.core.ui.UIToolsFactoriesManager", uitoolsDependencies);
            return clonedDependencies;
        }
        return _dependencies;
    }
}
