/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.ui;

import java.util.Map;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

/**
 * This implementation creates an element for adding a new task with a schedulable parameter filled by the selected target.
 * Use schedulable-param-name to define the parameter to update.
 * By default, the sent value is the target id.
 */
public class SelectionAwareAddTaskClientSideElement extends AddTaskClientSideElement
{
    @Override
    protected String _configureClass(Configuration configuration) throws ConfigurationException
    {
        return "Ametys.plugins.coreui.schedule.SelectionAwareAddTaskButtonController";
    }
    
    @Override
    protected Map<String, Object> configureInitialParameters(Configuration configuration) throws ConfigurationException
    {
        Map<String, Object> initialParameters = super.configureInitialParameters(configuration);
        if (!initialParameters.containsKey("selection-enable-multiselection") && !initialParameters.containsKey("enable-multiselection"))
        {
            initialParameters.put("selection-enable-multiselection", "false");
        }
        return initialParameters;
    }
    
    @Override
    protected Script _configureScript(Configuration configuration) throws ConfigurationException
    {
        Script script = super._configureScript(configuration);
        script.getScriptFiles().add(new ScriptFile("/plugins/core-ui/resources/js/Ametys/plugins/coreui/schedule/SelectionAwareAddTaskButtonController.js"));
        return script;
    }
}
