/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.ui.right;

import java.util.List;
import java.util.Map;

import org.ametys.core.ui.ClientSideElementHelper;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * Override of static client side element to switch the label and description
 * depending on the user having the "Runtime_Rights_SeeUserRights" right on context
 */
public class ExplainUserRightButton extends StaticClientSideElement
{
    private static final String __MY_USER_DEFAULT_DESCRIPTION = "my-user-default-description";
    private static final String __ALL_USER_DEFAULT_DESCRIPTION = "all-user-default-description";
    private static final String __MY_USER_LABEL = "my-user-label";
    private static final String __ALL_USER_LABEL = "all-user-label";
    
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        if (scripts.isEmpty())
        {
            return scripts;
        }
        
        Script buttonScript = ClientSideElementHelper.cloneScript(scripts.get(0));
        Map<String, Object> parameters = buttonScript.getParameters();
        // Check if the user has right to the see all user rights.
        if (ignoreRights 
            || _rights != null
                && _rights.containsKey(ExplainUserRightTool.RIGHT_EXPLAIN_ALL_USERS_RIGHTS)
                && hasRight(Map.of(ExplainUserRightTool.RIGHT_EXPLAIN_ALL_USERS_RIGHTS, _rights.get(ExplainUserRightTool.RIGHT_EXPLAIN_ALL_USERS_RIGHTS))))
        {
            if (parameters.containsKey(__ALL_USER_LABEL))
            {
                parameters.put("label", parameters.remove(__ALL_USER_LABEL));
                parameters.remove(__MY_USER_LABEL);
            }
            if (parameters.containsKey(__ALL_USER_DEFAULT_DESCRIPTION))
            {
                parameters.put("default-description", parameters.remove(__ALL_USER_DEFAULT_DESCRIPTION));
                parameters.remove(__MY_USER_DEFAULT_DESCRIPTION);
            }
            parameters.put("opentool-params", Map.of("mode", "anyUser"));
        }
        else
        {
            if (parameters.containsKey(__MY_USER_LABEL))
            {
                parameters.put("label", parameters.remove(__MY_USER_LABEL));
                parameters.remove(__ALL_USER_LABEL);
            }
            if (parameters.containsKey(__MY_USER_DEFAULT_DESCRIPTION))
            {
                parameters.put("default-description", parameters.remove(__MY_USER_DEFAULT_DESCRIPTION));
                parameters.remove(__ALL_USER_DEFAULT_DESCRIPTION);
            }
            parameters.put("opentool-params", Map.of("mode", "currentUser"));
        }
        return List.of(buttonScript);
    }
}
