/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.ui.widgets.richtext;

import java.util.Set;

/**
 * An attribute configuration for a {@link RichTextConfigurationTag}
 */
public interface RichTextConfigurationAttribute
{
    /**
     * Get the attribute name
     * @return a non null and non empty value
     */
    public String getName();
    
    /**
     * Get the default value for this attribute. An attribute with a default value will always be present in the code.
     * @return Can be null if there is no default value.
     */
    public String getDefaultValue();
    
    /**
     * Get the values that can be used on this attribute.
     * @return A non null set of possible values.
     */
    public Set<String> getAuthorizedValues();
    
    /**
     * Only applyable to the "class" attribute.<br>
     * Between the authorized values, some are "technical" values (by opposition to "style" values). Theses values should not be removed if the style of the tag change.<br>
     * For example when going from a "bordered" image to a "large bordered" image... the image should stay "float to the right".
     * @return A non null set of values.
     */
    public Set<String> getTechnicalValues();
}
