/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.ui.widgets.richtext;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.core.ui.ClientSideElement;
import org.ametys.runtime.plugin.component.PluginAware;

/**
 * This file imports extension will imports all files requires by validators and convertors from the {@link RichTextConfigurationExtensionPoint} 
 */
public class RichTextConfigurationFileImportsClientSideElement implements ClientSideElement, PluginAware, Serviceable
{
    private RichTextConfigurationExtensionPoint _richTextConfigurationExtensionPoint;
    private String _id;
    private String _pluginName;

    public void service(ServiceManager manager) throws ServiceException
    {
        _richTextConfigurationExtensionPoint = (RichTextConfigurationExtensionPoint) manager.lookup(RichTextConfigurationExtensionPoint.ROLE);
    }
    
    public void setPluginInfo(String pluginName, String featureName, String id)
    {
        _pluginName = pluginName;
        _id = id;
    }

    public String getId()
    {
        return _id;
    }

    public List<Script> getScripts(Map<String, Object> contextParameters)
    {
        return getScripts(false, contextParameters);
    }

    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = new ArrayList<>();
        
        for (String richTextConfigurationId : _richTextConfigurationExtensionPoint.getExtensionsIds())
        {
            RichTextConfiguration richTextConfiguration = _richTextConfigurationExtensionPoint.getExtension(richTextConfigurationId);
            for (String category : richTextConfiguration.getCategories())
            {
                Set<ClientSideElement> convertors = richTextConfiguration.getConvertors(category, contextParameters);
                if (convertors != null)
                {
                    for (ClientSideElement convertor : convertors)
                    {
                        List<Script> scriptsToAdd = convertor.getScripts(contextParameters);
                        if (scriptsToAdd != null)
                        {
                            scripts.addAll(scriptsToAdd);
                        }
                    }
                }
                
                Set<ClientSideElement> validators = richTextConfiguration.getValidators(category, contextParameters);
                if (validators != null)
                {
                    for (ClientSideElement validator : validators)
                    {
                        List<Script> scriptsToAdd = validator.getScripts(contextParameters);
                        if (scriptsToAdd != null)
                        {
                            scripts.addAll(scriptsToAdd);
                        }
                    }
                }
            }
        }
        
        return scripts;
    }

    public Map<String, String> getRights(Map<String, Object> contextParameters)
    {
        return Collections.EMPTY_MAP;
    }

    public String getPluginName()
    {
        return _pluginName;
    }

    public Map<String, List<String>> getDependencies()
    {
        return Collections.EMPTY_MAP;
    }

}
