/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.ui.widgets.richtext;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * A style is a way to render a table, a link, an image, a paragraph, an ordered list or an unordered list.
 */
public interface RichTextConfigurationStyle
{
    /**
     * Optionally a style can specify a tag name to use. For example, some 'paragraph' styles may use 'p' while another can use 'h1'.<br>
     * Tag has to be authorized separately
     * @return The tag name. Can be null.
     */
    public String getTagName();
    /**
     * Optionally a style can specify a CSS class name to use.<br>
     * The 'class' attribute has to be separately authorized and this particular value also.
     * @return The class name. Can be null.
     */
    public String getClassName();
    
    /**
     * Get the style label. A short name for button text.
     * @return A non-null value
     */
    public I18nizableText getButtonLabel();
    /**
     * Get the style description. A long description for tips.
     * @return A non-null value
     */
    public I18nizableText getButtonDescription();
    /**
     * Get the optional css to apply to the button.<br>
     * The CSS file declaring this class has to be loaded separately.
     * @return A class name. Can be null.
     */
    public String getButtonCSSClass();
    /**
     * Get the optional image to set on the button. Small is 16x16.
     * @return An image url. Can be null.
     */
    public String getButtonSmallIcon();
    /**
     * Get the optional image to set on the button. Medium is 32x32.
     * @return An image url. Can be null.
     */
    public String getButtonMediumIcon();
    /**
     * Get the optional image to set on the button. Large is 48x48.
     * @return An image url. Can be null.
     */
    public String getButtonLargeIcon();
}
