/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.ui.widgets.richtext;

import java.util.Set;

/**
 * A tag configuration for a {@link RichTextConfiguration}
 */
public interface RichTextConfigurationTag
{
    /**
     * What to do if this tag is empty?
     */
    public enum EMPTY_TAG 
    {
        /** Remove the tag. <code>&lt;span&gt;content&lt;/span&gt;</code> =&gt; <code>content</code> */
        REMOVE_EMPTY_ATTRIBUTES,
        /** Remove the tag. <code>&lt;span&gt;&lt;/span&gt;</code> =&gt; */
        REMOVE_EMPTY_CONTENT,
        /** Padding the tag. <code>&lt;span&gt;&lt;/span&gt;</code> =&gt; <code>&lt;span&gt;&amp;nbsp;&lt;/span&gt;</code> */
        PADDING,
        /** Keep open the tag. <code>&lt;span&gt;&lt;/span&gt;</code> =&gt; <code>&lt;span&gt;&lt;/span&gt;</code> */
        OPEN,
        /** Auto-close the tag. <code>&lt;span&gt;&lt;/span&gt;</code> =&gt; <code>&lt;span/&gt;</code> */
        CLOSE
    }
    
    /**
     * Get the tag name. Such as 'span'.
     * @return The tag name. Cannot be empty or null.
     */
    public String getTag();
    
    /**
     * Determine the action to do when this tag is empty.
     * @return The behavior. Cannot be null.
     */
    public EMPTY_TAG onEmptyTag();
    
    /**
     * The tags that should be replaced by this one. For example, "b" should be replaced by "strong".
     * Note that if "b" is handled otherwise, it will not be replaced.
     * @return A non null set of tags.
     */
    public Set<String> getSynonyms();
    
    /**
     * Get the attributes handled on this tag
     * @return A non null set of attributes.
     */
    public Set<RichTextConfigurationAttribute> getAttributes();
}
