/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.authentication;

import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.commons.lang3.StringUtils;

import org.ametys.core.authentication.AuthenticateAction;
import org.ametys.core.authentication.CredentialProvider;
import org.ametys.core.ui.StaticClientSideElement;
import org.ametys.core.user.User;
import org.ametys.core.user.UserIdentity;
import org.ametys.core.user.UserManager;
import org.ametys.plugins.core.impl.authentication.FormCredentialProvider;

/**
 * This implementation shows the multifactor authentication menu entry only if it is activated for the current credential provider
 */
public class MultifactorAuthenticationClientSideElement extends StaticClientSideElement implements Contextualizable
{
    /** The Avalon context */
    protected Context _context;
    
    /** The user manager */
    protected UserManager _userManager;
    
    @Override
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _userManager = (UserManager) smanager.lookup(UserManager.ROLE);
    }

    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        Request request = ContextHelper.getRequest(_context);
        CredentialProvider credentialProvider = AuthenticateAction.getCredentialProviderFromSession(request);
        if (credentialProvider instanceof FormCredentialProvider formCredentialProvider && formCredentialProvider.useMultifactorAuthentication())
        {
            UserIdentity userIdentity = _currentUserProvider.getUser();
            User user = _userManager.getUser(userIdentity);
            String recipient = user.getEmail();
            
            if (!StringUtils.isEmpty(recipient))
            {
                return super.getScripts(ignoreRights, contextParameters);
            }
        }

        return List.of();
    }
}
