/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.glyph;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.runtime.plugin.component.AbstractLogEnabled;
import org.ametys.runtime.plugin.component.PluginAware;

/**
 * Static implementation of a {@link GlyphProvider} based on a static configuration
 * 
 */
public class StaticGlyphProvider extends AbstractLogEnabled implements GlyphProvider, Configurable, PluginAware
{
    /** The name of the plugin that declared the provider */
    protected String _pluginName;
    /** The name of the feature that declared the provider */
    protected String _featureName;
    /** The files declared */
    protected Map<String, String> _cssFiles;

    public void setPluginInfo(String pluginName, String featureName, String id)
    {
        _pluginName = pluginName;
        _featureName = featureName;
    }
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _cssFiles = new HashMap<>();
        
        for (Configuration fileConfiguration : configuration.getChildren("file"))
        {
            String path = "plugin:" + _pluginName + "://" + fileConfiguration.getValue();
            String prefix = fileConfiguration.getAttribute("prefix", "");
            _cssFiles.put(path, prefix);
        }
    }
    
    @Override
    public Map<String, String> getCSSFiles()
    {
        return _cssFiles;
    }

}
