/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.plugins.core.ui.log;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Level;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.apache.log4j.spi.LoggerRepository;

import org.ametys.core.ui.Callable;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * A static client side element for the ServerLogMessageTargetFactory, giving some callables 
 */
public class ServerLogMessageTargetFactoryElement extends StaticClientSideElement
{
    /**
     * Get the log levels associated with the given log categories
     * @param categories The log categories to check
     * @return A map with 2 keys : levels and effectiveLevels. Each one is associating each log category given to its level ('DEBUG'... 'INHERIT'...)
     */
    @Callable (rights = Callable.SKIP_BUILTIN_CHECK)
    public Map<String, Map<String, String>> getLevels(List<String> categories)
    {
        LoggerRepository loggerRepository = LogManager.getLoggerRepository();
        
        Map<String, String> levels = new HashMap<>();
        Map<String, String> effectiveLevels = new HashMap<>();
        
        for (String category : categories)
        {
            Logger logger = "root".equals(category) ? loggerRepository.getRootLogger() : loggerRepository.getLogger(category);
            if (logger != null)
            {
                Level level = logger.getLevel();
                levels.put(category, level != null ? level.toString() : "inherit");
                effectiveLevels.put(category, logger.getEffectiveLevel().toString());
            }
        }

        Map<String, Map<String, String>> results = new HashMap<>();
        results.put("levels", levels);
        results.put("effectiveLevels", effectiveLevels);
        return results;
    }
}
