/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.minimize;

import java.io.Serializable;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.caching.CacheableProcessingComponent;
import org.apache.cocoon.reading.ServiceableReader;
import org.apache.excalibur.source.SourceResolver;
import org.apache.excalibur.source.SourceValidity;
import org.apache.excalibur.source.impl.validity.NOPValidity;

import org.ametys.core.minimize.SourceMapCache;
import org.ametys.core.resources.ProxiedContextPathProvider;

/**
 * Reader for Source map of minimized files
 */
public abstract class AbstractMinimizeSourceMapReader extends ServiceableReader implements CacheableProcessingComponent
{
    /** SourceMapCache */
    protected SourceMapCache _sourceMapCache;

    /** SourceResolver */
    protected SourceResolver _resolver;

    /** Cache for hash files list */
    protected HashCache _hashCache;
    
    private ProxiedContextPathProvider _proxiedContextPathProvider;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        
        _sourceMapCache = (SourceMapCache) smanager.lookup(SourceMapCache.ROLE);
        _resolver = (SourceResolver) smanager.lookup(SourceResolver.ROLE);
        _hashCache = (HashCache) smanager.lookup(HashCache.ROLE);
        _proxiedContextPathProvider = (ProxiedContextPathProvider) manager.lookup(ProxiedContextPathProvider.ROLE);
    }

    @Override
    public Serializable getKey()
    {
        return source + "*" + _proxiedContextPathProvider.getContextPath();
    }

    @Override
    public SourceValidity getValidity()
    {
        return new NOPValidity();
    }
}
