/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.plugins.core.ui.minimize.css;

import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.core.minimize.css.MinimizeCSSManager;
import org.ametys.plugins.core.ui.minimize.AbstractMinimizeReader;
import org.ametys.plugins.core.ui.minimize.HashCache.UriData;

/**
 * This generator generates a single CSS file to load all ui items css files.
 * Can generates a list of imports of directly integrates all css files.
 */
public class MinimizeCSSReader extends AbstractMinimizeReader
{
    private MinimizeCSSManager _cssMinimizeManager;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _cssMinimizeManager = (MinimizeCSSManager) smanager.lookup(MinimizeCSSManager.ROLE);
    }
    
    @Override
    public String getMimeType()
    {
        return "text/css";
    }
    
    @Override
    protected String _handleFiles(List<UriData> files, boolean generateSourceMap)
    {
        return _cssMinimizeManager.minimizeAndAggregateURIs(files, source + ".css", generateSourceMap);
    }
}
