/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.minimize.css;

import java.io.IOException;
import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.commons.io.IOUtils;
import org.apache.excalibur.source.Source;
import org.xml.sax.SAXException;

import org.ametys.core.minimize.css.MinimizeCSSManager;
import org.ametys.plugins.core.ui.minimize.AbstractMinimizeSourceMapReader;
import org.ametys.plugins.core.ui.minimize.HashCache.UriData;

/**
 * Reader for Source map of minimized css files
 */
public class MinimizeCSSSourceMapReader extends AbstractMinimizeSourceMapReader
{
    private MinimizeCSSManager _cssMinimizeManager;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        
        _cssMinimizeManager = (MinimizeCSSManager) manager.lookup(MinimizeCSSManager.ROLE);
    }

    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        Source sourceMap = _sourceMapCache.get(source + ".css.map");
        if (sourceMap == null) 
        {
            List<UriData> filesForHash = _hashCache.getFilesForHash(source, true);
            if (filesForHash != null)
            {
                // compiles the css files and store the source map in the source map cache
                _cssMinimizeManager.minimizeAndAggregateURIs(filesForHash, source + ".css", true);
                
                sourceMap = _sourceMapCache.get(source + ".css.map");
            }
        }
        
        if (sourceMap == null) 
        {
            throw new IllegalStateException("There is no source map for minimized hash file '" + source + ".css'");
        }
        
        IOUtils.copy(sourceMap.getInputStream(), out);
        out.close();
    }
}
