/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources;

import java.net.URI;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceResolver;

import org.ametys.core.resources.ResourceReader;
import org.ametys.plugins.core.ui.minimize.HashCache.UriData;
import org.ametys.plugins.core.ui.util.RequestAttributesHelper;

/**
 * Default resource dependencies listing for unsupported resource. Only returns self as a dependency
 */
public class DefaultResourceDependenciesList implements ResourceDependenciesList, Serviceable
{

    /** RequestAttributesHelper */
    protected RequestAttributesHelper _requestAttributesHelper;
    
    private SourceResolver _sourceResolver;

    public void service(ServiceManager manager) throws ServiceException
    {
        _sourceResolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
        _requestAttributesHelper = (RequestAttributesHelper) manager.lookup(RequestAttributesHelper.ROLE);
    }

    public boolean isSupported(String uri)
    {
        return true;
    }

    public int getPriority()
    {
        return 0;
    }

    public Set<UriData> getDependenciesList(String uri, Map<String, String> data, boolean onlyFirstLevel)
    {
        Map<String, Object> resolveParameters = new HashMap<>();
        Source fileSource = _getFileSource(uri, resolveParameters);
        
        long fileLastModified = resolveParameters.get(ResourceReader.LAST_MODIFIED) != null ? (long) resolveParameters.get("lastModified") : fileSource.getLastModified();
         
        UriData fileInfos = new UriData(uri, true);
        fileInfos.setLastModified(fileLastModified);
        
        Set<UriData> set = new HashSet<>();
        set.add(fileInfos);
        return set;
    }
    
    private Source _getFileSource(String cssUri, Map<String, Object> resolveParameters)
    {
        try
        {
            String uriToResolve = cssUri;
            URI uri = new URI(cssUri);
            if (!uri.isAbsolute())
            {
                uriToResolve = "cocoon:/" + uriToResolve;
            }
            
            _requestAttributesHelper.removeRequestAttributes();
            
            return _sourceResolver.resolveURI(uriToResolve, null, resolveParameters);
        }
        catch (Exception e)
        {
            throw new IllegalArgumentException("Unable to resolve the dependencies of specified uri", e);
        }
    }
}
