/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources;

import java.util.Map;
import java.util.Set;

import org.ametys.plugins.core.ui.minimize.HashCache.UriData;
import org.ametys.runtime.plugin.component.Prioritizable;

/**
 * List the dependencies of a resource
 */
public interface ResourceDependenciesList extends Prioritizable
{
    /**
     * Is the uri supported to get the list of dependencies
     * @param uri The uri
     * @return True if the uri is supported
     */
    public boolean isSupported(String uri);
    
    /**
     * Get the list of dependencies
     * @param uri The input source
     * @param data Additional data, specific per ResourceDependenciesList implementations
     * @param onlyFirstLevel if true, only data corresponding to the given uris should be returned
     * @return The list of dependencies URIs
     */
    public Set<UriData> getDependenciesList(String uri, Map<String, String> data, boolean onlyFirstLevel);
}
