/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources;

import java.util.Map;
import java.util.Set;
import java.util.function.Function;
import java.util.function.Predicate;

import org.ametys.plugins.core.ui.minimize.HashCache.UriData;
import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentPrioritizableExtensionPoint;

/**
 * Extension point for calculating a resource's dependencies
 */
public class ResourceDependenciesListExtensionPoint extends AbstractThreadSafeComponentPrioritizableExtensionPoint<ResourceDependenciesList>
{
    /** The avalon ROLE */
    public static final String ROLE = ResourceDependenciesListExtensionPoint.class.getName();
    
    @Override
    protected boolean sortPriorityAscending()
    {
        return false;
    }
    
    /**
     * Get the list of dependencies of a resource
     * @param uri The resource uri
     * @param data Additional data, specific per ResourceDependenciesList implementations
     * @param onlyFirstLevel if true, only data corresponding to the given uris should be returned
     * @return The list of dependencies' URIs, or null if no extension supports this URI
     */
    public Set<UriData> getDependencies(String uri, Map<String, String> data, boolean onlyFirstLevel)
    {
        Predicate<ResourceDependenciesList> isUriSupported = ext -> ext.isSupported(uri);
        Function<ResourceDependenciesList, Set<UriData>> getUriDependenciesList = ext -> ext.getDependenciesList(uri, data, onlyFirstLevel);
        
        return getExtensionsIds().stream()
                .map(this::getExtension)
                .filter(isUriSupported)
                .findFirst()
                .map(getUriDependenciesList)
                .orElse(null);
    }
}
