/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources.css;

import java.net.URISyntaxException;
import java.util.Objects;
import java.util.function.Function;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.commons.lang3.StringUtils;

/**
 * JSASS Resource URI for context URI
 */
public class ContextJSASSResourceURI implements JSASSResourceURI, Serviceable
{
    private SupportedContextResourceUriExtensionPoint _supportedContextResourceUri;
    
    public void service(ServiceManager manager) throws ServiceException
    {
        _supportedContextResourceUri = (SupportedContextResourceUriExtensionPoint) manager.lookup(SupportedContextResourceUriExtensionPoint.ROLE);
    }
    
    @Override
    public String resolve(String uri) throws URISyntaxException
    {
        if (!StringUtils.startsWith(uri, "context://"))
        {
            return null;
        }
        
        Function<SupportedContextResourceUri, String> resolveUri = ext -> ext.resolve(uri);
        
        String resolvedUri = _supportedContextResourceUri.getExtensionsIds().stream()
                .map(this::getExtension)
                .map(resolveUri)
                .filter(Objects::nonNull)
                .findFirst()
                .orElseThrow(() -> new URISyntaxException(uri, "No supported context:// for this uri, a SupportedContextResourceUri extension is required"));
        
        return resolvedUri;
    }

    @Override
    public String resolvePath(String path)
    {
        Function<SupportedContextResourceUri, String> resolvePath = ext -> ext.resolvePath(path);
        
        String resolvedUri = _supportedContextResourceUri.getExtensionsIds().stream()
                .map(this::getExtension)
                .map(resolvePath)
                .filter(Objects::nonNull)
                .findFirst()
                .orElse(null);
        
        return resolvedUri;
    }
    
    private SupportedContextResourceUri getExtension(String id)
    {
        return _supportedContextResourceUri.getExtension(id);
    }
    
}
