/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources.css;

import java.net.URISyntaxException;
import java.util.Objects;

import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;

/**
 * Extension point for resource URIs supported by JSASS
 */
public class JSASSResourceURIExtensionPoint extends AbstractThreadSafeComponentExtensionPoint<JSASSResourceURI> 
{
    /** avalon role */
    public static final String ROLE = JSASSResourceURIExtensionPoint.class.getName();
    
    /**
     * Resolve the URI, or returns the original uri if it is not supported
     * @param uri The URI
     * @return The resolved URI
     * @throws URISyntaxException If the URI is not supported
     */
    public String resolve(String uri) throws URISyntaxException
    {
        for (String extensionId : getExtensionsIds())
        {
            JSASSResourceURI extension = getExtension(extensionId);
            String resolvedUri = extension.resolve(uri);
            if (resolvedUri != null)
            {
                return resolvedUri;
            }
        }
        return uri;
    }
    
    /**
     * Resolve a path and return the URI corresponding, or null if the path is not supported
     * @param path The path
     * @return The URI
     */
    public String resolvePath(String path)
    {
        String result = getExtensionsIds()
                .stream()
                .map(this::getExtension)
                .map(ext -> ext.resolvePath(path))
                .filter(Objects::nonNull)
                .findFirst()
                .orElse(null);
        if (result != null)
        {
            return result;
        }
        return path.contains("://") ? path : "cocoon:/" + path;
    }
    
}
