/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources.css;

import java.net.URISyntaxException;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.lang3.StringUtils;

import org.ametys.runtime.plugin.component.PluginAware;

/**
 * JSASS Resource URI for plugins URI
 */
public class PluginsJSASSResourceURI implements JSASSResourceURI, PluginAware
{
    private static final Pattern URI_SUPPORTED_PATTERN = Pattern.compile("^plugin(?::([^:]+))?://(resources/.*)$");
    private static final Pattern PATH_SUPPORTED_PATTERN = Pattern.compile("^/plugins/([^/]+)/(resources/.*)$");
    private String _pluginName;

    @Override
    public void setPluginInfo(String pluginName, String featureName, String id)
    {
        _pluginName = pluginName;
    }
    
    @Override
    public String resolve(String uri) throws URISyntaxException
    {
        Matcher matcher = URI_SUPPORTED_PATTERN.matcher(uri);
        if (matcher.matches())
        {
            String target = matcher.group(1);
            if (StringUtils.isEmpty(target))
            {
                target = _pluginName;
            }
            String path = matcher.group(2);
            
            StringBuilder relativeSb = new StringBuilder();
            relativeSb.append("/plugins/");
            relativeSb.append(target);
            relativeSb.append("/");
            relativeSb.append(path);
            
            return relativeSb.toString();
        }
        return null;
    }

    @Override
    public String resolvePath(String path)
    {
        Matcher matcher = PATH_SUPPORTED_PATTERN.matcher(path);
        if (matcher.matches())
        {
            StringBuilder uri = new StringBuilder();
            uri.append("plugin:");
            uri.append(matcher.group(1));
            uri.append("://");
            uri.append(matcher.group(2));
            return uri.toString();
        }
        return null;
    }

}
