/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources.css.sass;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceResolver;

import org.ametys.core.resources.AbstractResourceHandlerProvider;
import org.ametys.core.resources.ResourceHandler;
import org.ametys.core.resources.ResourceHandlerProvider;

/**
 * {@link ResourceHandlerProvider} for Sass source map files.
 */
public class SassSourceMapResourceHandlerProvider extends AbstractResourceHandlerProvider
{
    private static final String[] __SASS_EXTENSION = new String[] {".scss", ".sass"};
    
    private SourceResolver _resolver;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _resolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }
    
    public int getPriority()
    {
        return MIN_PRIORITY + 1000;
    }
    
    public ResourceHandler getResourceHandler(String source) throws Exception
    {
        String lcSource = StringUtils.lowerCase(source);
        
        for (String ext : __SASS_EXTENSION)
        {
            if (StringUtils.endsWith(lcSource, ext + ".map"))
            {
                return setup(new SassSourceMapResourceHandler());
            }
        }
        
        if (lcSource.endsWith(".css.map"))
        {
            String sourceWithoutExt = StringUtils.substringBeforeLast(source, ".css.map");
            
            for (String ext : __SASS_EXTENSION)
            {
                Source src = null;
                try
                {
                    src = _resolver.resolveURI(sourceWithoutExt + ext);
                    if (src.exists())
                    {
                        // .scss or .sass file found
                        return setup(new SassSourceMapResourceHandler(src));
                    }
                    else
                    {
                        _resolver.release(src);
                    }
                }
                catch (IOException e)
                {
                    // Nothing
                }
            }
        }
       
        return null;
    }
}
