/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.plugins.core.ui.resources.css.sass;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.ResourceNotFoundException;
import org.apache.excalibur.source.Source;

import org.ametys.core.resources.SimpleResourceHandler;

/**
 * Reader for uncompiled SASS files.
 */
public class UncompiledSassResourceHandler extends SimpleResourceHandler
{
    @Override
    public Source setup(String location, Map objectModel, Parameters par, boolean readForDownload) throws ProcessingException, IOException
    {
        Source source = null;
        // If the file exists at the original location, return it without any processing
        
        source = _getSource(location);
        if (source == null)
        {
            int lastSlashIndex = location.lastIndexOf("/");
            if (lastSlashIndex + 2 < location.length())
            {
                // Appends underscore to the beginning of the file name
                String underscorelocation = location.substring(0, lastSlashIndex + 1) + "_" + location.substring(lastSlashIndex + 1);
                source = _getSource(underscorelocation);
            }
        }
        
        if (source == null)
        {
            throw new ResourceNotFoundException("Resource not found for URI : " + location);
        }
        
        _source = source;
        return _source;
    }

    private Source _getSource(String location)
    {
        Source source = null;
        try 
        {
            source = _resolver.resolveURI(location);
        } 
        catch (IOException e) 
        {
            // Nothing
        }
        
        if (source == null || !source.exists())
        {
            _resolver.release(source);
            return null;
        }
        
        return source;
    }

    @Override
    public String getMimeType()
    {
        return "text/css";
    }
}
