/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.resources.vuejs;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceResolver;

import org.ametys.core.resources.AbstractResourceHandlerProvider;
import org.ametys.core.resources.ResourceHandler;
import org.ametys.core.resources.ResourceHandlerProvider;
import org.ametys.plugins.core.ui.resources.vuejs.VueJsResourceHandler.LocationParser;

/**
 * {@link ResourceHandlerProvider} for compiled VueJS files.
 */
public class VueJsResourceHandlerProvider extends AbstractResourceHandlerProvider
{
    private SourceResolver _resolver;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _resolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }
    
    public int getPriority()
    {
        return MIN_PRIORITY + 10_000;
    }
    
    @Override
    public ResourceHandler getResourceHandler(String source) throws Exception
    {
        LocationParser lp = new LocationParser(source);
        if (!lp.matches())
        {
            return null;
        }
        
        try
        {
            Source src = _resolver.resolveURI(source);
            if (!src.exists())
            {
                return setup(new VueJsResourceHandler(src));
            }
            else
            {
                _resolver.release(src);
            }
        }
        catch (IOException e)
        {
            // Nothing
        }
        
        return null;
    }
}
