/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.right.profile;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.ametys.core.right.RightManager.RightResult;
import org.ametys.core.ui.ClientSideElementHelper;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * Client side element for the profile tools
 */
public class ProfileToolsClientSideElement extends StaticClientSideElement
{
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        if (scripts == null)
        {
            return null;
        }
        
        if (_rightManager.currentUserHasRight("Runtime_Rights_Rights_Profile_Handle", "/admin") != RightResult.RIGHT_ALLOW)
        {
            return scripts;
        }
        
        // The user has the right to handle profiles on /admin (and not only on its workspace... so it will be allowed to edit shared profiles
        
        List<Script> modifiedScripts = new ArrayList<>();
        
        for (Script originalScript : scripts)
        {
            Script clonedScript = ClientSideElementHelper.cloneScript(originalScript);
            
            clonedScript.getParameters().put("canEditAnyContext", "true");
            
            modifiedScripts.add(clonedScript);
        }
        
        return modifiedScripts;
    }
}
