/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.script;

import org.apache.commons.lang3.StringUtils;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;

final class ScriptResultFormatter
{
    private static final String[][] __STACKTRACE_REPLACEMENTS = {
            {"\r\n", "<br>"},
            {"\n\r", "<br>"},
            {"\r", "<br>"},
            {"\n", "<br>"},
    };
    
    private static final Gson __GSON = new GsonBuilder()
            .setPrettyPrinting()
            .disableHtmlEscaping()
            .create();
    
    private ScriptResultFormatter()
    { }
    
    static String htmlFormatResult(Object result)
    {
        if (result instanceof String)
        {
            // can be HTML => do not wrap around "<pre>" tag ! keep as it is
            return (String) result;
        }
        
        String value;
        try
        {
            // Pretty print JSON (better render than JSONUtils)
            String jsonString = __GSON.toJson(result);
            value = jsonString;
        }
        catch (Exception e)
        {
            value = String.valueOf(result);
        }
        
        return String.format("<pre>%s</pre>", value);
    }
    
    static String htmlFormatStacktrace(String errorStacktrace)
    {
        String htmlStacktrace = errorStacktrace;
        for (String[] replacement : __STACKTRACE_REPLACEMENTS)
        {
            htmlStacktrace = StringUtils.replace(htmlStacktrace, replacement[0], replacement[1], -1);
        }
        return htmlStacktrace;
    }
}
