/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.user;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.ametys.core.right.RightManager.RightResult;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * Client side element for user management
 *
 */
public class UserManagmentClientSideElement extends StaticClientSideElement
{
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        
        if (!scripts.isEmpty())
        {
            List<Script> clonedScripts = new ArrayList<>();
            
            boolean canHandleAll = _rightManager.hasRight(_currentUserProvider.getUser(), "Runtime_Rights_User_Handle", "/${WorkspaceName}") == RightResult.RIGHT_ALLOW;
            
            for (Script script : scripts)
            {
                Script clonedScript = new Script(script);
                
                Map<String, Object> parameters = clonedScript.getParameters();
                
                if (parameters.containsKey("opentool-id"))
                {
                    @SuppressWarnings("unchecked")
                    Map<String, Object> openToolParams = (Map<String, Object>) parameters.get("opentool-params");
                    openToolParams.put("userPopulationOnly", !canHandleAll);
                }
                else
                {
                    parameters.put("userPopulationOnly", !canHandleAll);
                }
                
                clonedScripts.add(clonedScript);
            }
            
            return clonedScripts;
        }
        
        return List.of();
    }
}
