/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.ui.util;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.core.ui.Callable;
import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.model.Enumerator;

/**
 * Helper for getting entries from a given enumerator
 */
public class ParameterEnumeratorHelper implements Component, Serviceable
{
    /** Avalon role */
    public static final String ROLE = ParameterEnumeratorHelper.class.getName();
        
    private ServiceManager _manager;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _manager = manager;
    }

    /**
     * Provides the enumerated values with their optional label.
     * @param enumeratorRole enumerator role
     * @return the enumerated values and their label.
     * @throws Exception if an error occurs.
     */
    @Callable (rights = Callable.SKIP_BUILTIN_CHECK)
    public Map<String, Object> getTypedEntries(String enumeratorRole) throws Exception
    {
        List<Map<String, Object>> entries = new ArrayList<>();
        Enumerator enumerator = (Enumerator) _manager.lookup(enumeratorRole);
        Map<String, I18nizableText> typedEntries = enumerator.getTypedEntries();
        
        for (Map.Entry<String, I18nizableText> entry : typedEntries.entrySet())
        {
            entries.add(Map.of("id", entry.getKey(), "label", entry.getValue()));
        }
        return Map.of("data", entries, "success", true);
    }
    
}
