/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.authentication.token;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.core.authentication.token.AuthenticationTokenManager.Token;
import org.ametys.core.cocoon.JSonReader;
import org.ametys.core.util.DateUtils;

/**
 * Get all authentication tokens in JSON
 */
public class GetAuthenticationTokensAction extends ServiceableAction
{
    /** The authentication token manager */
    private AuthenticationTokenManager _authenticationTokenManager;

    /**
     * Lookup the authentication token manager
     * 
     * @return the authentication token manager
     */
    protected AuthenticationTokenManager getAuthenticationTokenManager()
    {
        if (_authenticationTokenManager == null)
        {
            try
            {
                _authenticationTokenManager = (AuthenticationTokenManager) manager.lookup(AuthenticationTokenManager.ROLE);
            }
            catch (ServiceException e)
            {
                throw new IllegalStateException("Cannot get " + AuthenticationTokenManager.ROLE, e);
            }
        }

        return _authenticationTokenManager;
    }

    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);

        Map<String, Object> result = new HashMap<>();
        List<Map<String, Object>> tokensList = new ArrayList<>();

        List<Token> tokens = getAuthenticationTokenManager().getTokens(AuthenticationTokenManager.USER_TOKEN_TYPE);
        for (Token token : tokens)
        {
            Map<String, Object> infos = new HashMap<>();

            infos.put("id", token.getId());
            infos.put("description", token.getComment());
            Date creationDate = token.getCreationDate();
            infos.put("creationDate", creationDate != null ? DateUtils.dateToString(creationDate) : null);
            Date endDate = token.getEndDate();
            infos.put("endDate", endDate != null ? DateUtils.dateToString(endDate) : null);
            infos.put("nbUsesLeft", token.getNbUsesLeft());
            infos.put("contexts", token.getContexts());
            infos.put("comment", token.getComment());
            tokensList.add(infos);
        }

        result.put("tokens", tokensList);

        request.setAttribute(JSonReader.OBJECT_TO_READ, result);
        return EMPTY_MAP;
    }

}
