/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.cache;

import java.util.Collections;
import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.core.ObservationConstants;
import org.ametys.core.observation.Event;
import org.ametys.core.observation.ObservationManager;
import org.ametys.core.ui.Callable;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * Client side element for the cache buttons
 */
public class CacheClientSideElement extends StaticClientSideElement
{
    private AbstractCacheManager _cacheManager;
    private org.apache.cocoon.caching.Cache _cocoonCache;
    private ObservationManager _observationManager;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _cacheManager = (AbstractCacheManager) smanager.lookup(AbstractCacheManager.ROLE);
        _cocoonCache = (org.apache.cocoon.caching.Cache) smanager.lookup(org.apache.cocoon.caching.Cache.ROLE);
        if (smanager.hasService(ObservationManager.ROLE))
        {
            _observationManager = (ObservationManager) smanager.lookup(ObservationManager.ROLE);
        }
    }

    /**
     * clear the cache related to given id
     * @param ids the list of all caches ids
     */
    @Callable(rights = "Runtime_Rights_Admin_Access", context = "/admin")
    public void clearCaches(List<String> ids)
    {
        List<String> cleanedCaches = _cacheManager.resetCaches(ids);
        for (String cacheId : cleanedCaches)
        {
            if (_observationManager != null)
            {
                _observationManager.notify(new Event(ObservationConstants.EVENT_CACHE_RESET, 
                        _currentUserProvider.getUser(), 
                        Collections.singletonMap(ObservationConstants.ARGS_CACHE_ID, cacheId)));
            }
        }
    }

    /**
     * clear all the memory caches
     * @return the list of all cleaned caches
     */
    @Callable(rights = "Runtime_Rights_Admin_Access", context = "/admin")
    public List<String> clearAllCaches()
    {
        List<String> cleanedCaches = _cacheManager.resetAllMemoryCaches();
        for (String cacheId : cleanedCaches)
        {
            if (_observationManager != null)
            {
                _observationManager.notify(new Event(ObservationConstants.EVENT_CACHE_RESET, 
                        _currentUserProvider.getUser(), 
                        Collections.singletonMap(ObservationConstants.ARGS_CACHE_ID, cacheId)));
            }
        }
        return cleanedCaches;
    }

    /**
     * Empty the cocoon cache
     */
    @Callable(rights = "Runtime_Rights_Admin_Access", context = "/admin")
    public void emptyCocoonCache()
    {
        _cocoonCache.clear();
    }    
}
