/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.cache;

import java.util.Collections;
import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.environment.Request;
import org.apache.commons.lang3.StringUtils;

import org.ametys.core.ui.dispatcher.DispatchRequestProcess;

/**
 * Handle cache stats during dispatch
 */
public class CacheDispatchRequestProcess implements DispatchRequestProcess, Serviceable
{

    private AbstractCacheManager _cacheManager;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _cacheManager = (AbstractCacheManager) manager.lookup(AbstractCacheManager.ROLE);
    }
    
    @Override
    public void preProcess(Request request)
    {
        // Nothing to handle on preProcess
    }
    
    @Override
    public void postProcess(Request request)
    {
        @SuppressWarnings("unchecked")
        List<String> attrNames = Collections.list(request.getAttributeNames());
        for (String attrName : attrNames)
        {
            if (attrName != null && attrName.startsWith(AbstractCacheManager.ROLE))
            {
                String id = StringUtils.replace(attrName, AbstractCacheManager.ROLE + "$", StringUtils.EMPTY);
                Cache<Object, Object> cache = _cacheManager.get(id);
                if (!cache.isDispatchable())
                {
                    _cacheManager.refreshStats(request, id);
                    cache.resetCache();
                }
            }
        }
    }
}
