/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.cache;

import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.function.Predicate;
import java.util.stream.Collectors;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.core.cache.AbstractCacheManager.CacheType;
import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.model.Enumerator;

/**
 * {@link Enumerator} for the memory caches.
 */
public class MemoryCacheEnumerator implements Enumerator<String>, Serviceable
{
    /** The cache manager */
    protected AbstractCacheManager _cacheManager;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _cacheManager = (AbstractCacheManager) manager.lookup(AbstractCacheManager.ROLE);
    }

    @Override
    public I18nizableText getEntry(String value) throws Exception
    {
        try
        {
            return Optional.ofNullable(value)
                    .map(_cacheManager::get)
                    // FIXME Impossible to filter on CacheType for now
                    .map(Cache::getLabel)
                    .orElse(null);
        }
        catch (CacheException e)
        {
            // Ignore.
        }
        
        return null;
    }

    @Override
    public Map<String, I18nizableText> getTypedEntries() throws Exception
    {
        return _cacheManager.getAllCaches()
            .entrySet()
            .stream()
            .filter(entry -> entry.getKey().getRight() == CacheType.MEMORY)
            .map(Map.Entry::getValue)
            .filter(Predicate.not(List::isEmpty))
            .map(list -> list.get(0))
            .collect(Collectors.toMap(Cache::getId, Cache::getLabel));
    }
}
