/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.captcha;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.excalibur.source.SourceException;

import org.ametys.runtime.plugin.Feature;
import org.ametys.runtime.plugin.PluginsManager;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;
import org.ametys.runtime.plugin.component.PluginAware;

/**
 * Abstract class for Captchas to handle common methods such as retrieving wanted xsl file
 */
public abstract class AbstractCaptcha extends AbstractLogEnabled implements PluginAware, Configurable, Captcha
{
    private String _pluginName;
    private String _id;
    private String _xslPath;
    private String _scssPath;
    private String _featureName;
    
    public void setPluginInfo(String pluginName, String featureName, String id)
    {
        _pluginName = pluginName;
        _id = id;
        _featureName = featureName;
    }
    
    public String getId()
    {
        return _id;
    }
    
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _xslPath = configuration.getChild("xslPath").getValue();
        _scssPath = configuration.getChild("scssPath").getValue();
    }

    public Collection<String> getConfigParameters()
    {
        Feature feature = PluginsManager.getInstance().getFeatures().get(_pluginName + "/" + _featureName);
        Set<String> configParametersDeclared = feature.getConfigParameters().keySet();
        Collection<String> configParametersReferences = feature.getConfigParametersReferences();
        
        Set<String> configParameters = new HashSet<>();
        configParameters.addAll(configParametersDeclared);
        configParameters.addAll(configParametersReferences);
        return configParameters;
    }
    
    public String getXSLHelperURL() throws SourceException
    {
        return "plugin:" + _pluginName + "://" + _xslPath;
    }
    
    public String getLoginSCSSURL() throws SourceException
    {
        return "plugin:" + _pluginName + "://" + _scssPath;
    }
}
