/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.captcha;

import java.util.Map;
import java.util.stream.Collectors;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.model.Enumerator;

/**
 * {@link Enumerator} for the captchas.
 */
public class CaptchaEnumerator implements Enumerator<String>, Serviceable, Component
{
    /** Avalon role */
    public static final String ROLE = org.ametys.core.captcha.CaptchaEnumerator.class.getName();
    
    /** The captcha extension point */
    private CaptchaExtensionPoint _captchaExtensionPoint;
    private ServiceManager _manager;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _manager = manager;
    }
    
    private CaptchaExtensionPoint getCaptchaExtensionPoint()
    {
        if (_captchaExtensionPoint == null)
        {
            try
            {
                _captchaExtensionPoint = (CaptchaExtensionPoint) _manager.lookup(CaptchaExtensionPoint.ROLE);
            }
            catch (ServiceException e)
            {
                // Can be called during application startup
                return null;
            }
        }
        return _captchaExtensionPoint;
    }

    @Override
    public I18nizableText getEntry(String value) throws Exception
    {
        CaptchaExtensionPoint captchaExtensionPoint = getCaptchaExtensionPoint();
        
        if (captchaExtensionPoint != null)
        {
            return captchaExtensionPoint.getExtension(value).getLabel();
        }
        else
        {
            // Can be called during application startup
            return new I18nizableText(value);
        }
    }

    @Override
    public Map<String, I18nizableText> getTypedEntries() throws Exception
    {
        return getCaptchaExtensionPoint().getExtensionsIds()
                .stream()
                .map(extensionId -> _captchaExtensionPoint.getExtension(extensionId))
                .collect(Collectors.toMap(Captcha::getId, Captcha::getLabel));
    }
}
