/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.cocoon;

import java.util.Locale;

import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.i18n.Bundle;
import org.apache.cocoon.xml.ParamSaxBuffer;
import org.apache.excalibur.source.SourceResolver;

import org.ametys.core.util.cocoon.InvalidSourceValidity;

/**
 * This implementation of <code>Bundle</code> interface for XML resources allows to be invalidated. 
 *
 */
public class XMLResourceBundle extends org.apache.cocoon.i18n.XMLResourceBundle
{
    /**
     * Construct a bundle.
     * @param sourceURI source URI of the XML bundle
     * @param locale locale
     * @param parentBundle parent bundle of this bundle
     */
    public XMLResourceBundle(String sourceURI, Locale locale, Bundle parentBundle)
    {
        super(sourceURI, locale, parentBundle);
    }

    @Override
    public boolean reload(ServiceManager manager, SourceResolver resolver, long interval)
    {
        return super.reload(manager, resolver, interval);
    }
    
    /**
     * Invalidate bundle
     */
    public void invalidate ()
    {
        setValidity(new InvalidSourceValidity());
    }
    
    /**
     * Expert method !
     * Get an instance of the {@link ParamSaxBuffer} associated with the key. 
     * This method delegates to parent object only if related to the same Locale. 
     * @param key the key
     * @return the value, or null if no value associated with the key in this Locale.
     */
    public Object getRawObject(String key) 
    {
        if (key == null) 
        {
            return null;
        }

        Object value = this.values.get(key);
        if (value != null) 
        {
            return value;
        }
        
        // get the parent only if it concerns the same locale, so that it is still possible to override plugins with WEB-INF/i18n
        // but get null anyway if not found for current locale
        if (parent != null && ((XMLResourceBundle) parent).getLocale().equals(getLocale()))
        {
            return ((XMLResourceBundle) this.parent).getRawObject(key);
        }

        return null;
    }
}
