/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.devmode;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;

import org.ametys.core.DevMode;
import org.ametys.core.DevMode.DEVMODE;
import org.ametys.core.ui.ClientSideElementHelper;
import org.ametys.core.ui.SimpleMenu;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * Client side element for the dev mode button
 */
public class DevModeClientSideElement extends SimpleMenu implements Contextualizable
{
    private Context _context;

    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        
        if (!scripts.isEmpty())
        {
            if (scripts.size() != 1)
            {
                throw new IllegalStateException(getId() + " cannot return more than 1 script");
            }
            
            Script script = ClientSideElementHelper.cloneScript(scripts.get(0));

            Request request = ContextHelper.getRequest(_context);
            DEVMODE devMode = DevMode.getDeveloperMode(request);

            boolean toggle = false;
            I18nizableText description = null;
            String decorator = null;
            
            switch (devMode)
            {
                case DEVELOPMENT:
                    toggle = true;
                    description = new I18nizableText("plugin.core-ui", "PLUGINS_CORE_UI_TOOLS_DEVMODE_DEVELOPMENT_MODE_DESCRIPTION");
                    break;
                case SUPER_DEVELOPPMENT:
                    toggle = true;
                    description = new I18nizableText("plugin.core-ui", "PLUGINS_CORE_UI_TOOLS_DEVMODE_SUPER_DEV_MODE_DESCRIPTION");
                    decorator = "decorator-ametysicon-bugs3";
                    break;
                default:
                case PRODUCTION:
                    description = new I18nizableText("plugin.core-ui", "PLUGINS_CORE_UI_TOOLS_DEVMODE_PRODUCTION_MODE_DESCRIPTION");
                    break;
            }
            
            Map<String, Object> parameters = script.getParameters();
            parameters.put("description", description);
            parameters.put("toggle-state", toggle);
            if (decorator != null)
            {
                parameters.put("icon-decorator", decorator);
            }
            
            return Collections.singletonList(script);
        }
        
        return scripts; // Empty list
    }
}
