/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.devmode;

import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.commons.lang3.StringUtils;

import org.ametys.core.DevMode;
import org.ametys.core.DevMode.DEVMODE;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * Client side element for the dev mode menu item buttons
 */
public class DevModeMenuItemClientSideElement extends StaticClientSideElement implements Contextualizable
{
    private Context _context;
    private String _toggleOn;
    private Boolean _dynamicDecorator;

    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        super.configure(configuration);
        _toggleOn = configuration.getChild("toggle-on").getValue("");
        _dynamicDecorator = Boolean.valueOf(configuration.getChild("dynamic-decorator").getValue("false"));
    }

    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        
        if (!scripts.isEmpty())
        {
            Script script = scripts.get(0);

            Request request = ContextHelper.getRequest(_context);
            DEVMODE devMode = DevMode.getDeveloperMode(request);
            String forceDevMode = request.getParameter(DevMode.REQUEST_PARAM_FORCE_DEVMODE);
            String decorator = null;

            if (_dynamicDecorator)
            {
                if (DEVMODE.PRODUCTION.equals(devMode))
                {
                    decorator = "decorator-ametysicon-sign-raw-cross";
                }
                else if (DEVMODE.DEVELOPMENT.equals(devMode))
                {
                    decorator = "decorator-ametysicon-sign-raw-check";
                }
                else if (DEVMODE.SUPER_DEVELOPPMENT.equals(devMode))
                {
                    decorator = "decorator-ametysicon-bugs3";
                }
            }
            
            Map<String, Object> parameters = script.getParameters();
            if (decorator != null)
            {
                parameters.put("icon-decorator", decorator);
            }
            boolean toggled = forceDevMode != null ? forceDevMode.equals(_toggleOn) : StringUtils.isEmpty(_toggleOn);
            parameters.put("toggle-state", toggled);
            parameters.put("disabled", toggled);
        }
        
        return scripts;
    }
}
