/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.engine;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.Session;
import org.apache.cocoon.environment.commandline.CommandLineRequest;
import org.apache.cocoon.environment.commandline.CommandLineSession;

/**
 * Simple {@link Request} used for internal requests.
 */
public class BackgroundRequest extends CommandLineRequest
{
    private Session _session;
    
    /**
     * Constructs this simple request.
     * @param env the parent environment.
     */
    public BackgroundRequest(BackgroundEnvironment env)
    {
        super(
            env,                   // environment
            "",                    // context path
            "",                    // servlet path
            "",                    // path info
            new HashMap(),         // attributes
            Collections.EMPTY_MAP, // parameters
            Collections.EMPTY_MAP  // headers
        );
    }
    
    /**
     * Constructs this simple request.
     * @param env the parent environment.
     * @param contextPath the context path
     * @param requestAttributes request attributes.
     * @param requestParameters request parameters.
     * @param requestHeaders request headers.
     */
    public BackgroundRequest(BackgroundEnvironment env, String contextPath, Map requestAttributes, Map requestParameters, Map requestHeaders)
    {
        super(
            env,                   // environment
            contextPath,           // context path
            "",                    // servlet path
            "",                    // path info
            requestAttributes,     // attributes
            requestParameters,     // parameters
            requestHeaders         // headers
        );
    }

    @Override
    public Session getSession(boolean create)
    {
        if (_session != null)
        {
            return _session;
        }
        
        if (create)
        {
            _session = new CommandLineSession();
        }
        
        return _session;
    }
}
