/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.file;

import org.apache.avalon.framework.activity.Initializable;
import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.tika.Tika;

/**
 * Provides a single shared Tika instance to other Components.
 */
public class TikaProvider extends AbstractLogEnabled implements Component, Initializable
{
    /** The avalon role. */
    public static final String ROLE = TikaProvider.class.getName();
    
    /** The managed Tika instance. */
    protected Tika _tika;
    
    @Override
    public void initialize() throws Exception
    {
        _tika = new Tika();
    }
    
    /**
     * Get the Tika instance.
     * @return The Tika instance.
     */
    public Tika getTika()
    {
        return _tika;
    }
}
