/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.group;

import java.util.Set;

import org.ametys.core.group.directory.GroupDirectory;
import org.ametys.core.user.UserIdentity;

/**
 * A user group is a set of {@link UserIdentity}, representing a group of users.<br>
 * A group contains any number of users, and a single user may belong to any number of groups.
 */
public interface Group
{
    /**
     * Returns the identity of this group
     * @return the identity of this group
     */
    public GroupIdentity getIdentity();
    
    /**
     * Returns the label of this group
     * @return the label of this group
     */
    public String getLabel();
    
    /**
     * Returns the group directory this group belongs to
     * @return the group directory this group belongs to
     */
    public GroupDirectory getGroupDirectory();
    
    /**
     * Returns all users of this group.
     * @return Users as a Set of {@link UserIdentity}
     */
    public Set<UserIdentity> getUsers();
}
