/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.mbean;

import java.lang.management.ManagementFactory;
import java.util.Hashtable;

import javax.management.DynamicMBean;
import javax.management.MBeanServer;
import javax.management.ObjectName;

import org.apache.commons.lang3.StringUtils;

import org.ametys.runtime.plugin.Init;
import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;
import org.ametys.runtime.util.AmetysHomeHelper;

/**
 * Extension point holding all {@link Init} classes loaded after all components and extensions.
 */
public class MBeanExtensionPoint extends AbstractThreadSafeComponentExtensionPoint<DynamicMBean>
{
    /** Avalon Role */
    public static final String ROLE = MBeanExtensionPoint.class.getName();
    
    @Override
    public void initializeExtensions() throws Exception
    {
        super.initializeExtensions();
        MBeanServer mbs = ManagementFactory.getPlatformMBeanServer(); 
        for (String ePId : getExtensionsIds())
        {
            DynamicMBean mbean = getExtension(ePId);
            String key = AmetysHomeHelper.getAmetysHome().getAbsolutePath();
            String className = mbean.getMBeanInfo().getClassName();
            Hashtable<String, String> properties = new Hashtable<>();
            properties.put("context", StringUtils.replace(StringUtils.remove(key, ":"), "=", "_"));
            properties.put("type", className);
            ObjectName name = new ObjectName("org.ametys", properties);
            // If for any reason, there was already an MBean with the same name, we replace it.
            if (mbs.isRegistered(name))
            {
                mbs.unregisterMBean(name);
            }
            mbs.registerMBean(mbean, name);
        }
    }
}
