/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.migration;

import org.ametys.core.migration.MigrationEngine.ActionData;

/**
 * Exception that occured during an automatic migration
 */
public class MigrationException extends Exception
{
    private String _causeMessage;
    private ActionData _failedAction;
    
    /**
     * Constructs a new exception with the specified detail message.
     * @param message the detail message.
     */
    public MigrationException(String message)
    {
        super(message);
        _causeMessage = message;
    }
    
    /**
     * Constructs a new exception with the specified detail message, associated with the initial failure cause.
     * @param message the detail message.
     * @param causeMessage the failure message.
     */
    public MigrationException(String message, String causeMessage)
    {
        super(message);
        _causeMessage = causeMessage;
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * @param message the detail message.
     * @param cause the cause.
     */
    public MigrationException(String message, Throwable cause)
    {
        super(message, cause);
        _causeMessage = cause.getMessage();
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * @param message the detail message.
     * @param causeMessage the failure message.
     * @param cause the cause.
     * @param action the failed action
     */
    public MigrationException(String message, String causeMessage, Throwable cause, ActionData action)
    {
        super(message, cause);
        _causeMessage = causeMessage;
        _failedAction = action;
    }

    /**
     * Constructs a new exception with the specified cause.
     * @param cause the specified cause.
     */
    public MigrationException(Throwable cause)
    {
        super(cause);
        _causeMessage = cause.getMessage();
    }
    
    /**
     * Returns the failure message, if any.
     * @return the failure message
     */
    public String getFailureMessage()
    {
        return _causeMessage;
    }
    
    /**
     * Returns the failed action, if any
     * @return the failed action
     */
    public ActionData getFailedAction()
    {
        return _failedAction;
    }
}
