/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.migration.action;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.core.migration.MigrationEngine.ActionData;
import org.ametys.core.migration.MigrationException;

/**
 * Interface for actions components 
 */
public interface Action
{
    /**
     * Run the action with the provided data
     * @param actionData data needed to do the action
     * @throws MigrationException Something went wrong
     */
    public void act(ActionData actionData) throws MigrationException;
    
    /**
     * Generate an {@link ActionConfiguration} linked to this kind of action
     * @param versionNumber id of the action
     * @param type type of action
     * @param comment Comment about this action
     * @param from if this actions is the equivalent of multiple actions, this is the version id just before the 1st action impacted by this action
     * @param restartRequired true if a restart is required after the action
     * @param isInitialization true for initialization action, false for upgrade
     * @param configuration configuration of the action
     * @return a {@link ActionConfiguration} for this type of action
     * @throws ConfigurationException Configuration malformed
     */
    public ActionConfiguration createActionConfiguration(String versionNumber, String type, String comment, String from, boolean restartRequired, boolean isInitialization, Configuration configuration) throws ConfigurationException;
}
