/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.migration.action;

/**
 * Representation of an upgrade line in the extension
 */
public interface ActionConfiguration
{
    /**
     * Get the upgrade version number
     * @return upgrade version number
     */
    public String getVersionNumber();

    /**
     * Get the upgrade type
     * @return upgrade type
     */
    public String getType();
    
    /**
     * Get the comment about this action
     * @return The comment about this action
     */
    public String getComment();

    /**
     * Get the upgrade "from" field
     * @return upgrade "from" field
     */
    public String getFrom();

    /**
     * If true at the end of the action, the server will be restarted
     * @return true to restart server
     */
    public boolean requiresRestart();
    
    /**
     * Set the requireRestart flag
     * @param requiresRestart true to indicates that the server will require a restart at the end of the action
     */
    public void setRequiresRestart(boolean requiresRestart);
}
