/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.migration.action;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.core.migration.MigrationEngine.ActionData;
import org.ametys.core.migration.MigrationException;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Manual action: no code will be executed, and an exception will be thrown to stop the migration
 */
public class ManualAction extends AbstractLogEnabled implements Action
{
    @Override
    public void act(ActionData actionData) throws MigrationException
    {
        StringBuilder message = new StringBuilder();
        message.append("ACTION: '");
        message.append(actionData.configuration().getVersionNumber());
        message.append("'/'");
        message.append(actionData.currentVersion().getComponentId());
        message.append("' for version '");
        message.append(actionData.currentVersion().getVersionNumber());
        message.append("' was not done automatically. [");
        message.append(actionData.configuration().getComment());
        message.append("]");
        throw new MigrationException(message.toString());
    }
    
    public ActionConfiguration createActionConfiguration(String versionNumber, String type, String comment, String from, boolean restartRequired, boolean isInitialization, Configuration configuration) throws ConfigurationException
    {
        return new DefaultActionConfiguration(versionNumber, type, comment, from, restartRequired, isInitialization);
    }
}
