/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.migration.version.handler;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.core.migration.MigrationEngine.MigrationComponent;
import org.ametys.core.migration.MigrationEngine.Versions;
import org.ametys.core.migration.MigrationException;
import org.ametys.core.migration.NotMigrableInSafeModeException;
import org.ametys.core.migration.version.Version;
import org.ametys.core.migration.version.VersionConfiguration;
import org.ametys.core.migration.version.storage.VersionStorage;

/**
 * Handler to retrieve all versions
 */
public interface VersionHandler
{
    /**
     * Returns the {@link VersionStorage} associated with this {@link VersionHandler}.
     * @param configuration the associated configuration
     * @return the associated {@link VersionStorage}
     * @throws MigrationException if an exception occur while getting the version storage
     */
    VersionStorage getVersionStorage(VersionConfiguration configuration) throws MigrationException;
    
    /**
     * Retrieves a hierarchical view of all {@link Version} managed by this component.
     * @param component the context component
     * @return all {@link Version} managed by this component
     * @throws MigrationException something went wrong while retrieveing the versions
     */
    Versions getVersions(MigrationComponent component) throws MigrationException;
    
    /**
     * Creates a {@link VersionConfiguration} associated with this {@link VersionHandler}
     * @param configuration the {@link Configuration} for retrieving versions 
     * @return a configuration for this type of version handler 
     * @throws ConfigurationException something is wrong in the configuration
     * @throws NotMigrableInSafeModeException if it's impossible to configure the versions in safe mode
     */
    VersionConfiguration createVersionConfiguration(Configuration configuration) throws ConfigurationException, NotMigrableInSafeModeException;
}
