/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.minimize;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.ResourceNotFoundException;
import org.apache.excalibur.source.Source;

import org.ametys.core.resources.SimpleResourceHandler;

/**
 * Resource handler for source map files
 */
public abstract class AbstractSourceMapResourceHandler extends SimpleResourceHandler
{
    /** SourceMapCache */
    protected SourceMapCache _sourceMapCache;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _sourceMapCache = (SourceMapCache) manager.lookup(SourceMapCache.ROLE);
    }
    
    @Override
    public Source setup(String location, Map objectModel, Parameters par, boolean readForDownload) throws IOException, ProcessingException
    {
        // 1. if the source map file exists, use it
        Source source = _getExistingSource(location);
        if (source == null)
        {
            source = _getAlternateSource(location, objectModel);

            if (source == null)
            {
                throw new ResourceNotFoundException("Resource not found for URI : " + location);
            }
        }
        
        _source = source;
        return source;
    }

    /**
     * Find the source at an alternative location
     * @param location The original location
     * @param objectModel The object model
     * @return The source, or null if not found
     * @throws IOException  If an error occurred
     * @throws ProcessingException  If an error occurred
     */
    protected abstract Source _getAlternateSource(String location, Map objectModel) throws ProcessingException, IOException;
    
    /**
     * Try to retrieve an existing source
     * @param location The location
     * @return The source, or null if not found
     */
    protected Source _getExistingSource(String location) 
    {
        Source source = null;
        try 
        {
            source = _resolver.resolveURI(location);
        } 
        catch (IOException e) 
        {
            // Nothing
        }
        
        if (source == null || !source.exists())
        {
            _resolver.release(source);
            return null;
        }
        
        return source;
    }
}
