/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.minimize;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.activity.Initializable;
import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceResolver;

import org.ametys.core.cache.AbstractCacheManager;
import org.ametys.core.cache.Cache;
import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * A simple cache for source maps from files
 */
public class SourceMapCache extends AbstractLogEnabled implements Component, Serviceable, Initializable
{
    /** The avalon ROLE */
    public static final String ROLE = SourceMapCache.class.getName();

    /** CacheManager used to create and get cache */
    protected AbstractCacheManager _cacheManager;
    
    /** Excalibur source resolver */
    protected SourceResolver _sourceResolver;

    public void service(ServiceManager manager) throws ServiceException
    {
        _cacheManager = (AbstractCacheManager) manager.lookup(AbstractCacheManager.ROLE);
        _sourceResolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }

    public void initialize() throws Exception
    {
        _cacheManager.createMemoryCache(ROLE, 
                new I18nizableText("plugin.core", "PLUGINS_CORE_CACHE_SOURCE_MAP_LABEL"),
                new I18nizableText("plugin.core", "PLUGINS_CORE_CACHE_SOURCE_MAP_DESCRIPTION"),
                true,
                null);
    }
    /**
     * Put a source map into the cache
     * @param uri The uri of the source map
     * @param content The content of the source map
     * @param lastModified The last modified date of the source map
     * @throws IOException If the uri is invalid
     */
    public void put(String uri, String content, Long lastModified) throws IOException
    {
        Source sourceMapData = _sourceResolver.resolveURI(SourceMapSourceFactory.SCHEME + "://" + uri, null, Map.of(SourceMapSourceFactory.CONTENT, content, 
                                                                                                                    SourceMapSourceFactory.LAST_MODIFIED, lastModified));
        _getCache().put(uri, sourceMapData);
    }
    
    /**
     * Get a value from the cache
     * @param uri The uri of the source map
     * @return The data, or null if the uri is not in the cache
     */
    public Source get(String uri)
    {
        return _getCache().get(uri);
    }
    
    private Cache<String, Source> _getCache() 
    {
        return this._cacheManager.get(ROLE);
    }    
}
