/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.model.type;

import java.util.Optional;
import java.util.stream.Stream;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.tuple.Triple;

import org.ametys.runtime.model.compare.DataChangeType;
import org.ametys.runtime.model.compare.DataChangeTypeDetail;

/**
 * Abstract class for string element types
 */
public abstract class AbstractStringElementType extends AbstractElementType<String>
{
    @Override
    public String convertValue(Object value)
    {
        return value.toString();
    }
    
    @Override
    public String toString(String value)
    {
        return value;
    }
    
    @Override
    protected Stream<Triple<DataChangeType, DataChangeTypeDetail, String>> _compareSingleValues(String value1, String value2)
    {
        return Stream.of(ModelItemTypeHelper.compareSingleStrings(value1, value2, StringUtils.EMPTY))
                     .filter(Optional::isPresent)
                     .map(Optional::get);
    }
    
    public boolean isSimple()
    {
        return true;
    }
}
