/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.resources;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.components.LifecycleHelper;
import org.apache.cocoon.util.log.SLF4JLoggerAdapter;

import org.ametys.runtime.plugin.component.AbstractLogEnabled;
import org.ametys.runtime.plugin.component.LogEnabled;

/**
 * Abstract superclass for {@link ResourceHandlerProvider} for helping {@link ResourceHandler} creation.
 */
public abstract class AbstractResourceHandlerProvider extends AbstractLogEnabled implements ResourceHandlerProvider, Serviceable, Contextualizable
{
    /** The application context */
    protected Context _context;
    
    /** The service manager */
    protected ServiceManager _manager;
    
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    public void service(ServiceManager manager) throws ServiceException
    {
        _manager = manager;
    }
    
    /**
     * Setup the handler right after its creation
     * @param handler the handler.
     * @return the initialized {@link ResourceHandler}.
     * @throws Exception if something goes wrong during initialization
     */
    protected ResourceHandler setup(ResourceHandler handler) throws Exception
    {
        LifecycleHelper.setupComponent(handler, new SLF4JLoggerAdapter(getLogger()), _context, _manager, null);
        if (handler instanceof LogEnabled)
        {
            ((LogEnabled) handler).setLogger(getLogger());
        }
        
        return handler;
    }
}
