/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.resources;

import java.util.HashSet;
import java.util.Set;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.commons.lang3.StringUtils;

/**
 * Simple {@link ResourceHandlerProvider} based on source suffixes (mainly file extensions).
 */
public abstract class AbstractSimpleResourceHandlerProvider extends AbstractResourceHandlerProvider implements Configurable
{
    /** The supported suffixes */
    protected Set<String> _supportedSuffixes;
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _supportedSuffixes = new HashSet<>();
        
        Configuration[] suffixConf = configuration.getChild("suffixes").getChildren("suffix");
        for (Configuration suffix : suffixConf)
        {
            _supportedSuffixes.add(StringUtils.lowerCase(suffix.getValue()));
        }
    }
    
    public ResourceHandler getResourceHandler(String source) throws Exception
    {
        String lcSource = StringUtils.lowerCase(source);
        
        if (_supportedSuffixes.stream().anyMatch(suffix -> StringUtils.endsWith(lcSource, suffix)))
        {
            return setup(createResourceHandler(source));            
        }
        
        return null;
    }
    
    /**
     * Actually creates the {@link ResourceHandler}.
     * @param source the requested resource.
     * @return the created {@link ResourceHandler}.
     */
    protected abstract ResourceHandler createResourceHandler(String source);
}
