/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.resources;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Response;
import org.apache.excalibur.source.Source;

/**
 * Default resource handler that expires 
 */
public class ExpiresResourceHandler extends SimpleResourceHandler implements Contextualizable
{
    private Context _context;
    
    /**
     * Default constructor
     */
    public ExpiresResourceHandler()
    {
        super();
    }
    
    /**
     * Constructor with an already resolved {@link Source}.
     * @param source the source
     */
    public ExpiresResourceHandler(Source source)
    {
        super(source);
    }
    
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public Source setup(String location, Map objectModel, Parameters parameters, boolean readForDownload) throws IOException, ProcessingException
    {
        // This header prevents browser storage of the resource in cache
        Response response = ContextHelper.getResponse(_context);
        response.setDateHeader("Expires", 0);
        
        return super.setup(location, objectModel, parameters, readForDownload);
    }
}
