/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.resources;

import java.util.HashSet;
import java.util.Set;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;
import org.apache.excalibur.source.SourceResolver;

import org.ametys.core.resources.ImageResourceHandler.SizedSource;

/**
 * {@link ResourceHandlerProvider} for images.
 */
public class ImageResourceHandlerProvider extends AbstractSimpleResourceHandlerProvider
{
    /** The source resolver */
    protected SourceResolver _resolver;
    
    /** The supported mime types */
    protected Set<String> _supportedMimeTypes;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _resolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        super.configure(configuration);
        
        _supportedMimeTypes = new HashSet<>();
        
        Configuration[] mimeTypes = configuration.getChild("mimeTypes").getChildren("mimeType");
        for (Configuration mimeType : mimeTypes)
        {
            _supportedMimeTypes.add(StringUtils.lowerCase(mimeType.getValue()));
        }
    }
    
    @Override
    public ResourceHandler getResourceHandler(String location) throws Exception
    {
        ResourceHandler resourceHandler = super.getResourceHandler(location);
        if (resourceHandler != null)
        {
            return resourceHandler;
        }
        
        SizedSource sizedSource = ImageResourceHandler._resolveSource(location, _resolver);
        if (sizedSource != null)
        {
            if (_supportedMimeTypes.stream()
                    .anyMatch(mimeType -> StringUtils.equalsIgnoreCase(sizedSource.source().getMimeType(), mimeType)))
            {
                return new ImageResourceHandler(sizedSource);
            }
            else
            {
                _resolver.release(sizedSource.source());
            }
        }
                
        return null;
    }
    
    @Override
    protected ResourceHandler createResourceHandler(String source)
    {
        return new ImageResourceHandler();
    }
}
