/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.resources;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Response;
import org.apache.excalibur.source.Source;

/**
 * Resource handler for JavaScript files
 */
public class JSResourceHandler extends I18nTextResourceHandler
{
    /** Parameter to enable or not the expire 0 header. Default to true */
    protected boolean _setExpiresToNoCache = true; 

    @Override
    public Source setup(String location, Map objectModel, Parameters par, boolean readForDownload) throws ProcessingException, IOException
    {
        // RUNTIME-2898 : In chrome, the cache validity of javascript files loaded by Source Maps 
        // is not properly checked with the server. No request is performed. To fix this issue, 
        // non-minimized JS files should have an expire header of 0, so they are not stored in the browser cache.
        if (_setExpiresToNoCache)
        {
            Response response = ContextHelper.getResponse(_context);
            response.setDateHeader("Expires", 0);
        }
        
        return super.setup(location, objectModel, par, readForDownload);
    }
    
    @Override
    public String getMimeType()
    {
        return "text/javascript;charset=utf-8";
    }
}
