/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.resources;

import org.apache.excalibur.source.Source;

import org.ametys.runtime.plugin.component.Prioritizable;

/**
 * Provides a {@link ResourceHandler} able to process a {@link Source}.
 */
public interface ResourceHandlerProvider extends Prioritizable
{
    /** Minimum priority. */
    public static final int MIN_PRIORITY = 0;
    /** Maximum priority. */
    public static final int MAX_PRIORITY = Integer.MAX_VALUE;

    @Override
    default int getPriority()
    {
        return MIN_PRIORITY;
    }
    
    /**
     * Returns the corresponding {@link ResourceHandler} or null if none.<br>
     * Returned {@link ResourceHandler} should be thread safe.
     * @param source the requested resource.
     * @return a ResourceHandler able to process the resource.
     * @throws Exception if an error occurs during ResourceHandler creation.
     */
    public ResourceHandler getResourceHandler(String source) throws Exception;
}
