/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.resources;

import java.util.Objects;

import org.apache.cocoon.components.LifecycleHelper;
import org.apache.cocoon.util.log.SLF4JLoggerAdapter;

import org.ametys.core.util.LambdaUtils;
import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentPrioritizableExtensionPoint;
import org.ametys.runtime.plugin.component.LogEnabled;

/**
 * Extension point for {@link ResourceHandlerProvider}.
 */
public class ResourceHandlerProviderExtensionPoint extends AbstractThreadSafeComponentPrioritizableExtensionPoint<ResourceHandlerProvider>
{
    /** Avalon Role */
    public static final String ROLE = ResourceHandlerProviderExtensionPoint.class.getName();

    @Override
    protected boolean sortPriorityAscending()
    {
        return false;
    }
    
    /**
     * Get the extension of max priority matching the provided source, based on the registered suffixes
     * @param source The source
     * @return The corresponding extension
     * @throws Exception if an error occurs during ResourceHandler creation.
     */
    public ResourceHandler getResourceHandler(String source) throws Exception
    {
        return getExtensionsIds().stream()
                                 .map(this::getExtension)
                                 .map(LambdaUtils.wrap(provider -> provider.getResourceHandler(source)))
                                 .filter(Objects::nonNull)
                                 .findFirst()
                                 .orElse(_getDefaultResourceHandler());
    }
    
    private ResourceHandler _getDefaultResourceHandler() throws Exception
    {
        ResourceHandler handler = new DefaultResourceHandler();
        LifecycleHelper.setupComponent(handler, new SLF4JLoggerAdapter(getLogger()), _context, _cocoonManager, null);
        if (handler instanceof LogEnabled)
        {
            ((LogEnabled) handler).setLogger(getLogger());
        }
        
        return handler;
    }
}
