/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.core.schedule.progression;

import java.util.Map;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * Track a progression
 */
public sealed interface ProgressionTracker permits AbstractProgressionTracker 
{
    /**
     * Get the label
     * @return The label
     */
    public I18nizableText getLabel();
    
    /**
     * Get the id 
     * @return The id
     */
    public String getId();
    
    /**
     * Get the index of the current step
     * @return The index between [1 and size]
     */
    public long getIndex();
    
    /**
     * Get the size
     * @return The size
     */
    public long getSize();
    
    /**
     * Get the progression percentage, that can be simply {@link #getIndex()} / {@link #getSize()} or a more complex algorithm when handling children progressions
     * @return The progression (between 0 and 100)
     */
    public double asPercentage();
    
    /**
     * Get the progression tracker as a JSON
     * @return The progression tracker's JSON
     */
    public Map<String, Object> toJSON();
    
    /**
     * Get the parent progression tracker
     * @return the parent or null
     */
    ContainerProgressionTracker getParent();
}
