/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.servletwrapper.servlet;

import java.util.Enumeration;
import java.util.Map;

import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;

/**
 * The wrapped servlet configuration based on configuration parameters (as if there were a web.xml)
 */
public class ServletWrapperConfig implements ServletConfig
{
    private String _servletName;
    private ServletContext _servletContext;
    private Map<String, String> _parameters;
    private Enumeration<String> _enumParameters;
    
    /**
     * set the configuration
     * @param servletName servlet-name
     * @param servletContext Context
     * @param parameters init-param
     */
    public ServletWrapperConfig(String servletName, ServletContext servletContext, Map<String, String> parameters)
    {
        this._servletName = servletName;
        this._servletContext = servletContext;
        this._parameters = parameters;
        this._enumParameters = java.util.Collections.enumeration(parameters.keySet());
    }

    public String getServletName()
    {
        return this._servletName;
    }

    public ServletContext getServletContext()
    {
        return this._servletContext;
    }

    public String getInitParameter(String name)
    {
        return this._parameters.get(name);
    }

    public Enumeration<String> getInitParameterNames()
    {
        return this._enumParameters;
    }

}
