/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.user;

import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.Redirector;

/**
 * Component which:
 * <ul>
 *  <li>provides the {@link UserIdentity identity} of the current user.
 *  <li>can logout the the current user.
 * </ul>
 */
public interface CurrentUserProvider
{
    /** Avalon role. */
    public static final String ROLE = CurrentUserProvider.class.getName();

    /**
     * Provides the current logged user.
     * @return the current user or <code>null</code> if there is no logged user.
     */
    UserIdentity getUser();
    
    /**
     * Logout the current user if he can be.
     * @param redirector the redirector to use if a redirection needs to be perform for the logout. can be null when called during admin operation
     * @throws ProcessingException If an error occurred during the logout process
     */
    void logout(Redirector redirector) throws ProcessingException;
}
