/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.user.directory;

import org.ametys.core.user.UserIdentity;

/**
 * Exception when user is authenticated with a weak password
 */
public class WeakPasswordException extends Exception
{
    private UserIdentity _userIdentity;
    
    /**
     * Default constructor.
     * @param userIdentity The user identity with a weak password.
     */
    public WeakPasswordException(UserIdentity userIdentity)
    {
        _userIdentity = userIdentity;
    }

     /**
      * Constructor with a cause.
      * @param userIdentity The user identity with a weak password.
      * @param cause The cause.
      */
    public WeakPasswordException(UserIdentity userIdentity, Exception cause)
    {
        super(cause);
        _userIdentity = userIdentity;
    }

     /**
      * Constructor with a message and a cause.
      * @param userIdentity The user identity with a weak password.
      * @param message The message.
      * @param cause The cause.
      */
    public WeakPasswordException(UserIdentity userIdentity, String message, Exception cause)
    {
        super(message, cause);
        _userIdentity = userIdentity;
    }
    
    /**
     * Get the user identity concerned by this weak password exception
     * @return the user identity
     */
    public UserIdentity getUserIdentity()
    {
        return _userIdentity;
    }
}
