/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.util;

import java.io.IOException;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;

import org.apache.avalon.framework.component.Component;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;

/**
 * Serializer for {@link LocalDate}.
 * Returns the formatted date for JSON value to ISO 8601 standard format (e.g. 2013-02-28T17:13:50.000+02:00)
 */
public class LocalDateSerializer extends StdSerializer<LocalDate> implements Component
{
    /** The Avalon Role */
    public static final String ROLE = LocalDateSerializer.class.getName();
    
    /**
     * Constructor
     */
    public LocalDateSerializer()
    {
        super(LocalDate.class);
    }
    
    @Override
    public void serialize(LocalDate value, JsonGenerator jgen, SerializerProvider provider) throws IOException
    {
        jgen.writeString(value.format(DateTimeFormatter.ISO_LOCAL_DATE));
    }
}
