/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.util;

import java.util.Optional;

/**
 * A session provider allow to retrieve a value stored in session.
 * This interface allow for implementation able to handle case where the session doesn't exists
 */
public interface SessionAttributeProvider
{
    /** The avalon role */
    public static final String ROLE = SessionAttributeProvider.class.getName();
    
    /**
     * Retrieve a stored session attribute from the current request.
     * 
     * The stored attribute must be a String or the behavior is undefined and may throw an exception
     * @param attributeName the name of the attribute
     * @return the value of the attribute or empty if no value are stored for the given attribute
     */
    public Optional<Object> getSessionAttribute(String attributeName);
}
