/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.util;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;

import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.model.Enumerator;

/**
 * {@link Enumerator} for listing days of the week.
 */
public class WeekDaysEnumerator implements Enumerator<Long>
{
    private static final Map<Long, I18nizableText> __WEEK_DAYS;
    
    static
    {
        __WEEK_DAYS = new LinkedHashMap<>(7);
        __WEEK_DAYS.put(Long.valueOf(1), new I18nizableText("plugin.core", "PLUGINS_CORE_WEEK_DAYS_MONDAY"));
        __WEEK_DAYS.put(Long.valueOf(2), new I18nizableText("plugin.core", "PLUGINS_CORE_WEEK_DAYS_TUESDAY"));
        __WEEK_DAYS.put(Long.valueOf(3), new I18nizableText("plugin.core", "PLUGINS_CORE_WEEK_DAYS_WEDNESDAY"));
        __WEEK_DAYS.put(Long.valueOf(4), new I18nizableText("plugin.core", "PLUGINS_CORE_WEEK_DAYS_THURSDAY"));
        __WEEK_DAYS.put(Long.valueOf(5), new I18nizableText("plugin.core", "PLUGINS_CORE_WEEK_DAYS_FRIDAY"));
        __WEEK_DAYS.put(Long.valueOf(6), new I18nizableText("plugin.core", "PLUGINS_CORE_WEEK_DAYS_SATURDAY"));
        __WEEK_DAYS.put(Long.valueOf(7), new I18nizableText("plugin.core", "PLUGINS_CORE_WEEK_DAYS_SUNDAY"));
    }
    
    public Map<Long, I18nizableText> getTypedEntries() throws Exception
    {
        return Collections.unmodifiableMap(__WEEK_DAYS);
    }
    
    public I18nizableText getEntry(Long value) throws Exception
    {
        return __WEEK_DAYS.get(value);
    }
}
