/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.util.filereloader;

import java.io.InputStream;

import org.apache.excalibur.source.Source;

/**
 * Represents a class able to handle a reloadable configuration file
 */
public interface FileReloader
{
    /**
     * Update the file, the sourceUrl is only there if you manage multiple files, the Configuration object is already present to read it
     * @param sourceUrl the url of the file.
     * @param source the source to read, can be null if no file was read
     * @param is the input stream to read, can be null if no file was read
     * @throws Exception something went wrong while reading the inputstream
     */
    public void updateFile(String sourceUrl, Source source, InputStream is) throws Exception;
    
    /**
     * Get an unique ID for this File Reloader
     * @param sourceUrl this is passed as an argument if your class read multiple files.
     * If it reads only one file, the full class name can be a good enough ID
     * @return an unique ID
     */
    public String getId(String sourceUrl);
    
}
