/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.util.ldap;

import javax.naming.SizeLimitExceededException;

/**
 * Exception when the LDAP refused to return all the results.
 * The exception contains the partial result.
 */
public class IncompleteLDAPResultException extends Exception
{
    private Object _partialResults;

    /**
     * Constructor
     * @param <T> The type of the partial results
     * @param partialResults The partial results
     * @param e The wrapped exception such as a {@link SizeLimitExceededException}
     */
    public <T extends Object> IncompleteLDAPResultException(T partialResults, Exception e)
    {
        super(e);
        _partialResults = partialResults;
    }
    
    /**
     * Get the partial results
     * @param <T> The type of the partial results
     * @return the partial results
     */
    @SuppressWarnings("unchecked")
    public <T extends Object> T getPartialResults()
    {
        return (T) _partialResults;
    }
}
