/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.authentication;

import java.io.File;

import org.apache.avalon.framework.activity.Initializable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.core.util.CryptoHelper;
import org.ametys.runtime.util.AmetysHomeHelper;

/**
 *  Helper to encrypt/decrypt multifactor authentication secrets for a specific user population
 */
public class MultifactorAuthenticationCryptoHelper extends CryptoHelper implements Initializable
{
    /** The prefix of file storing the key to encrypt/decrypt users' secrets for multifactor authentication */
    private static final String __MFA_KEY_FILE_PREFIX = "mfa/mfa_";
    
    @Override
    protected String _configureFilename(Configuration configuration) throws ConfigurationException
    {
        String userPopulationId = configuration.getChild("userPopulationId").getValue();
        return __MFA_KEY_FILE_PREFIX + userPopulationId;
    }
    
    public void initialize() throws Exception
    {
        File mfaKeyFile = new File(AmetysHomeHelper.getAmetysHomeConfig(), _getFilename());

        if (!mfaKeyFile.exists())
        {
            if (!mfaKeyFile.getParentFile().exists())
            {
                mfaKeyFile.getParentFile().mkdirs();
            }
            
            mfaKeyFile.createNewFile();
            _writeKeyInFile(mfaKeyFile);
        }   
    }
    
    @Override
    public String getCryptoKey()
    {
        File cryptoFile = new File(AmetysHomeHelper.getAmetysHomeConfig(), _getFilename());
        if (!cryptoFile.exists())
        {
            getLogger().error("Unable to read the crypto key in file {}. This file does not exist", cryptoFile.getAbsolutePath());
            return null;
        }
        else
        {
            return super.getCryptoKey();
        }
    }
}
