/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.search;

import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.avalon.framework.thread.ThreadSafe;
import org.apache.cocoon.acting.AbstractAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.core.cocoon.JSonReader;
import org.ametys.core.user.CurrentUserProvider;
import org.ametys.runtime.authentication.AccessDeniedException;

/**
 * Get users and groups, by context, sorted alphabetically
 */
public class UserAndGroupSearchAction extends AbstractAction implements ThreadSafe, Serviceable
{
    private CurrentUserProvider _userProvider;

    private UserAndGroupSearchManager _userAndGroupSearchManager;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _userProvider = (CurrentUserProvider) manager.lookup(CurrentUserProvider.ROLE);
        _userAndGroupSearchManager = (UserAndGroupSearchManager) manager.lookup(UserAndGroupSearchManager.ROLE);
    }
    

    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        if (_userProvider.getUser() == null)
        {
            throw new AccessDeniedException("Anonymous user tried to access to users list");
        }
        
        @SuppressWarnings("unchecked")
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        @SuppressWarnings("unchecked")
        Set<String> contexts = new HashSet<>((List<String>) jsParameters.get("contexts"));
        @SuppressWarnings("unchecked")
        Map<String, Object> searchData = (Map<String, Object>) jsParameters.getOrDefault("searchData", null);

        Map<String, Object> params = new HashMap<>();
        params.put("pattern", source);
        params.put("sort", true);
        int limit = parameters.getParameterAsInteger("limit", Integer.MAX_VALUE);
        
        Map<String, Object> result = _userAndGroupSearchManager.searchUsersAndGroupByContext(contexts, limit, searchData, params, true);

        Request request = ObjectModelHelper.getRequest(objectModel);
        request.setAttribute(JSonReader.OBJECT_TO_READ, result);

        return EMPTY_MAP;
    }
}
