/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.user;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.cocoon.servlet.multipart.Part;

import org.ametys.core.cocoon.JSonReader;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * Import users from a CSV or text file.
 */
public class ImportUsersAction extends ServiceableAction
{
    /** import user component */
    protected ImportUsers _importUser;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _importUser = (ImportUsers) smanager.lookup(ImportUsers.ROLE);
    }
    
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);

        String userDirectories = request.getParameter("userDirectories");
        String[] split = userDirectories.split("#", 2);
        if (split == null || split.length != 2)
        {
            Map<String, Object> result = new HashMap<>();
            result.put("success", false);
            result.put("error", "user-directory");
            result.put("message", new I18nizableText("plugin.core", "PLUGINS_CORE_USERS_IMPORT_ERROR_USER_DIRECTORIES"));
            request.setAttribute(JSonReader.OBJECT_TO_READ, result);
            return EMPTY_MAP;
        }
        String populationId = split[0];
        String userDirectoryId = split[1];
        boolean cleanDirectory = "true".equals(request.getParameter("cleanDirectory"));
        
        Part part = (Part) request.get("importFile");
        
        Map<String, Object> result = _importUser.importUsers(part, populationId, userDirectoryId, cleanDirectory);
        
        request.setAttribute(JSonReader.OBJECT_TO_READ, result);
        return EMPTY_MAP;
    }
}
