/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.workspaces.admin.authentication;

import java.util.Collections;
import java.util.List;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.environment.Request;

import org.ametys.core.authentication.AuthenticateAction;
import org.ametys.core.right.RightManager;
import org.ametys.runtime.plugin.PluginsManager;

/**
 * Cocoon action for authenticating users in the administration workspace. 
 */
public class AdminAuthenticateAction extends AuthenticateAction
{
    /** The runtime rights manager */
    protected RightManager _rightManager;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _rightManager = (RightManager) manager.lookup(RightManager.ROLE);
    }
    
    @Override
    protected Set<String> _getAvailableUserPopulationsIds(Request request, List<String> contexts)
    {
        if (PluginsManager.getInstance().isSafeMode() || _userPopulationDAO.getEnabledUserPopulations(false).isEmpty())
        {
            return Collections.singleton(_userPopulationDAO.getAdminPopulation().getId());
        }
        else
        {
            return super._getAvailableUserPopulationsIds(request, contexts);
        }
    }
}
