/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.framework;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.core.group.GroupDirectoryDAO;
import org.ametys.core.group.GroupIdentity;
import org.ametys.core.user.UserIdentity;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;

/**
 * Abstract test case providing a population and users.
 */
@NeedFeatures({
    "core/runtime.groups.manager", 
    "core-impl/runtime.group.directory.impl.static"
})
public abstract class AbstractGroupDirectoriesAwareTestCase extends AbstractPopulationAwareTestCase
{
    /** The id of the test population. It is already created and removed. */
    protected static final String DIRECTORY_TEST_ID = "static";
    
    /** The test group 'group1' */
    protected static final GroupIdentity GROUP1_TEST_IDENTITY = new GroupIdentity("group1", DIRECTORY_TEST_ID);
    /** The test group 'group2' */
    protected static final GroupIdentity GROUP2_TEST_IDENTITY = new GroupIdentity("group2_without_users", DIRECTORY_TEST_ID);
    /** The test group 'group3' */
    protected static final GroupIdentity GROUP3_TEST_IDENTITY = new GroupIdentity("group3", DIRECTORY_TEST_ID);
    
    /** The group directory DAO */
    protected static GroupDirectoryDAO _groupDirectoryDAO;
    
    @Override
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        super.lookupComponents(manager);
        _groupDirectoryDAO = (GroupDirectoryDAO) manager.lookup(GroupDirectoryDAO.ROLE);
    }
    
    @Override
    public void prepareComponents() throws Exception
    {
        super.prepareComponents();
        _createDirectory();
    }
    
    private static void _createDirectory()
    {
        String ugModelId = "org.ametys.plugins.core.group.directory.static";
        Map<String, String> params = new HashMap<>();
        String groupAsString = GROUP1_TEST_IDENTITY.getId() + ":group1:" + UserIdentity.userIdentityToString(USER1_TEST_IDENTITY) + "\n"
                + GROUP2_TEST_IDENTITY.getId() + "\n"
                + GROUP3_TEST_IDENTITY.getId() + ":another group:" + UserIdentity.userIdentityToString(USER3_TEST_IDENTITY);
        params.put(ugModelId + "$runtime.groups.static.group", groupAsString);
        _groupDirectoryDAO.add(DIRECTORY_TEST_ID, "Static group directory", ugModelId, params);
    }
    
    @Override
    protected void essentialsAfter() throws Exception
    {
        _removeGroupDirectory();
        super.essentialsAfter();
    }
    
    private static void _removeGroupDirectory()
    {
        boolean hasTestDirectory = false;
        try
        {
            hasTestDirectory = _groupDirectoryDAO != null && _groupDirectoryDAO.getGroupDirectory(DIRECTORY_TEST_ID) != null;
        }
        catch (Exception e)
        {
            // Silently ignore, Cocoon must have been not well loaded for instance, etc.
        }
        
        if (hasTestDirectory)
        {
            _groupDirectoryDAO.remove(DIRECTORY_TEST_ID);
        }
    }
}
