/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.framework;

import java.util.Optional;

import org.ametys.runtime.data.AmetysHomeLock;

/**
 * A wrapper of {@link AmetysHomeLock} as an optional lock needs to be retrieved even if an exception is thrown.
 */
public class AmetysHomeLockWrapper
{
    private AmetysHomeLock _lock;

    /**
     * Constructs an empty wrapper
     */
    public AmetysHomeLockWrapper()
    {
    }
    
    void setLock(AmetysHomeLock lock)
    {
        _lock = lock;
    }
    
    /**
     * Gets the optional {@link AmetysHomeLock}
     * @return the optional {@link AmetysHomeLock}
     */
    public Optional<AmetysHomeLock> getLock()
    {
        return Optional.ofNullable(_lock);
    }
}
