/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.framework;

import org.junit.runner.Runner;
import org.junit.runner.notification.RunNotifier;
import org.junit.runners.BlockJUnit4ClassRunner;
import org.junit.runners.model.InitializationError;
import org.slf4j.LoggerFactory;

/**
 * {@link Runner} for {@link AbstractBaseTestCase}
 */
public class AmetysJUnitClassRunner extends BlockJUnit4ClassRunner
{
    private BeforeAndAfterClassTestCase _testCase;
    
    /**
     * Creates a AmetysJUnitClassRunner to run {@code klass}
     * @param klass The {@link Class} of the Test Case
     * @throws InitializationError if the test class is malformed.
     */
    public AmetysJUnitClassRunner(Class< ? > klass) throws InitializationError
    {
        super(klass);
    }
    
    @Override
    protected Object createTest() throws Exception
    {
        Object test = super.createTest();
        if (test instanceof BeforeAndAfterClassTestCase && _testCase == null)
        {
            _testCase = (BeforeAndAfterClassTestCase) test;
            _testCase.beforeClass();
        }
        return test;
    }
    
    @Override
    public void run(RunNotifier notifier)
    {
        super.run(notifier);
        if (_testCase != null)
        {
            try
            {
                _testCase.afterClass();
            }
            catch (Exception e)
            {
                LoggerFactory.getLogger(getClass()).error("An error occured when doing #afterClass: \n{}", e);
            }
        }
        // We call this manually in order to have these logs to be the last ones
        AbstractBaseTestCase.baseAfterClass();
    }
}
