/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.framework;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;

/**
 * Represents a Runtime for an Ametys application (source being a raw String or a File).
 */
public final class AmetysRuntime
{
    private String _runtimeContent;
    private String _runtimeContentSource;
    
    private File _runtimeFile;
    
    private AmetysRuntime()
    {  }
    
    static AmetysRuntime fromFile(String filePathName)
    {
        AmetysRuntime runtime = new AmetysRuntime();
        runtime._runtimeFile = new File(filePathName);
        return runtime;
    }
    
    static AmetysRuntime fromContent(String content, String source)
    {
        AmetysRuntime runtime = new AmetysRuntime();
        runtime._runtimeContent = content;
        runtime._runtimeContentSource = source;
        return runtime;
    }
    
    boolean isFromFile()
    {
        return _runtimeFile != null;
    }
    
    InputStream getInputStream() throws FileNotFoundException
    {
        return _runtimeContent == null
                ? new FileInputStream(_runtimeFile)
                : new ByteArrayInputStream(_runtimeContent.getBytes(StandardCharsets.UTF_8));
    }
    
    String getSystemId()
    {
        return _runtimeContent == null
                ? _runtimeFile.getAbsolutePath()
                : _runtimeContentSource;
    }
    
    File getRuntimeFile()
    {
        return _runtimeFile;
    }
    
    @Override
    public String toString()
    {
        return "AmetysRuntime [" + (_runtimeContent == null ? _runtimeFile.getPath() : "STATIC CONTENT FROM " + _runtimeContentSource) + "]";
    }
}

