/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.framework;

import java.util.Optional;

import org.apache.commons.lang3.exception.ExceptionUtils;

import org.ametys.runtime.plugin.PluginIssue;
import org.ametys.runtime.plugin.PluginsManager;
import org.ametys.runtime.plugin.PluginIssue.PluginIssueCode;

import com.google.common.base.Predicates;

/**
 * Implements this interface if your Test Case needs to check the exception returned from the initialization of Cocoon.
 * <br>Be sure to implement {@link CocoonTestCase} as well or to manually call {@link AbstractRuntimeTestCase#startCocoon(TestConfigSet, java.util.Collection) startCocoon}.
 * <br>This interface is just a helper providing the method {@link #getInitializationException()} to easily retrieve the initialization exception.
 */
public interface PluginInitializationFailureTestCase
{
    /**
     * Retrieves the initialization exception from PluginManager errors
     * @return the initialization exception
     */
    default Optional<Throwable> getInitializationException()
    {
        return PluginsManager.getInstance()
                .getErrors()
                .stream()
                .filter(Predicates.compose(Predicates.equalTo(PluginIssueCode.INITIALIZATION_EXCEPTION), PluginIssue::getCode))
                .findFirst()
                .map(PluginIssue::getCause)
                .map(ExceptionUtils::getRootCause);
    }
}
