/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.framework;

import static java.lang.annotation.ElementType.TYPE_USE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * By default, all interfaces handled by {@link AbstractRuntimeTestCase} (such as {@link ScriptTestCase}, {@link CocoonTestCase}...)
 * do their processing (such as running a script, start a Cocoon application...) once {@link BeforeAndAfterClassTestCase#beforeClass() before} 
 * any test and once {@link BeforeAndAfterClassTestCase#afterClass() after} all tests, for performance purposes.
 * <br>If your test needs to do those processings before each test and after each test, you must annotate your Test Case class
 * with this annotation.
 */
@Retention(RUNTIME)
@Target(TYPE_USE)
@Inherited
public @interface Unoptimized
{
    // Nothing
}
