/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.framework;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;

class VariableHandler
{
    private Map<String, String> _variableValues;

    VariableHandler(AbstractRuntimeTestCase test, DatabaseProperties dbProperties)
    {
        _initVariableValues(test, dbProperties);
    }
    
    private void _initVariableValues(AbstractRuntimeTestCase test, DatabaseProperties dbProperties)
    {
        if (test instanceof CocoonTestCase)
        {
            _variableValues = new HashMap<>(((CocoonTestCase) test).variableValues());
        }
        else
        {
            _variableValues = new HashMap<>();
        }
        dbProperties.addVariables(_variableValues);
    }
    
    Map<String, String> variableValues()
    {
        return _variableValues;
    }
    
    // for logging purposes, hide passwords
    Map<String, String> variableValuesWithHiddenPasswords()
    {
        return _variableValues.entrySet()
                .stream()
                .map(e ->
                {
                    String k = e.getKey();
                    if (StringUtils.containsIgnoreCase(k, "password"))
                    {
                        return Map.entry(k, "****");
                    }
                    else
                    {
                        return Map.entry(k, e.getValue());
                    }
                })
                .collect(Collectors.toMap(Entry::getKey, Entry::getValue));
    }
}
