/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.rights.access.controller;

import java.util.ArrayList;
import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.junit.Assert;

import org.ametys.core.right.AccessController;
import org.ametys.core.right.AccessControllerExtensionPoint;
import org.ametys.core.right.Profile;
import org.ametys.core.right.ProfileAssignmentStorageExtensionPoint;
import org.ametys.core.right.RightManager;
import org.ametys.core.right.RightProfilesDAO;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;
import org.ametys.runtime.test.framework.TestConfigSet;

/**
 * Common test class for testing the {@link AccessController}
 */
@NeedFeatures({
    "core/runtime.rights.profiles.dao", 
    "core/runtime.rights.manager", 
    "core/runtime.rights.profiles.dao", 
    "core/runtime.rights.assignments.observer",
})
public abstract class AbstractAccessControllerTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    /** The access controller to test */
    protected static AccessController _accessController;
    
    /** The extension point for profile assignment storage */
    protected static ProfileAssignmentStorageExtensionPoint _profileAssignmentStorageEP;

    /** The right manager */
    protected static RightManager _rightManager;
    /** The profiles DAO */
    protected static RightProfilesDAO _profilesDAO;
    /** The ids of profiles */
    protected List<String> _profileIds;
    
    @Override
    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp4");
    }
    
    @Override
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        AccessControllerExtensionPoint accessControllerEP = (AccessControllerExtensionPoint) manager.lookup(AccessControllerExtensionPoint.ROLE);
        String accessControllerId = _getExtensionId();
        _accessController = accessControllerEP.getExtension(accessControllerId);
        Assert.assertNotNull("The #_getExtensionId() method ('" + accessControllerId + "') does not point to an AccessController extension", _accessController);
        _profileAssignmentStorageEP = (ProfileAssignmentStorageExtensionPoint) manager.lookup(ProfileAssignmentStorageExtensionPoint.ROLE);
        _rightManager = (RightManager) manager.lookup(RightManager.ROLE);
        _profilesDAO = (RightProfilesDAO) manager.lookup(RightProfilesDAO.ROLE);
    }
    
    /**
     * Returns the id of the extension for {@link AccessController} to use.
     * @return the id of the extension to use.
     */
    protected String _getExtensionId()
    {
        return "org.ametys.runtime.test.rights.TestAccessController";
    }
    
    /**
     * Init the profiles db
     */
    protected void initProfiles()
    {
        for (Profile profile : _profilesDAO.getProfiles())
        {
            _profilesDAO.deleteProfile(profile);
        }
        _profileIds = new ArrayList<>();
        
        Profile newProfile;
        
        newProfile = _profilesDAO.addProfile("1");
        _profileIds.add(newProfile.getId());
        _profilesDAO.addRight(newProfile, "right1");
        _profilesDAO.addRight(newProfile, "right12");
        _profilesDAO.addRight(newProfile, "rightall");
        
        newProfile = _profilesDAO.addProfile("2");
        _profileIds.add(newProfile.getId());
        _profilesDAO.addRight(newProfile, "right2");
        _profilesDAO.addRight(newProfile, "right12");
        _profilesDAO.addRight(newProfile, "rightall");
        
        newProfile = _profilesDAO.addProfile("3");
        _profileIds.add(newProfile.getId());
        _profilesDAO.addRight(newProfile, "right3");
        _profilesDAO.addRight(newProfile, "rightall");
        
        newProfile = _profilesDAO.addProfile("4");
        _profileIds.add(newProfile.getId());
        _profilesDAO.addRight(newProfile, "right4");
        _profilesDAO.addRight(newProfile, "rightall");
        
        newProfile = _profilesDAO.addProfile("5");
        _profileIds.add(newProfile.getId());
        _profilesDAO.addRight(newProfile, "right5");
        _profilesDAO.addRight(newProfile, "rightall");
        
        newProfile = _profilesDAO.addProfile("6");
        _profileIds.add(newProfile.getId());
        _profilesDAO.addRight(newProfile, "right6");
        _profilesDAO.addRight(newProfile, "right67");
        _profilesDAO.addRight(newProfile, "rightall");
        
        newProfile = _profilesDAO.addProfile("7");
        _profileIds.add(newProfile.getId());
        _profilesDAO.addRight(newProfile, "right7");
        _profilesDAO.addRight(newProfile, "right67");
        _profilesDAO.addRight(newProfile, "rightall");
    }
}
