/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
 
// Freely inspired from Lee Boonstra https://github.com/savelee/sencha-theming-tutorial
var tools3Items = [
    {
        xtype: 'panel',
        x: 10,
        y: 10,
        height: 150,
        maxWidth: 150,
        title: 'Regular Panel',
        tools: [
            {
                xtype: 'tool'
            }
        ]
    },
    {
        xtype: 'panel',
        x: 175,
        y: 10,
        height: 150,
        maxWidth: 150,
        ui: 'light',
        title: 'Regular Light Panel',
        tools: [
            {
                xtype: 'tool'
            }
        ]
    },
    {
        xtype: 'panel',
        x: 330,
        maxWidth: 150,
        y: 10,
        frame: true,
        height: 150,
        title: 'Framed Panel',
        tools: [
            {
                xtype: 'tool'
            }
        ]
    },
    {
        xtype: 'panel',
        x: 490,
        y: 10,
        frame: true,
        height: 150,
        width: 150,
        collapsible: true,
        titleCollapse: true,
        ui: 'light',
        title: 'Framed Light Panel',
        tools: [
            {
                xtype: 'tool'
            }
        ]
    },
    {
        xtype: 'panel',
        x: 700,
        y: 10,
        height: 150,
        width: 150,
        collapsed: true,
        collapsible: true,
        title: 'Collapsed Panel'
    },

    {
        xtype: 'tabpanel',
        x: 910,
        y: 10,
        height: 150,
        width: 200,
        activeTab: 0,
        border: true,
        items: [
            {
                xtype: 'panel',
                title: 'Tab 1',
                html: 'text'
            },
            {
                xtype: 'panel',
                title: 'Tab 2'
            },
            {
                xtype: 'panel',
                title: 'Tab 3',
                tabConfig: {
                    xtype: 'tab',
                    disabled: true
                }
            }
        ]
    },
    {
        xtype: 'tabpanel',
        
        x: 1120,
        y: 10,
        plain: true,
        height: 150,
        width: 200,
        activeTab: 0,
        items: [
            {
                xtype: 'panel',
                title: 'Tab 1',
                border: true,
                html: 'text'
            },
            {
                xtype: 'panel',
                border: true,
                title: 'Tab 2'
            },
            {
                xtype: 'panel',
                title: 'Tab 3',
                border: true,
                tabConfig: {
                    xtype: 'tab',
                    disabled: true
                }
            }
        ]
    },
    {
        xtype: 'tabpanel',
        
        x: 1340,
        y: 10,
        plain: true,
        border: true,
        height: 150,
        width: 200,
        activeTab: 0,
        items: [
            {
                xtype: 'panel',
                title: 'Tab 1',
                border: true,
                html: 'text'
            },
            {
                xtype: 'panel',
                border: true,
                title: 'Tab 2'
            },
            {
                xtype: 'panel',
                title: 'Tab 3',
                border: true,
                tabConfig: {
                    xtype: 'tab',
                    disabled: true
                }
            }
        ]
    },
    {
        xtype: 'menu',
        x: 10,
        y: 170,
        floating: false,
        width: 120,
        items: [
            {
                xtype: 'menuitem',
                text: 'Menu Item',
                focusable: true
            },
            {
                xtype: 'menuitem',
                disabled: true,
                text: 'Menu Item',
                focusable: true
            },
            {
                xtype: 'menuseparator',
                focusable: true
            },
            {
                xtype: 'menucheckitem',
                text: 'Menu Item',
                focusable: true
            },
            {
                xtype: 'menucheckitem',
                text: 'Menu Item',
                focusable: true,
                checked: true
            }
        ]
    },

    {
        xtype: 'panel',
        x: 10,
        y: 330,
        width: 280,
        items: [
            {
                xtype: 'checkboxfield',
                fieldLabel: 'Checkbox',
                checked: true
            },
            {
                xtype: 'datefield',
                fieldLabel: 'Date Field'
            },
            {
                xtype: 'filefield',
                fieldLabel: 'File Upload'
            },
            {
                xtype: 'combobox',
                fieldLabel: 'ComboBox',
                store: [
                    'icecream',
                    'chocolate',
                    'popcorn'
                ]
            },
            {
                xtype: 'tagfield',
                fieldLabel: 'Select a Show',
                store: Ext.create('Ext.data.Store', {
                      fields: ['id','show'],
                      data: [
                          {id: 0, show: 'Battlestar Galactica'},
                          {id: 1, show: 'Doctor Who'},
                          {id: 2, show: 'Farscape'},
                          {id: 3, show: 'Firefly'},
                          {id: 4, show: 'Star Trek'},
                          {id: 5, show: 'Star Wars: Christmas Special'}
                      ]
                   }),
                displayField: 'show',
                valueField: 'id',
                queryMode: 'local',
                value: [0, 1],
                filterPickList: true
            }
        ]
    },

    {
        xtype: 'fieldset',
        x: 300,
        y: 380,
        title: 'legend',
        layout: 'form',
        items: [{
            xtype: 'textfield',
            fieldLabel: 'Text',
            allowBlank: false,
            maxLength: 2,
            value: "2222",
            emptyText: "placeholder"
        }],
        width: 260
    },
    {
        xtype: 'htmleditor',
        x: 10,
        y: 510,
        height: 150,
        width: 650,
        fieldLabel: 'HTML Editor'
    },
    {
        xtype: 'numberfield',
        x: 10,
        y: 660,
        fieldLabel: 'Number Field'
    },
    {
        xtype: 'radiofield',
        x: 10,
        y: 690,
        fieldLabel: 'Radio'
    },
    {
        xtype: 'radiofield',
        x: 150,
        y: 690,
        fieldLabel: 'Radio',
        checked: true
    },
    {
        xtype: 'textareafield',
        x: 640,
        y: 685,
        fieldLabel: 'Text Area',
        width: 320
    },
    {
        xtype: 'textfield',
        x: 330,
        y: 720,
        value: 'Default',
        fieldLabel: 'Text Field'
    },
    {
        xtype: 'timefield',
        x: 330,
        y: 685,
        fieldLabel: 'Time Field'
    },
    {
        xtype: 'colormenu',
        x: 620,
        y: 170,
        floating: false,
        height: 150,
        width: 150
    },
    /*{
        xtype: 'datemenu',
        x: 780,
        y: 170,
        floating: false,
        width: 300
    },*/
            {
        xtype: 'gridpanel',
        x: 780,
        y: 170,
        border: true, 
        height: 250,
        width: 450,
        title: 'Grid Panel',
        bbar: [{
            xtype: 'pagingtoolbar',
            store: Ext.create('Ext.data.Store', {
                fields: ['name', 'gender', {
                    name: 'age',
                    type: 'int'
                }],
                data: [
                    {
                        name: 'Joe',
                        gender: 'male',
                        age: 36
                    },
                    {
                        name: 'Anna',
                        gender: 'female',
                        age: 29
                    },
                    {
                        name: 'Frederick',
                        gender: 'male',
                        age: 74
                    }
                ]
            }),
            displayInfo: true,
            displayMsg : 'Displaying topics {0} - {1} of {2}'
        }],
        store: Ext.create('Ext.data.Store', {
            fields: ['name', 'gender', {
                name: 'age',
                type: 'int'
            }],
            data: [
                {
                    name: 'Joe',
                    gender: 'male',
                    age: 36
                },
                {
                    name: 'Anna',
                    gender: 'female',
                    age: 29
                },
                {
                    name: 'Frederick',
                    gender: 'male',
                    age: 74
                }
            ]
        }),
        columns: [
            {
                xtype: 'gridcolumn',
                dataIndex: 'name',
                text: 'Name',
                flex: 1
            },
            {
                xtype: 'gridcolumn',
                dataIndex: 'gender',
                text: 'Gender'
            },
            {
                xtype: 'numbercolumn',
                dataIndex: 'age',
                text: 'Age'
            }
        ]
    },


    {
        xtype: 'button',
        x: 680,
        y: 450,
        text: 'Small Button'
    },
    {
        xtype: 'button',
        x: 680,
        y: 600,
        disabled: true,
        text: 'Disabled Button'
    },
    {
        xtype: 'button',
        x: 680,
        y: 490,
        scale: 'medium',
        text: 'Medium Button'
    },
    {
        xtype: 'button',
        x: 680,
        y: 540,
        scale: 'large',
        text: 'Large Button'
    },
    {
        xtype: 'progressbar',
        x: 570,
        y: 390,
        width: 200,
        value: 0.4
    },
    {
        xtype: 'progressbar',
        x: 570,
        y: 415,
        width: 200,
        value: 0.6
    },
    {
        xtype: 'toolbar',
        x: 10,
        y: 800,
        maxWidth: 850,
        items: [
            {
                xtype: 'button',
                text: 'Small Button'
            },
            {
                xtype: 'button',
                scale: 'medium',
                text: 'Medium Button'
            },
            {
                xtype: 'button',
                scale: 'large',
                text: 'Large Button'
            },
            {
                xtype: 'tbseparator'
            },
            {
                xtype: 'button',
                disabled: true,
                text: 'Disabled Button'
            },
            {
                xtype: 'cycle',
                showText: true,
                menu: {
                    xtype: 'menu',
                    width: 120,
                    items: [
                        {
                            xtype: 'menucheckitem',
                            text: 'Menu Item',
                            focusable: true
                        },
                        {
                            xtype: 'menucheckitem',
                            text: 'Menu Item',
                            focusable: true
                        },
                        {
                            xtype: 'menucheckitem',
                            text: 'Menu Item',
                            focusable: true
                        }
                    ]
                }
            },
            {
                xtype: 'splitbutton',
                text: 'Split Button'
            }
        ]
    },
    {
        xtype: 'treepanel',
        x: 370,
        y: 170,
        height: 200,
        width: 200,
        title: 'Tree Panel',
        store: Ext.create('Ext.data.TreeStore', {
            fields: [
                {
                    type: 'string',
                    name: 'id'
                },
                {
                    type: 'string',
                    name: 'text'
                }
            ],
            root: {
                expanded: true,
                children: [
                    {
                        text: 'Trees',
                        leaf: false,
                        expanded: true,
                        children: [
                            {
                                text: 'Oak',
                                leaf: true
                            },
                            {
                                text: 'Pine',
                                leaf: true
                            }
                        ]
                    }
                ]
            }
        })
    },
    {
        xtype: 'cycle',
        x: 840,
        y: 450,
        showText: true,
        menu: {
            xtype: 'menu',
            width: 120,
            items: [
                {
                    xtype: 'menucheckitem',
                    text: 'Menu Item',
                    focusable: true
                },
                {
                    xtype: 'menucheckitem',
                    text: 'Menu Item',
                    focusable: true
                },
                {
                    xtype: 'menucheckitem',
                    text: 'Menu Item',
                    focusable: true
                }
            ]
        }
    },
    {
        xtype: 'splitbutton',
        x: 840,
        y: 490,
        text: 'Split Button'
    },
    {
        xtype: 'button',
        x: 840,
        y: 570,
        ui: 'confirm',
        text: 'ui: confirm'
    },
    {
        xtype: 'button',
        x: 840,
        y: 610,
        ui: 'back',
        text: 'ui: back'
    },
    {
        xtype: 'button',
        x: 840,
        y: 680,
        ui: 'forward',
        text: 'ui: forward'
    },
    {
        xtype: 'button',
        x: 980,
        y: 440,
        ui: 'round',
        text: 'round: small'
    },
    {
        xtype: 'button',
        x: 980,
        y: 490,
        glyph: '88@Spotifinder',
        scale: 'medium',
        ui: 'round',
        text: 'round: medium'
    },
    {
        xtype: 'button',
        x: 980,
        y: 560,
        scale: 'large',
        ui: 'round',
        text: 'round: large'
    },
    {
        xtype: 'button',
        x: 980,
        y: 640,
        ui: 'gray',
        text: 'gray: small'
    },
    {
        xtype: 'button',
        x: 980,
        y: 690,
        glyph: '88@Spotifinder',
        scale: 'medium',
        ui: 'gray',
        text: 'gray: medium'
    },
    {
        xtype: 'button',
        x: 980,
        y: 750,
        scale: 'large',
        ui: 'gray',
        text: 'large: large'
    },
    {
        xtype: 'panel',
        x: 10,
        y: 870,
        height: 500,
        width: 500,
        title : 'BorderLayout Panel',
        tools: [
            {type:'close'},
            {type:'minimize'},
            {type:'maximize'},
            {type:'restore'},
            {type:'gear'},
            {type:'pin'},
            {type:'unpin'},
            {type:'right'},
            {type:'left'},
            {type:'down'},
            {type:'refresh'},
            {type:'minus'},
            {type:'plus'},
            {type:'help'},
            {type:'search'},
            {type:'save'},
            {type:'print'}
        ],
        layout: {
            type: 'border'
        },
        collapsible: true,

        defaults: {
            collapsible: true,
            split      : true
        },

        items: [
            {
                title  : 'North',
                region : 'north',
                html   : 'North',
                height      : 100
            },
            {
                title       : 'South',
                region      : 'south',
                html        : 'South',
                collapseMode: 'mini',
                height      : 100
            },
            {
                title       : 'West',
                region      : 'west',
                html        : 'West',
                collapseMode: 'mini',
                width       : 150
            },
            {
                title  : 'East',
                region : 'east',
                html   : 'East',
                width  : 150
            },
            {
                title      : 'Center',
                region     : 'center',
                collapsible: false,
                html       : 'Center'
            }
        ]
    }, {
        x: 520,
        y: 870,
        xtype: 'panel',

        title : 'Accordion',
        collapsible: true,

        layout: 'accordion',

        items: [
            {
                title: 'Item 1',
                html: 'Some content'
            }, {
                title: 'Item 2',
                html : 'Some content'
            }, {
                title: 'Item 3',
                html: 'Some content'
            }
        ]
    }, {
        xtype: 'component',
        x: 520,
        y: 1100,
        style: 'background:transparent;overflow:hidden;',
        html: '<div style="margin:20px">Resizable handles</div>',
        resizable: {
            handles: 'all',
            pinned: true
        }
    },
    {
        xtype: 'multislider',
        x: 520,
        y: 1200,
        width: 400,
        fieldLabel: 'Multi Slider',
        values: [
            10,
            40
        ]
    }
];