/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.core.model.type;

import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.Optional;

import org.apache.commons.lang3.tuple.Triple;
import org.junit.Assert;
import org.junit.Test;

import org.ametys.runtime.model.compare.DataChangeType;
import org.ametys.runtime.model.compare.DataChangeTypeDetail;
import org.ametys.runtime.test.framework.AbstractBaseTestCase;

/**
 * Test cases for {@link ModelItemTypeHelperTestCase}
 */
public class ModelItemTypeHelperTestCase extends AbstractBaseTestCase
{
    /**
     * Tests the comparison between zoned date times that represent the same instant but in different zones
     * No difference should be retrieved. The only important thing in this comparison is the instant
     */
    @Test
    public void testCompareSingleDatesSameDatesInDifferentZone()
    {
        ZonedDateTime zonedDateTime = ZonedDateTime.of(2023, 11, 28, 14, 38, 45, 596_000_000, ZoneId.systemDefault());
        ZonedDateTime zonedDateTime2 = zonedDateTime.withZoneSameInstant(ZoneId.of("America/Puerto_Rico"));
        
        Optional<Triple<DataChangeType, DataChangeTypeDetail, String>> comparisonResult = ModelItemTypeHelper.compareSingleDates(zonedDateTime, zonedDateTime2, "data");
        Assert.assertTrue(comparisonResult.isEmpty());
    }
}
