/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.core.impl.model.type.xml;

import java.time.Month;
import java.time.ZonedDateTime;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.junit.Assert;
import org.junit.Test;

import org.ametys.runtime.model.type.ModelItemTypeConstants;
import org.ametys.runtime.model.type.ModelItemTypeExtensionPoint;
import org.ametys.runtime.model.type.xml.XMLElementType;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;
import org.ametys.runtime.test.framework.TestConfigSet;

/**
 * {@link DateTimeXMLElementType} implementation test case
 */
@NeedFeatures({
    "test/test-data-types",
})
public class DateTimeXMLElementTypeTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    private static ModelItemTypeExtensionPoint _testDataTypeExtensionPoint;
    private static XMLElementType<ZonedDateTime> _datetimeType;

    @Override
    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp-item-types-tests");
    }
    
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        _testDataTypeExtensionPoint = (ModelItemTypeExtensionPoint) manager.lookup(ModelItemTypeExtensionPoint.class.getName() + ".Test");
    }
    
    @SuppressWarnings("unchecked")
    @Override
    public void prepareComponents() throws Exception
    {
        _datetimeType = (XMLElementType<ZonedDateTime>) _testDataTypeExtensionPoint.getExtension(ModelItemTypeConstants.DATETIME_TYPE_ID);
    }
    
    /**
     * Test the method {@link DateXMLElementType#castValue(Object)}
     */
    @Test
    public void testCastValueWithStrinDateTime()
    {
        String value = "2018-05-18T14:15:31Z";
        ZonedDateTime date = _datetimeType.castValue(value);
        Assert.assertEquals(18, date.getDayOfMonth());
        Assert.assertEquals(Month.MAY, date.getMonth());
        Assert.assertEquals(2018, date.getYear());
        Assert.assertEquals(14, date.getHour());
    }
    
    /**
     * Test the method {@link DateXMLElementType#castValue(Object)} with a date with time info, including fraction of second
     */
    @Test
    public void testCastValueWithStrinDateTimeAndFractionOfSecond()
    {
        String value = "2018-05-18T14:15:31.000+02:00";
        ZonedDateTime date = _datetimeType.castValue(value);
        Assert.assertEquals(18, date.getDayOfMonth());
        Assert.assertEquals(Month.MAY, date.getMonth());
        Assert.assertEquals(2018, date.getYear());
    }
}
