/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.runtime.parameter;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.junit.Assert;
import org.junit.Test;

import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.TestConfigSet;

/**
 * Test of {@link  DefaultValidator}
 */
public class DefaultValidatorTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    @Override
    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp1");
    }
    
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        // Nothing to do
    }
    
    /**
     * Tests the {@link DefaultValidator#equals(Object)} method with two identical validators
     * Test the modifications made in the generated equals method of DefaultValidator
     */
    @Test
    public void testEqualsWithSameRegexp()
    {
        Validator validator1 = new DefaultValidator("[a-zA-Z]", new I18nizableText("Regexp invalide"), true);
        Validator validator2 = new DefaultValidator("[a-zA-Z]", new I18nizableText("Regexp invalide"), true);
        
        Assert.assertTrue(validator1.equals(validator2));
    }
    
    /**
     * Tests the {@link DefaultValidator#equals(Object)} method with two different validators.
     * Test the modifications made in the generated equals method of DefaultValidator
     */
    @Test
    public void testEqualsWithDifferentRegexp()
    {
        Validator validator1 = new DefaultValidator("[a-zA-Z]", new I18nizableText("Regexp invalide"), true);
        Validator validator2 = new DefaultValidator("[a-zA-Z0-9]", new I18nizableText("Regexp invalide"), true);
        
        Assert.assertFalse(validator1.equals(validator2));
    }
}
