/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.plugin;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.util.Collections;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.configuration.Configuration;

/**
 * Tests {@link ExcludePolicyFeatureActivator}
 */
public class ExcludePolicyFeatureActivatorTestCase extends AbstractFeatureActivatorTestCase
{
    @Override
    FeatureActivator _buildFeatureActivator(Configuration pluginConfiguration)
    {
        Map<String, Plugin> allPlugins = _buildPlugin(pluginConfiguration);
        FeatureActivator featureActivator = new ExcludePolicyFeatureActivator(allPlugins, Collections.EMPTY_LIST, Collections.EMPTY_LIST);
        return featureActivator;
    }
    
    @Override
    void _testChain(Configuration rootConfig) throws Exception
    {
        _test(rootConfig, 
                Set.of("A", "B", "C", "D", "E", "C-DEP"), 
                Set.of());
    }
    
    @Override
    void _testOneDeactivate(Configuration rootConfig) throws Exception
    {
        _test(rootConfig, 
                Set.of("D-d1", "D-d1-DEP", "C-DEP"),
                Set.of("A", "B", "C", "D", "E"));
    }
    
    @Override
    void _testOneOverride(Configuration rootConfig) throws Exception
    {
        _test(rootConfig, 
                Set.of("A", "B", "C", "D-o1", "C-DEP", "D-o1-DEP"),
                Set.of("D", "E"));
    }
    
    @Override
    void _testOneDeactivateAndOneOverride(Configuration rootConfig) throws Exception
    {
        _test(rootConfig, 
                Set.of("A", "B", "C", "D-d1", "D-o1", "C-DEP", "D-d1-DEP", "D-o1-DEP"),
                Set.of("D", "E"));
    }
    
    @Override
    void _testTwoDeactivates(Configuration rootConfig) throws Exception
    {
        _test(rootConfig, 
                Set.of("D-d1", "D-d2", "C-DEP", "D-d1-DEP", "D-d2-DEP"),
                Set.of("A", "B", "C", "D", "E"));
    }
    
    @Override
    void _testTwoOverrides(Configuration rootConfig) throws Exception
    {
        try
        {
            _computeFeatures(rootConfig);
            fail("It works while it should not.");
        }
        catch (Exception e)
        {
            _logger.info("Exception is: \n", e);
            assertTrue(e instanceof IllegalStateException);
            assertTrue(e.getMessage().contains("It cannot be overridden by 2 features"));
        }
    }
    
    @Override
    void _testTwoDeactivatesThroughDepend(Configuration rootConfig) throws Exception
    {
        _test(rootConfig, 
                Set.of("D-d1", "D-d21", "D-d2", "C-DEP", "D-d1-DEP", "D-d2-DEP"),
                Set.of("A", "B", "C", "D", "E"));
    }
    
    @Override
    void _testTwoOverridesThroughDepend(Configuration rootConfig) throws Exception
    {
        try
        {
            _computeFeatures(rootConfig);
            fail("It works while it should not.");
        }
        catch (Exception e)
        {
            _logger.info("Exception is: \n", e);
            assertTrue(e instanceof IllegalStateException);
            assertTrue(e.getMessage().contains("It cannot be overridden by 2 features"));
        }
    }
    
    @Override
    void _testOverrideInCascade(Configuration rootConfig) throws Exception
    {
        _test(rootConfig, 
                Set.of("A", "B", "C", "D-o3", "D-o3-DEP", "C-DEP", "D-o1-DEP", "D-o2-DEP"), 
                Set.of("D", "E", "D-o1", "D-o2"));
    }
}
