/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;
import org.junit.runners.Suite.SuiteClasses;

import org.ametys.core.model.type.ModelItemTypeHelperTestCase;
import org.ametys.core.util.CachedValueTestCase;
import org.ametys.core.util.DateUtilsTestCase;
import org.ametys.core.util.MapUtilsTestCase;
import org.ametys.core.util.dom.DOMUtilsTestCase;
import org.ametys.plugins.core.impl.model.type.xml.DateTimeXMLElementTypeTestCase;
import org.ametys.plugins.core.impl.model.type.xml.DateXMLElementTypeTestCase;
import org.ametys.runtime.config.AllConfigTestSuite;
import org.ametys.runtime.model.AllModelTestSuite;
import org.ametys.runtime.parameter.DefaultValidatorTestCase;
import org.ametys.runtime.plugin.AllFeatureActivatorTests;
import org.ametys.runtime.test.administrator.jvmstatus.RequestCountListenerTestCase;
import org.ametys.runtime.test.administrator.jvmstatus.SessionCountListenerTestCase;
import org.ametys.runtime.test.authentication.token.AllTokenTestSuite;
import org.ametys.runtime.test.cache.CacheTestSuite;
import org.ametys.runtime.test.cocoon.TraxProcessorTestCase;
import org.ametys.runtime.test.cocoon.XHTMLSerializerTestCase;
import org.ametys.runtime.test.groups.jdbc.AllGroupsTestSuite;
import org.ametys.runtime.test.groups.ldap.LdapGroupsBidirectionalTestCase;
import org.ametys.runtime.test.groups.ldap.LdapGroupsWithMemberOfTestCase;
import org.ametys.runtime.test.groups.ldap.LdapGroupsWithMemberTestCase;
import org.ametys.runtime.test.groups.ldap.LdapGroupsWithMemberUidTestCase;
import org.ametys.runtime.test.groups.ldap.LdapGroupsWithNamedMemberOfTestCase;
import org.ametys.runtime.test.migration.AllMigrationTestSuite;
import org.ametys.runtime.test.minimize.MinimizeTransformerContextPathTestCase;
import org.ametys.runtime.test.minimize.MinimizeTransformerTestCase;
import org.ametys.runtime.test.observers.ObserversTestCase;
import org.ametys.runtime.test.plugins.PluginsTestCase;
import org.ametys.runtime.test.resources.CompiledResourceReaderTestCase;
import org.ametys.runtime.test.resources.JsassResourceUriTestCase;
import org.ametys.runtime.test.resources.JsassSourceMapTestCase;
import org.ametys.runtime.test.resources.SourceMapContextPathTestCase;
import org.ametys.runtime.test.resources.SourceMapTestCase;
import org.ametys.runtime.test.rights.AllRightsTestSuite;
import org.ametys.runtime.test.scheduler.SchedulableTestCase;
import org.ametys.runtime.test.scheduler.progression.ContainerProgressionTrackerTestCase;
import org.ametys.runtime.test.scheduler.progression.SimpleProgressionTrackerTestCase;
import org.ametys.runtime.test.search.UserAndGroupSearchTestCase;
import org.ametys.runtime.test.ui.StaticUIItemFactoryTestCase;
import org.ametys.runtime.test.userpref.AllUserPreferencesTestSuite;
import org.ametys.runtime.test.users.jdbc.AllJdbcUsersTestSuite;
import org.ametys.runtime.test.users.ldap.LdapUsersTestCase;
import org.ametys.runtime.test.users.modifiable.ImportUsersTestCase;
import org.ametys.runtime.test.users.others.StaticUsersTestCase;
import org.ametys.runtime.test.util.AnnotationsTestCase;
import org.ametys.runtime.test.util.DateConversionTestCase;
import org.ametys.runtime.test.util.FilenameUtilsTestCase;
import org.ametys.runtime.test.util.I18nTestCase;
import org.ametys.runtime.test.util.JSONTestCase;
import org.ametys.runtime.test.util.SizeUtilsTestCase;
import org.ametys.runtime.test.util.URIUtilsTestCase;
import org.ametys.runtime.test.util.path.PathSourceTestCase;
import org.ametys.runtime.test.workspaces.WorkspaceGeneratorTestCase;

/**
 * Test suite grouping all Runtime tests
 */
@RunWith(Suite.class)
@SuiteClasses({
    AllFeatureActivatorTests.class,
    
    AllConfigTestSuite.class,
    AllModelTestSuite.class,
    ModelItemTypeHelperTestCase.class,
    DateXMLElementTypeTestCase.class,
    DateTimeXMLElementTypeTestCase.class,
    
    SafeModeTestCase.class,
    AmetysHomeTestCase.class,
    RuntimeConfigTestCase.class,
    WorkspacesTestCase.class,
    
    RequestCountListenerTestCase.class,
    SessionCountListenerTestCase.class,

    AllTokenTestSuite.class,
    
    CacheTestSuite.class,
    
    TraxProcessorTestCase.class,
    XHTMLSerializerTestCase.class,
    
    AllGroupsTestSuite.class,
    LdapGroupsWithMemberTestCase.class,
    LdapGroupsWithMemberUidTestCase.class,
    LdapGroupsWithMemberOfTestCase.class,
    LdapGroupsWithNamedMemberOfTestCase.class,
    LdapGroupsBidirectionalTestCase.class,
    
    MinimizeTransformerTestCase.class,
    MinimizeTransformerContextPathTestCase.class,
    ObserversTestCase.class,
    PluginsTestCase.class,
    
    CompiledResourceReaderTestCase.class,
    JsassResourceUriTestCase.class,
    JsassSourceMapTestCase.class,
    SourceMapTestCase.class,
    SourceMapContextPathTestCase.class,
    
    AllRightsTestSuite.class,
    
    UserAndGroupSearchTestCase.class,
    
    StaticUIItemFactoryTestCase.class,
    
    AllUserPreferencesTestSuite.class,
    
    AllJdbcUsersTestSuite.class,
    LdapUsersTestCase.class,
    ImportUsersTestCase.class,
    StaticUsersTestCase.class,
    
    AnnotationsTestCase.class,
    DOMUtilsTestCase.class,
    DateUtilsTestCase.class,
    MapUtilsTestCase.class,
    CachedValueTestCase.class,
    DateConversionTestCase.class,
    I18nTestCase.class,
    JSONTestCase.class,
    SizeUtilsTestCase.class,
    WorkspaceGeneratorTestCase.class,
    URIUtilsTestCase.class,
    FilenameUtilsTestCase.class,
    
    PathSourceTestCase.class,
    
    AllMigrationTestSuite.class,
    
    DefaultValidatorTestCase.class,
    
    SchedulableTestCase.class,
    SimpleProgressionTrackerTestCase.class,
    ContainerProgressionTrackerTestCase.class
})
public final class AllTests
{
    // empty class
}
