/*
 *  Copyright 2009 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test;

import org.junit.Assert;
import org.junit.Test;

import org.ametys.core.datasource.ConnectionHelper;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.ScriptHelper;
import org.ametys.runtime.test.framework.TestConfigSet;
import org.ametys.runtime.workspace.WorkspaceManager;

/**
 * Tests WorkspacesManager
 */
public class WorkspacesTestCase extends AbstractRuntimeTestCase
{
    /**
     * Tests many workspaces cases : dependencies, sitemap availability, ...
     * @throws Exception if an error occurs
     */
    @Test
    public void testValidWorkspace() throws Exception
    {
        TestConfigSet configSet = new TestConfigSet()
                .withRuntimeFile("test/environments/runtimes/exclude-policy/runtime01.xml")
                .withConfigFile("test/environments/configs/config1.xml")
                .withSqlFile(ScriptHelper.getDataSourceFile(ConnectionHelper.DATABASE_HSQLDB))
                .withWebappPath("test/environments/webapp2");
        try
        {
            startCocoon(configSet);
            Assert.assertTrue(WorkspaceManager.getInstance().getWorkspaceNames().contains("admin"));
            
            Assert.assertTrue(WorkspaceManager.getInstance().getWorkspaceNames().contains("workspace-test"));
            Assert.assertEquals(WorkspaceManager.getInstance().getWorkspaces().get("workspace-test").getThemeName(), "ametys-admin");
            
            // workspace-test2 don't have workspace.xml
            Assert.assertFalse(WorkspaceManager.getInstance().getWorkspaceNames().contains("workspace-test2"));
            
            // workspace-test3 has a dependency to an unexisting feature
            Assert.assertTrue(WorkspaceManager.getInstance().getWorkspaceNames().contains("workspace-test3"));
            Assert.assertEquals(WorkspaceManager.getInstance().getWorkspaces().get("workspace-test3").getThemeName(), "ametys-base");
        }
        finally
        {
            stopCocoon();
        }
    }
    
    /**
     * Tests an invalid workspaces set : the workspace 'admin' is defined twice
     * @throws Exception if an error occurs
     */
    @Test
    public void testInvalidWorkspace() throws Exception
    {
        TestConfigSet configSet = new TestConfigSet()
                .withRuntimeFile("test/environments/runtimes/exclude-policy/runtime01.xml")
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp3");
        try
        {
            startCocoon(configSet);
            Assert.fail("WorskpaceManager must have failed");
        }
        catch (IllegalArgumentException e)
        {
            // it is ok
        }
        finally
        {
            stopCocoon();
        }
    }
}
