/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.runtime.test.cache;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.junit.Assert;
import org.junit.Test;

import org.ametys.core.cache.AbstractCacheManager;
import org.ametys.core.cache.Cache;
import org.ametys.core.cache.CacheException;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;
import org.ametys.runtime.test.framework.TestConfigSet;
import org.ametys.runtime.test.framework.Unoptimized;

import junit.framework.TestCase;

/**
 * {@link TestCase} of {@link AbstractCacheManager} helper class.
 */
@NeedFeatures({
    "core/core.cache",
})
@Unoptimized /* Each test must have its own and independant CacheManager, thus declare the TestCase Unoptimized */
public class CacheManagerTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    private static AbstractCacheManager _cacheManager;

    @Override
    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp1");
    }
    
    @Override
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        _cacheManager = (AbstractCacheManager) manager.lookup(AbstractCacheManager.ROLE);
    }
    
    /**
     * Test that CacheManager can get a created cache successfully
     */
    @Test
    public void testCacheManager()
    {
        _cacheManager.createMemoryCache("id", null, null, false, null);
        Cache cache = _cacheManager.get("id");
        Assert.assertNotNull(cache);
    }

    /**
     * Test CacheException is thrown when getting uncreated cache
     */
    @Test
    public void testCacheException()
    {
        try
        {
            _cacheManager.get("id");
            Assert.fail();
        }
        catch (CacheException e)
        {
            Assert.assertEquals("Cache id does not exist ", e.getMessage());
        }
    }

}
