/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.runtime.test.cache;

import org.junit.Assert;
import org.junit.Test;

import org.ametys.core.cache.AbstractCacheManager;
import org.ametys.plugins.core.impl.cache.GuavaCacheStats;
import org.ametys.runtime.test.framework.AbstractBaseTestCase;

import com.google.common.cache.CacheStats;

import junit.framework.TestCase;

/**
 * {@link TestCase} of {@link AbstractCacheManager} helper class.
 */
public class CacheStatsTestCase extends AbstractBaseTestCase
{

    /**
     * Test date conversion
     */
    @Test
    public void testRate()
    {
        GuavaCacheStats cacheStats = new GuavaCacheStats(new CacheStats(5, 15, 0, 0, 0, 2));
        Assert.assertEquals(0.25, cacheStats.hitRate(), 0.1);
        Assert.assertEquals(0.75, cacheStats.missRate(), 0.1);
        Assert.assertEquals(0.1, cacheStats.evictionRate(), 0.1);
    }
    /**
     * Test date conversion
     */
    @Test
    public void testAddition()
    {
        GuavaCacheStats cacheStats1 = new GuavaCacheStats(new CacheStats(5, 19, 0, 0, 0, 2));
        GuavaCacheStats cacheStats2 = new GuavaCacheStats(new CacheStats(3, 7, 0, 0, 0, 0));
        org.ametys.core.cache.CacheStats additionCacheStats = cacheStats1.plus(cacheStats2);
        Assert.assertEquals(8, additionCacheStats.hitCount());
        Assert.assertEquals(26, additionCacheStats.missCount());
        Assert.assertEquals(34, additionCacheStats.requestCount());
        Assert.assertEquals(2, additionCacheStats.evictionCount());
        Assert.assertEquals(8.0 / 34.0, additionCacheStats.hitRate(), 0.1);
        Assert.assertEquals(26.0 / 34.0, additionCacheStats.missRate(), 0.1);
        Assert.assertEquals(2.0 / 34.0, additionCacheStats.evictionRate(), 0.1);
    }

    /**
     * Test date conversion
     */
    @Test
    public void testDifference()
    {
        GuavaCacheStats cacheStats1 = new GuavaCacheStats(new CacheStats(5, 19, 0, 0, 0, 2));
        GuavaCacheStats cacheStats2 = new GuavaCacheStats(new CacheStats(3, 7, 0, 0, 0, 0));
        org.ametys.core.cache.CacheStats additionCacheStats = cacheStats1.minus(cacheStats2);

        Assert.assertEquals(2, additionCacheStats.hitCount());
        Assert.assertEquals(12, additionCacheStats.missCount());
        Assert.assertEquals(14, additionCacheStats.requestCount());
        Assert.assertEquals(2, additionCacheStats.evictionCount());
        Assert.assertEquals(2.0 / 14, additionCacheStats.hitRate(), 0.1);
        Assert.assertEquals(12.0 / 14, additionCacheStats.missRate(), 0.1);
        Assert.assertEquals(2.0 / 34.0, additionCacheStats.evictionRate(), 0.1);
    }

}
