/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.cocoon;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Map;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceFactory;
import org.apache.excalibur.source.SourceResolver;

/**
 * {@link SourceFactory} used be the {@link TraxProcessorTestCase}.
 */
public class TestSourceFactory implements SourceFactory, Contextualizable, Serviceable
{
    private Context _context;
    private SourceResolver _resolver;
    
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    public void service(ServiceManager manager) throws ServiceException
    {
        _resolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }
    
    public Source getSource(String location, Map parameters) throws IOException, MalformedURLException
    {
        Request request = ContextHelper.getRequest(_context);
        String att = (String) request.getAttribute("test");
        
        String name = location.substring("test://".length(), location.length() - 4);
        
        String uri = att == null ? "resource://org/ametys/runtime/test/cocoon/" + name + "-1.xsl" : "resource://org/ametys/runtime/test/cocoon/" + name + "-2.xsl";
        
        return _resolver.resolveURI(uri);
    }

    public void release(Source source)
    {
        _resolver.release(source);
    }
}
