/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.migration;

import java.io.File;

import org.apache.commons.lang3.ArrayUtils;

import org.ametys.core.datasource.ConnectionHelper;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.TestConfigSet;

/**
 * Test migration with SQL version storage/handler
 */
public abstract class AbstractMigrationTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    public File[] getStartScriptFiles()
    {
        File initTable = new File("main/plugin-core/scripts/" + getDBType() + "/ametys_versions.sql");
        File[] startScriptFiles = CocoonTestCase.super.getStartScriptFiles();
        return ArrayUtils.add(startScriptFiles, initTable);
    }
    
    public String[] getStartScripts() throws Exception
    {
        String[] startScripts = CocoonTestCase.super.getStartScripts();
        
        // Adding a few Versions
        String versionQuery = "INSERT INTO Ametys_Versions \n"
                + "(component_identifier, ametys_version_number, execution_date, execution_comment) \n"
                + "VALUES \n"
                + "(\n"
                    + "'test.3', \n"
                    + "'20200101T1200', \n"
                    + getCurrentDateFunction() + ", \n"
                    + "'Inserted by test env.' \n"
                + ")";
        startScripts = ArrayUtils.add(startScripts, versionQuery);

        versionQuery = "INSERT INTO Ametys_Versions \n"
                + "(component_identifier, ametys_version_number, execution_date, execution_comment) \n"
                + "VALUES \n"
                + "(\n"
                    + "'test.4', \n"
                    + "'0', \n"
                    + getCurrentDateFunction() + ", \n"
                    + "'Inserted by test env.' \n"
                + ")";
        startScripts = ArrayUtils.add(startScripts, versionQuery);

        versionQuery = "INSERT INTO Ametys_Versions \n"
                + "(component_identifier, ametys_version_number, execution_date, execution_comment) \n"
                + "VALUES \n"
                + "(\n"
                    + "'test.migrations.scriptHandler.version0exists', \n"
                    + "'0', \n"
                    + getCurrentDateFunction() + ", \n"
                    + "'Inserted by test env.' \n"
                + ")";
        startScripts = ArrayUtils.add(startScripts, versionQuery);

        versionQuery = "INSERT INTO Ametys_Versions \n"
                + "(component_identifier, ametys_version_number, execution_date, execution_comment) \n"
                + "VALUES \n"
                + "(\n"
                    + "'test.migrations.javaHandler.version0exists', \n"
                    + "'0', \n"
                    + getCurrentDateFunction() + ", \n"
                    + "'Inserted by test env.' \n"
                + ");";
        startScripts = ArrayUtils.add(startScripts, versionQuery);
        
        // Init a few tables
        String initTable = "CREATE TABLE test_3 (comment_column varchar(64), PRIMARY KEY(comment_column))";
        startScripts = ArrayUtils.add(startScripts, initTable);
        initTable = "CREATE TABLE test_4 (comment_column varchar(64), PRIMARY KEY(comment_column));";
        startScripts = ArrayUtils.add(startScripts, initTable);
        initTable = "CREATE TABLE test_script (comment_column varchar(64), PRIMARY KEY(comment_column))";
        startScripts = ArrayUtils.add(startScripts, initTable);
        initTable = "CREATE TABLE test_java (comment_column varchar(64), PRIMARY KEY(comment_column))";
        startScripts = ArrayUtils.add(startScripts, initTable);
        
        return startScripts;
    }
    
    /**
     * Get the "now" function (NOW(), CURDATE, ...)
     * @return the "now" function.
     */
    public String getCurrentDateFunction()
    {
        String dbType = getDBType();
        switch (dbType)
        {
            case ConnectionHelper.DATABASE_MYSQL:
                return "NOW()";
            case ConnectionHelper.DATABASE_ORACLE:
                return "LOCALTIMESTAMP";
            case ConnectionHelper.DATABASE_HSQLDB:
                return "CURRENT_TIMESTAMP";
            case ConnectionHelper.DATABASE_POSTGRES:
                return "CURRENT_TIMESTAMP";
            case ConnectionHelper.DATABASE_DERBY:
                return "CURRENT_TIMESTAMP";
            default:
                return "";
        }
    }
    
    @Override
    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp-migration-tests");
    }
}
