/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.migration.component;

import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.core.migration.MigrationEngine.MigrationComponent;
import org.ametys.core.migration.MigrationEngine.VersionList;
import org.ametys.core.migration.MigrationEngine.VersionsContainer;
import org.ametys.core.migration.MigrationException;
import org.ametys.core.migration.version.Version;
import org.ametys.core.migration.version.handler.JavaVersionHandlerComponent;
import org.ametys.core.migration.version.storage.SqlVersionStorage;
import org.ametys.core.migration.version.storage.SqlVersionStorage.SqlVersionConfiguration;
import org.ametys.core.migration.version.storage.VersionStorageExtensionPoint;
import org.ametys.runtime.config.Config;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * dummy java handler that will return 2 versions
 */
public class Test8 implements JavaVersionHandlerComponent, Serviceable
{
    private SqlVersionStorage _sqlVersionStorage;
    
    public void service(ServiceManager manager) throws ServiceException
    {
        VersionStorageExtensionPoint versionStorageEP = (VersionStorageExtensionPoint) manager.lookup(VersionStorageExtensionPoint.ROLE);
        _sqlVersionStorage = (SqlVersionStorage) versionStorageEP.getExtension("sql");
    }

    public VersionsContainer getVersions(MigrationComponent component) throws MigrationException
    {
        VersionsContainer results = new VersionsContainer();
        
        String datasourceId = Config.getInstance().getValue("runtime.rights.datasource");
        SqlVersionConfiguration configuration = new SqlVersionConfiguration(datasourceId);

        List<Version> versionNull = _sqlVersionStorage.getVersions("test.migrations.javaHandler.noversion", configuration, component);
        for (Version version : versionNull)
        {
            version.addAdditionalValue("TABLENAME", "versionNull");
        }
        results.put(new I18nizableText("test.migrations.javaHandler.noversion"), new VersionList("test.migrations.javaHandler.noversion", versionNull, "test.migrations.javaHandler.noversion", configuration, Map.of("TABLENAME", "versionNull")));
        
        List<Version> versionNotNull = _sqlVersionStorage.getVersions("test.migrations.javaHandler.version0exists", configuration, component);
        for (Version version : versionNotNull)
        {
            version.addAdditionalValue("TABLENAME", "versionNotNull");
        }
        results.put(new I18nizableText("test.migrations.javaHandler.version0exists"), new VersionList("test.migrations.javaHandler.version0exists", versionNotNull, "test.migrations.javaHandler.version0exists", configuration, Map.of("TABLENAME", "versionNotNull")));
        
        return results;
    }
}
