/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.migration.script;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.junit.Assert;
import org.junit.Test;

import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;
import org.ametys.runtime.test.framework.TestConfigSet;

/**
 * Test migration with SQL version storage/handler
 */
@NeedFeatures({
    "test/test.migrations.script"
})
public class ScriptMigrationTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    /** Static property that will be modified by an initialization script */
    private static boolean __MODIFIED_BY_SCRIPT;
    
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        // Empty
    }
    
    @Override
    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp-migration-tests");
    }
    
    /**
     * Tests an initialization handled by a script
     */
    @Test
    public void testScriptInitialization()
    {
        Assert.assertEquals("Flag that should be modified by a script.", true, __MODIFIED_BY_SCRIPT);
    }
    
    /**
     * Will be called by an init script in test.2
     */
    public static void changeFlag()
    {
        __MODIFIED_BY_SCRIPT = true;
    }
}
