/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.minimize;

import org.junit.Test;

import org.ametys.core.DevMode;
import org.ametys.core.DevMode.DEVMODE;

/**
 * Test case for the minimize transformer using context paths
 */
public class MinimizeTransformerContextPathTestCase extends MinimizeTransformerTestCase
{
    @Override
    protected String getContextPath()
    {
        return "/contextPath";
    }
    
    /**
     * This test runs all the possible situations that the minimize transformer may encounter, though a single html file and all the minified results.
     * @throws Exception If an error occurs
     */
    @Test
    @Override
    public void testMinimizeTransformerFull() throws Exception
    {
        assertTransformation("complete-test-with-contextpath.html", "complete-test-result-with-contextpath.html", true);
    }
    
    @Override
    public void testMinimizeTransformerFileDependencies() throws Exception
    {
        DEVMODE mode = DevMode.getDeveloperMode(getRequest());
        
        getRequest().getSession(true).setAttribute(DevMode.SESSION_ATTRIBUTE_DEVMODE, DEVMODE.PRODUCTION.toString());
        
        assertCssFileDependencies("file-dependencies-test.html", true);
        
        getRequest().getSession(true).setAttribute(DevMode.SESSION_ATTRIBUTE_DEVMODE, DEVMODE.DEVELOPMENT.toString());
        
        assertCssFileDependencies("file-dependencies-test.html", false);
        
        getRequest().getSession(true).setAttribute(DevMode.SESSION_ATTRIBUTE_DEVMODE, mode.toString());
    }
}
