/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.resources;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.io.IOUtils;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceResolver;
import org.junit.Assert;
import org.junit.Test;

import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.TestConfigSet;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;

/**
 * Test case for the LESS and the SASS reader
 */
@NeedFeatures({
    "core/runtime.core",
    "test/test", "core/runtime.core.resources-handler",
    "core-ui/plugin.core.ui.resources.dependencies", "core-ui/plugin.core.ui.resources.sass.dependencies",
    "core-ui/runtime.core.ui.resources-handler",
    "core-ui/plugin.core.ui.minimize.resources.uri",
})
public class CompiledResourceReaderTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    private static SourceResolver _resolver;
    
    @Override
    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp2");
    }
    
    @Override
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        _resolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }
    
    /**
     * This test call the LESS reader and the SASS reader, and compare the result with the expected compiled value.
     * @throws Exception If an error occurs
     */
    @Test
    public void testSASSCompiledResourceReader() throws Exception
    {
        _assertCompiledResource("sass-less/sass-file-1.css", "sass-less-result/sass-file-1-result.css", "Error with SASS reader");
    }
    
    /**
     * This test call the LESS reader and the SASS reader, and compare the result with the expected compiled value.
     * @throws Exception If an error occurs
     */
    @Test
    public void testLESSCompiledResourceReader() throws Exception
    {
        _assertCompiledResource("sass-less/less-file-1.css", "sass-less-result/less-file-1-result.css", "Error with LESS reader");
    }
    
    /**
     * This test check if relative paths inside scss and css imported by scss behave as expected. 
     * @throws Exception If an error occurs
     */
    @Test
    public void testSASSRelativePaths() throws Exception
    {
        _assertCompiledResource("sass-relative-path/main.css", "sass-relative-path/result/expected-output.css", "Error with SCSS compiler and relative paths");
    }
    
    private void _assertCompiledResource(String inputFilename, String outputFilename, String error) throws Exception
    {
        Source expectedSource = _resolver.resolveURI("plugin:test://resources/css/" + outputFilename);
        Source resultSource = _resolver.resolveURI("cocoon://plugins/test/resources/css/" + inputFilename);
        
        String result = IOUtils.toString(resultSource.getInputStream(), "UTF-8");
        String expected = IOUtils.toString(expectedSource.getInputStream(), "UTF-8");
        Assert.assertEquals(error + ": Output does not match expected value", expected.replace("\r", ""), result.replace("\r", ""));
    }
}
