/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.resources;

import org.junit.Assert;
import org.junit.Test;

import org.ametys.core.minimize.css.JSASSFixHelper;
import org.ametys.runtime.test.framework.AbstractBaseTestCase;

import junit.framework.TestCase;

/**
 * {@link TestCase} of {@link JSASSFixHelper} for fix source maps after compiling sass files with JSASS.
 */
public class JsassSourceMapTestCase extends AbstractBaseTestCase
{
    /**
     * Test Helper that fix JSASS source map post compilation
     */
    @Test
    public void testJsassFixHelper()
    {
        String input = "{\n"
                + "    \"version\": 3,\n"
                + "    \"file\": \"file.css\",\n"
                + "    \"sources\": [\n"
                + "        \"path/file.scss\",\n"
                + "        \"path/file.scss/JSASS_CUSTOM.scss\",\n"
                + "        \"path/other_file.scss\",\n"
                + "        \"path/other_file.scss/JSASS_CUSTOM.scss\",\n"
                + "        \"path/other_file.scss/JSASS_PRE_IMPORT.scss\",\n"
                + "        \"path/another_file.scss\",\n"
                + "        \"path/other_file.scss/JSASS_POST_IMPORT.scss\",\n"
                + "    ],\n"
                + "    \"names\": [],\n"
                + "    \"mappings\": \"\"\n"
                + "}";
        
        String fixedSourceMap = JSASSFixHelper.fixJsassSourceMap(input, "/externalContextPath");
        
        Assert.assertTrue("JSASS injected file JSASS_CUSTOM found in source map, but should have been removed", !fixedSourceMap.contains("JSASS_CUSTOM.scss"));
        Assert.assertTrue("JSASS injected file JSASS_PRE_IMPORT found in source map, but should have been removed", !fixedSourceMap.contains("JSASS_PRE_IMPORT.scss"));
        Assert.assertTrue("JSASS injected file JSASS_POST_IMPORT found in source map, but should have been removed", !fixedSourceMap.contains("JSASS_POST_IMPORT.scss"));
        
        Assert.assertTrue("JSASS injected files were not correctly replaced", fixedSourceMap.contains("\"/externalContextPath/plugins/core/resources/css/jsass_injected_file_placeholder.css\""));
        
        Assert.assertTrue("File path in sources was not correctly transformed into absolute path", fixedSourceMap.contains("\"/path/file.scss\""));
    }
}
