/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.rights.access.controller;

import java.util.Collections;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import org.junit.Assert;
import org.junit.Test;

import org.ametys.core.group.GroupIdentity;
import org.ametys.core.right.AccessController.AccessResult;
import org.ametys.core.user.UserIdentity;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;

/**
 * Test when the hierarchical access controller has many parents
 */
@NeedFeatures({
    "rights-test/rights.access.controller.test.string",
    "rights-test/profile.assignment.test.jdbc"
})
public class MultipleParentsAccessControllerTestCase extends AbstractAccessControllerTestCase
{
    /**
     * Tests responding UNKNOWN when no assignments set
     */
    @Test
    public void testEmpty()
    {
        Object test = "/foo";
        
        initProfiles();
//        String profile1 = _profileIds.get(0);
//        String profile2 = _profileIds.get(1);
//        String profile3 = _profileIds.get(2);
//        String profile4 = _profileIds.get(3);
//        String profile5 = _profileIds.get(4);
//        String profile6 = _profileIds.get(5);
//        String profile7 = _profileIds.get(6);
        
        UserIdentity user1 = new UserIdentity("user1", "population1");
        
        GroupIdentity group1 = new GroupIdentity("group1", "directory1");
        GroupIdentity group2 = new GroupIdentity("group2", "directory2");
        Set<GroupIdentity> bothGroups = Stream.of(group1, group2).collect(Collectors.toSet());
        
        // initially nothing is set
        Assert.assertEquals(AccessResult.UNKNOWN, _accessController.getPermission(user1, Collections.EMPTY_SET, "noright", test));

        Assert.assertEquals(AccessResult.UNKNOWN, _accessController.getPermission(user1, bothGroups, "right12", test));
    }
    
    /**
     * Tests getPermissions method
     */
    @Test
    public void testGetPermissions()
    {
        Object test = "/foo";
        Object test1 = "/test1";
        Object test2 = "/test2";
        
        initProfiles();
        String profile1 = _profileIds.get(0);
        String profile2 = _profileIds.get(1);
        String profile3 = _profileIds.get(2);
        String profile4 = _profileIds.get(3);
        String profile5 = _profileIds.get(4);
        String profile6 = _profileIds.get(5);
        String profile7 = _profileIds.get(6);
        
        UserIdentity user1 = new UserIdentity("user1", "population1");
        UserIdentity user2 = new UserIdentity("user2", "population1");
        UserIdentity user3 = new UserIdentity("user3", "population1");
        UserIdentity user4 = new UserIdentity("user4", "population1");
        
        GroupIdentity group1 = new GroupIdentity("group1", "directory1");
        GroupIdentity group2 = new GroupIdentity("group2", "directory23");
        GroupIdentity group3 = new GroupIdentity("group3", "directory23");
        
        _profileAssignmentStorageEP.allowProfileToAnyConnectedUser(profile1, test1);
        _profileAssignmentStorageEP.allowProfileToUser(user1, profile2, test1);
        _profileAssignmentStorageEP.denyProfileToUser(user1, profile2, test2);
        
        _profileAssignmentStorageEP.allowProfileToGroup(group1, profile4, test1);
        _profileAssignmentStorageEP.denyProfileToGroup(group1, profile5, test1);
        
        _profileAssignmentStorageEP.allowProfileToGroup(group2, profile6, test1);
        _profileAssignmentStorageEP.denyProfileToGroup(group2, profile7, test2);
        
        _profileAssignmentStorageEP.allowProfileToGroup(group3, profile3, test2);
        _profileAssignmentStorageEP.denyProfileToGroup(group3, profile3, test1);
        
        // test
        Assert.assertEquals(AccessResult.ANY_CONNECTED_ALLOWED, _accessController.getPermission(user1, Collections.EMPTY_SET, "right1", test));
        Assert.assertEquals(AccessResult.UNKNOWN, _accessController.getPermission(user1, Collections.EMPTY_SET, "right4", test));
        Assert.assertEquals(AccessResult.USER_DENIED, _accessController.getPermission(user1, Collections.EMPTY_SET, "right2", test));
        Assert.assertEquals(AccessResult.GROUP_ALLOWED, _accessController.getPermission(user2, Collections.singleton(group1), "right4", test));
        Assert.assertEquals(AccessResult.GROUP_DENIED, _accessController.getPermission(user2, Collections.singleton(group1), "right5", test));
        
        Assert.assertEquals(AccessResult.GROUP_ALLOWED, _accessController.getPermission(user3, Collections.singleton(group2), "right6", test));
        Assert.assertEquals(AccessResult.GROUP_DENIED, _accessController.getPermission(user3, Collections.singleton(group2), "right7", test));
        
        Assert.assertEquals(AccessResult.GROUP_DENIED, _accessController.getPermission(user4, Collections.singleton(group3), "right3", test));
    }
}
