/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.rights.storage.assignments.jdbc;

import org.junit.Assert;
import org.junit.Test;

import org.ametys.core.right.ProfileAssignmentStorage;
import org.ametys.plugins.core.impl.right.JdbcProfileAssignmentStorage;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;
import org.ametys.runtime.test.framework.TestConfigSet;
import org.ametys.runtime.test.rights.storage.assignments.AbstractProfileAssignmentStorageTestCase; 

/**
 * Common test class for testing the {@link JdbcProfileAssignmentStorage} 
 */
@NeedFeatures("rights-test/profile.assignment.test.jdbc")
public abstract class AbstractJdbcProfileAssignmentStorageTestCase extends AbstractProfileAssignmentStorageTestCase
{
    @Override
    public TestConfigSet getConfigSet()
    {
        return super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp4");
    }
    
    @Override
    protected String _getExtensionId()
    {
        return "profile.assignment.test.JdbcProfileAssignmentStorage1";
    }
    
    @Override
    protected Object _getTest1()
    {
        return "/test1";
    }
    
    @Override
    protected Object _getTest2()
    {
        return "/test1/foo";
    }
    
    /**
     * Tests the support of String
     */
    @Test
    public void testSupport()
    {
        Assert.assertFalse(_profileAssignmentStorage.isSupported(""));
        Assert.assertFalse(_profileAssignmentStorage.isSupported("foo"));
        Assert.assertTrue(_profileAssignmentStorage.isSupported("/test1"));
        Assert.assertFalse(_profileAssignmentStorage.isSupported(new Object()));
    }
    
    /**
     * Tests the priority is min
     */
    @Test
    public void testPriority()
    {
        Assert.assertEquals(ProfileAssignmentStorage.MIN_PRIORITY, _profileAssignmentStorage.getPriority());
    }
}
