/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.scheduler;

import java.util.Collections;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.quartz.JobDataMap;
import org.quartz.JobExecutionContext;
import org.quartz.JobKey;

import org.ametys.core.schedule.AmetysJob;
import org.ametys.core.schedule.Runnable.FireProcess;
import org.ametys.core.schedule.progression.ContainerProgressionTracker;
import org.ametys.core.schedule.Schedulable;
import org.ametys.core.user.CurrentUserProvider;
import org.ametys.core.user.UserIdentity;
import org.ametys.plugins.core.impl.schedule.AbstractStaticSchedulable;
import org.ametys.plugins.core.impl.schedule.DefaultRunnable;
import org.ametys.plugins.core.schedule.Scheduler;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * {@link Schedulable} for testing concurrency. 
 */
public class TestSchedulable extends AbstractStaticSchedulable
{
    private CurrentUserProvider _userProvider;
    private Scheduler _scheduler;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _userProvider = (CurrentUserProvider) manager.lookup(CurrentUserProvider.ROLE);
        _scheduler = (Scheduler) manager.lookup(Scheduler.ROLE);
    }
    
    @Override
    public void execute(JobExecutionContext context, ContainerProgressionTracker progressionTracker) throws Exception
    {
        UserIdentity initialUser = _userProvider.getUser();
        
        org.ametys.core.schedule.Runnable job = new DefaultRunnable(
                "sub-test-schedulable",
                new I18nizableText("label"),
                new I18nizableText("desc"),
                FireProcess.NOW,
                null,
                "org.ametys.runtime.test.scheduler.SubTestSchedulable",
                true,
                false,
                false,
                null,
                true,
                new UserIdentity("user2", "static"),
                Collections.EMPTY_MAP);
        
        _scheduler.scheduleJob(job);
        
        JobDataMap dataMap = _scheduler.getScheduler().getJobDetail(new JobKey(job.getId(), Scheduler.JOB_GROUP)).getJobDataMap();
        while (dataMap.get(AmetysJob.KEY_SUCCESS) == null)
        {
            Thread.sleep(100);
            dataMap = _scheduler.getScheduler().getJobDetail(new JobKey(job.getId(), Scheduler.JOB_GROUP)).getJobDataMap();
        }
        
        UserIdentity user = _userProvider.getUser();
        
        System.out.println("Test schedulable executed by " + _userProvider.getUser());
        
        if (!initialUser.equals(user))
        {
            throw new IllegalArgumentException("Both initial user and end user should be the same");
        }
    }
}
