/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.scheduler.progression;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.junit.Assert;
import org.junit.Test;
import org.slf4j.LoggerFactory;

import org.ametys.core.schedule.progression.ProgressionTrackerFactory;
import org.ametys.core.schedule.progression.SimpleProgressionTracker;
import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;

/**
 * {@link SimpleProgressionTracker} implementation test case
 */
@NeedFeatures({
    "core/progression.tracker",
})
public class SimpleProgressionTrackerTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    @Override
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        // Do nothing
    }
    
    /**
     * Test the {@link SimpleProgressionTracker}
     */
    @Test
    public void testSimpleProgression()
    {
        SimpleProgressionTracker staticProgressionTracker = ProgressionTrackerFactory.createSimpleProgressionTracker(new I18nizableText("LABEL"), LoggerFactory.getLogger(getClass()));
        staticProgressionTracker.setSize(100);

        Assert.assertEquals(0d, staticProgressionTracker.asPercentage(), 0d);
        
        staticProgressionTracker.increment(10);
        Assert.assertEquals(10d, staticProgressionTracker.asPercentage(), 0d);
        
        staticProgressionTracker.increment(10);
        Assert.assertEquals(20d, staticProgressionTracker.asPercentage(), 0d);

        staticProgressionTracker.increment(50);
        Assert.assertEquals(70d, staticProgressionTracker.asPercentage(), 0d);

        staticProgressionTracker.increment(30);
        Assert.assertEquals(100d, staticProgressionTracker.asPercentage(), 0d);
    }
}
