/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.util.path;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Map;

import org.apache.avalon.framework.thread.ThreadSafe;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceFactory;
import org.apache.excalibur.source.SourceUtil;
import org.apache.excalibur.source.URIAbsolutizer;
import org.apache.excalibur.source.impl.FileSource;

import org.ametys.core.util.path.PathSource;

/**
 * A factory for filesystem-based sources (see {@link FileSource}).
 */
public class PathSourceFactory implements SourceFactory, ThreadSafe, URIAbsolutizer
{

    public Source getSource(String location, Map parameters) throws IOException, MalformedURLException
    {
        return new PathSource(location);
    }

    public void release(Source source)
    {
        // Nothing to do here
    }

    public String absolutize(String baseURI, String location)
    {
        // Call the absolutize utility method with false for the normalizePath argument.
        // This avoids the removal of "../" from the path.
        // This way, the "../" will be resolved by the operating system, which might
        // do things differently e.g. in case of symbolic links.
        return SourceUtil.absolutize(baseURI, location, false, false);
    }
}
