/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.runtime.test.util.path;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.InputStream;
import java.nio.charset.StandardCharsets;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.io.IOUtils;
import org.apache.excalibur.source.ModifiableTraversableSource;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceResolver;
import org.apache.excalibur.source.impl.FileSource;
import org.junit.Test;

import org.ametys.core.util.path.PathSource;
import org.ametys.runtime.plugin.PluginsManager;
import org.ametys.runtime.test.framework.AbstractRuntimeTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.TestConfigSet;

/**
 * Test PathSource
 */
public class PathSourceTestCase extends AbstractRuntimeTestCase implements CocoonTestCase
{
    private SourceResolver _sourceResolver;

    /**
     * Basic test for {@link PathSource}
     * @throws Exception if an error occurs
     */
    @Test
    public void testBasic() throws Exception
    {
        assertFalse(PluginsManager.getInstance().isSafeMode());
        
        // Get application root
        FileSource source = (FileSource) _sourceResolver.resolveURI("context://");
        
        Source webapp = _sourceResolver.resolveURI("path://" + source.getFile().getAbsolutePath());
        
        assertTrue(webapp instanceof ModifiableTraversableSource);
        ModifiableTraversableSource mtSource = (ModifiableTraversableSource) webapp;
        
        Source child = mtSource.getChild("plugins2");
        assertNotNull(child);
        assertFalse(child.exists());
        
        child = mtSource.getChild("plugins");
        assertNotNull(child);
        assertTrue(child.exists());
        
        Source pluginXml = _sourceResolver.resolveURI("path://" + source.getFile().getAbsolutePath() + "/plugins/test/plugin.xml");
        try (InputStream is = pluginXml.getInputStream())
        {
            assertTrue(IOUtils.toString(is, StandardCharsets.UTF_8).contains("http://www.ametys.org/schema/plugin"));
        }
        
        assertEquals(((ModifiableTraversableSource) ((ModifiableTraversableSource) pluginXml).getParent()).getChild("file").getContentLength(), 4L);
    }

    public TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/configs/config1.xml")
                .withWebappPath("test/environments/webapp5");
    }
    
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        _sourceResolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }
}
